import 'package:wnews/wnews.dart';
import 'package:test/test.dart';

void main() {
  test('throws from empty string', () {
    expect(() => extractNews(''), throwsArgumentError);
  });

  test('extracts the correct number of news items', () {
    expect(extractNews(_json).length, 4);
  });

  test('the first item is correct', () {
    final firstItem = extractNews(_json).first;
    expect(firstItem.text, contains('Texas Rangers'));
    expect(firstItem.link, isNotNull);
  });

  test('constructs endpoint URI', () {
    final uri = getEndpointUri();
    expect(uri.scheme, 'https');
    expect(uri.host, 'api.wikimedia.org');
    expect(uri.pathSegments, contains('en'));
    expect(uri.pathSegments, contains('featured'));
  });
}

const _json = r'''
{"tfa":{"type":"standard","title":"Murasaki_Shikibu","displaytitle":"<span class=\"mw-page-title-main\">Murasaki Shikibu</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q81731","titles":{"canonical":"Murasaki_Shikibu","normalized":"Murasaki Shikibu","display":"<span class=\"mw-page-title-main\">Murasaki Shikibu</span>"},"pageid":42758,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/1/19/Murasaki-Shikibu-composing-Genji-Monogatari.png/640px-Murasaki-Shikibu-composing-Genji-Monogatari.png","width":640,"height":514},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/1/19/Murasaki-Shikibu-composing-Genji-Monogatari.png","width":1817,"height":1458},"lang":"en","dir":"ltr","revision":"1183292530","tid":"f2d7e420-7a3e-11ee-9798-81f6f45eb32d","timestamp":"2023-11-03T11:48:45Z","description":"Japanese novelist and poet (c. 973 – c. 1014)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Murasaki_Shikibu","revisions":"https://en.wikipedia.org/wiki/Murasaki_Shikibu?action=history","edit":"https://en.wikipedia.org/wiki/Murasaki_Shikibu?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Murasaki_Shikibu"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Murasaki_Shikibu","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Murasaki_Shikibu","edit":"https://en.m.wikipedia.org/wiki/Murasaki_Shikibu?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Murasaki_Shikibu"}},"extract":"Murasaki Shikibu  was a Japanese novelist, poet and lady-in-waiting at the Imperial court in the Heian period. She is best known as the author of The Tale of Genji, widely considered to be one of the world's first novels, written in Japanese between about 1000 and 1012. Murasaki Shikibu is a descriptive name; her personal name is unknown, but she may have been Fujiwara no Kaoriko (藤原香子), who was mentioned in a 1007 court diary as an imperial lady-in-waiting.","extract_html":"<p><b>Murasaki Shikibu</b><span style=\"font-weight:normal\"> </span> was a Japanese novelist, poet and lady-in-waiting at the Imperial court in the Heian period. She is best known as the author of <i>The Tale of Genji</i>, widely considered to be one of the world's first novels, written in Japanese between about 1000 and 1012. Murasaki Shikibu is a descriptive name; her personal name is unknown, but she may have been <b>Fujiwara no Kaoriko</b><span style=\"font-weight:normal\"> (藤原香子)</span>, who was mentioned in a 1007 court diary as an imperial lady-in-waiting.</p>","normalizedtitle":"Murasaki Shikibu"},"mostread":{"date":"2023-11-02Z","articles":[{"views":718718,"rank":3,"view_history":[{"date":"2023-10-29Z","views":796947},{"date":"2023-10-30Z","views":574001},{"date":"2023-10-31Z","views":522628},{"date":"2023-11-01Z","views":570400},{"date":"2023-11-02Z","views":718718}],"type":"standard","title":"2023_Cricket_World_Cup","displaytitle":"<span class=\"mw-page-title-main\">2023 Cricket World Cup</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q16057443","titles":{"canonical":"2023_Cricket_World_Cup","normalized":"2023 Cricket World Cup","display":"<span class=\"mw-page-title-main\">2023 Cricket World Cup</span>"},"pageid":39812824,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/e/eb/2023_CWC_Logo.svg/320px-2023_CWC_Logo.svg.png","width":320,"height":377},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/e/eb/2023_CWC_Logo.svg/291px-2023_CWC_Logo.svg.png","width":291,"height":343},"lang":"en","dir":"ltr","revision":"1183291643","tid":"88d92530-7a3d-11ee-8008-0b7084c7bcd7","timestamp":"2023-11-03T11:38:34Z","description":"Ongoing ICC Cricket World Cup in India","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/2023_Cricket_World_Cup","revisions":"https://en.wikipedia.org/wiki/2023_Cricket_World_Cup?action=history","edit":"https://en.wikipedia.org/wiki/2023_Cricket_World_Cup?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:2023_Cricket_World_Cup"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/2023_Cricket_World_Cup","revisions":"https://en.m.wikipedia.org/wiki/Special:History/2023_Cricket_World_Cup","edit":"https://en.m.wikipedia.org/wiki/2023_Cricket_World_Cup?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:2023_Cricket_World_Cup"}},"extract":"The 2023 ICC Men's Cricket World Cup is the 13th edition of the Cricket World Cup, a quadrennial One Day International (ODI) cricket tournament contested by men's national teams and organised by the International Cricket Council (ICC). The tournament is being hosted by India. It started on 5 October and is scheduled to conclude on 19 November 2023. England are the defending champions, having won the 2019 edition by defeating New Zealand in the final at Lord's, London.","extract_html":"<p>The <b>2023 ICC Men's Cricket World Cup</b> is the 13th edition of the Cricket World Cup, a quadrennial One Day International (ODI) cricket tournament contested by men's national teams and organised by the International Cricket Council (ICC). The tournament is being hosted by India. It started on 5 October and is scheduled to conclude on 19 November 2023. England are the defending champions, having won the 2019 edition by defeating New Zealand in the final at Lord's, London.</p>","normalizedtitle":"2023 Cricket World Cup"},{"views":552818,"rank":5,"view_history":[{"date":"2023-10-29Z","views":618232},{"date":"2023-10-30Z","views":421805},{"date":"2023-10-31Z","views":381927},{"date":"2023-11-01Z","views":341797},{"date":"2023-11-02Z","views":552818}],"type":"standard","title":"Cricket_World_Cup","displaytitle":"<span class=\"mw-page-title-main\">Cricket World Cup</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q192202","titles":{"canonical":"Cricket_World_Cup","normalized":"Cricket World Cup","display":"<span class=\"mw-page-title-main\">Cricket World Cup</span>"},"pageid":7239,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/0/04/Icc_cricket_world_cup_trophy.jpg","width":284,"height":640},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/0/04/Icc_cricket_world_cup_trophy.jpg","width":284,"height":640},"lang":"en","dir":"ltr","revision":"1183274039","tid":"fcfe7980-7a1d-11ee-aa23-79ad1bedba6d","timestamp":"2023-11-03T07:52:44Z","description":"International cricket tournament","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Cricket_World_Cup","revisions":"https://en.wikipedia.org/wiki/Cricket_World_Cup?action=history","edit":"https://en.wikipedia.org/wiki/Cricket_World_Cup?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Cricket_World_Cup"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Cricket_World_Cup","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Cricket_World_Cup","edit":"https://en.m.wikipedia.org/wiki/Cricket_World_Cup?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Cricket_World_Cup"}},"extract":"The Cricket World Cup, officially known as ICC Men's Cricket World Cup, or simply called the World Cup is the international championship of One Day International (ODI) cricket. The event is organised by the sport's governing body, the International Cricket Council (ICC), every four years, with preliminary qualification rounds leading up to a finals tournament. The tournament is one of the world's most viewed sporting events and is considered the \"flagship event of the international cricket calendar\" by the ICC. It is the pinnacle championship of the sport of cricket.","extract_html":"<p>The <b>Cricket World Cup</b>, officially known as <b>ICC Men's Cricket World Cup</b>, or simply called the <b>World Cup</b> is the international championship of One Day International (ODI) cricket. The event is organised by the sport's governing body, the International Cricket Council (ICC), every four years, with preliminary qualification rounds leading up to a finals tournament. The tournament is one of the world's most viewed sporting events and is considered the \"flagship event of the international cricket calendar\" by the ICC. It is the pinnacle championship of the sport of cricket.</p>","normalizedtitle":"Cricket World Cup"},{"views":386522,"rank":7,"view_history":[{"date":"2023-10-29Z","views":91204},{"date":"2023-10-30Z","views":358857},{"date":"2023-10-31Z","views":548140},{"date":"2023-11-01Z","views":427708},{"date":"2023-11-02Z","views":386522}],"type":"standard","title":"XXXX_(beer)","displaytitle":"<span class=\"mw-page-title-main\">XXXX (beer)</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q924355","titles":{"canonical":"XXXX_(beer)","normalized":"XXXX (beer)","display":"<span class=\"mw-page-title-main\">XXXX (beer)</span>"},"pageid":90064,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/3/34/XXXX_Brewery_Milton.jpg/320px-XXXX_Brewery_Milton.jpg","width":320,"height":212},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/3/34/XXXX_Brewery_Milton.jpg","width":4928,"height":3264},"lang":"en","dir":"ltr","revision":"1182912750","tid":"1ad1b990-786b-11ee-82e4-8355c18c470d","timestamp":"2023-11-01T03:59:48Z","description":"Australian brand of beer","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/XXXX_(beer)","revisions":"https://en.wikipedia.org/wiki/XXXX_(beer)?action=history","edit":"https://en.wikipedia.org/wiki/XXXX_(beer)?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:XXXX_(beer)"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/XXXX_(beer)","revisions":"https://en.m.wikipedia.org/wiki/Special:History/XXXX_(beer)","edit":"https://en.m.wikipedia.org/wiki/XXXX_(beer)?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:XXXX_(beer)"}},"extract":"XXXX is a brand of Australian beer brewed in Milton, Brisbane, by Queensland brewers Castlemaine Perkins. It enjoys wide popularity in the state of Queensland, where it is commonly found on-tap in pubs and bars.","extract_html":"<p><b>XXXX</b> is a brand of Australian beer brewed in Milton, Brisbane, by Queensland brewers Castlemaine Perkins. It enjoys wide popularity in the state of Queensland, where it is commonly found on-tap in pubs and bars.</p>","normalizedtitle":"XXXX (beer)"},{"views":323840,"rank":8,"view_history":[{"date":"2023-10-29Z","views":8784586},{"date":"2023-10-30Z","views":2084189},{"date":"2023-10-31Z","views":955694},{"date":"2023-11-01Z","views":490539},{"date":"2023-11-02Z","views":323840}],"type":"standard","title":"Matthew_Perry","displaytitle":"<span class=\"mw-page-title-main\">Matthew Perry</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q171758","titles":{"canonical":"Matthew_Perry","normalized":"Matthew Perry","display":"<span class=\"mw-page-title-main\">Matthew Perry</span>"},"pageid":233338,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/c/c9/Matthew_Perry_and_Valerie_Jarrett_in_support_of_Awareness_on_Drug_Courts_and_Reduce_Substance_Abuse_%28cropped%29_%282%29.jpg/320px-Matthew_Perry_and_Valerie_Jarrett_in_support_of_Awareness_on_Drug_Courts_and_Reduce_Substance_Abuse_%28cropped%29_%282%29.jpg","width":320,"height":464},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/c/c9/Matthew_Perry_and_Valerie_Jarrett_in_support_of_Awareness_on_Drug_Courts_and_Reduce_Substance_Abuse_%28cropped%29_%282%29.jpg","width":515,"height":746},"lang":"en","dir":"ltr","revision":"1183287575","tid":"34c80de0-7a37-11ee-994b-bdfef062ad9e","timestamp":"2023-11-03T10:53:18Z","description":"American and Canadian actor (1969–2023)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Matthew_Perry","revisions":"https://en.wikipedia.org/wiki/Matthew_Perry?action=history","edit":"https://en.wikipedia.org/wiki/Matthew_Perry?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Matthew_Perry"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Matthew_Perry","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Matthew_Perry","edit":"https://en.m.wikipedia.org/wiki/Matthew_Perry?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Matthew_Perry"}},"extract":"Matthew Langford Perry was an American and Canadian actor. He starred as Chandler Bing on the NBC television sitcom Friends (1994–2004). Perry also appeared on Ally McBeal (2002) and received Primetime Emmy Award nominations for his performances in The West Wing (2003) and The Ron Clark Story (2006). He played a leading role in the NBC series Studio 60 on the Sunset Strip (2006–07). Perry also became known for his leading film roles in Fools Rush In (1997), Almost Heroes (1998), Three to Tango (1999), The Whole Nine Yards (2000), Serving Sara (2002), The Whole Ten Yards (2005), and 17 Again (2009).","extract_html":"<p><b>Matthew Langford Perry</b> was an American and Canadian actor. He starred as Chandler Bing on the NBC television sitcom <i>Friends</i> (1994–2004). Perry also appeared on <i>Ally McBeal</i> (2002) and received Primetime Emmy Award nominations for his performances in <i>The West Wing</i> (2003) and <i>The Ron Clark Story</i> (2006). He played a leading role in the NBC series <i>Studio 60 on the Sunset Strip</i> (2006–07). Perry also became known for his leading film roles in <i>Fools Rush In</i> (1997), <i>Almost Heroes</i> (1998), <i>Three to Tango</i> (1999), <i>The Whole Nine Yards</i> (2000), <i>Serving Sara</i> (2002), <i>The Whole Ten Yards</i> (2005), and <i>17 Again</i> (2009).</p>","normalizedtitle":"Matthew Perry"},{"views":297695,"rank":9,"view_history":[{"date":"2023-10-29Z","views":709},{"date":"2023-10-30Z","views":752},{"date":"2023-10-31Z","views":684},{"date":"2023-11-01Z","views":142570},{"date":"2023-11-02Z","views":297695}],"type":"standard","title":"Bob_Knight","displaytitle":"<span class=\"mw-page-title-main\">Bob Knight</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q888594","titles":{"canonical":"Bob_Knight","normalized":"Bob Knight","display":"<span class=\"mw-page-title-main\">Bob Knight</span>"},"pageid":4871,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/c/cc/Bob-Knight-Nov-21-07-1.jpg/320px-Bob-Knight-Nov-21-07-1.jpg","width":320,"height":400},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/c/cc/Bob-Knight-Nov-21-07-1.jpg","width":2400,"height":3000},"lang":"en","dir":"ltr","revision":"1183269499","tid":"3d18b550-7a17-11ee-aa48-091109f612d5","timestamp":"2023-11-03T07:04:27Z","description":"American basketball coach (1940–2023)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Bob_Knight","revisions":"https://en.wikipedia.org/wiki/Bob_Knight?action=history","edit":"https://en.wikipedia.org/wiki/Bob_Knight?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Bob_Knight"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Bob_Knight","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Bob_Knight","edit":"https://en.m.wikipedia.org/wiki/Bob_Knight?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Bob_Knight"}},"extract":"Robert Montgomery Knight was an American men's college basketball coach. Nicknamed \"the General\", Knight won 902 NCAA Division I men's basketball games, a record at the time of his retirement, and currently fifth all-time. Knight was the head coach of the Indiana Hoosiers from 1971 to 2000. He also coached the Texas Tech Red Raiders (2001–2008) and Army Black Knights (1965–1971).","extract_html":"<p><b>Robert Montgomery Knight</b> was an American men's college basketball coach. Nicknamed \"<b>the General</b>\", Knight won 902 NCAA Division I men's basketball games, a record at the time of his retirement, and currently fifth all-time. Knight was the head coach of the Indiana Hoosiers from 1971 to 2000. He also coached the Texas Tech Red Raiders (2001–2008) and Army Black Knights (1965–1971).</p>","normalizedtitle":"Bob Knight"},{"views":295441,"rank":10,"view_history":[{"date":"2023-10-29Z","views":14526},{"date":"2023-10-30Z","views":4469},{"date":"2023-10-31Z","views":14610},{"date":"2023-11-01Z","views":32293},{"date":"2023-11-02Z","views":295441}],"type":"standard","title":"Bruce_Bochy","displaytitle":"<span class=\"mw-page-title-main\">Bruce Bochy</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q586449","titles":{"canonical":"Bruce_Bochy","normalized":"Bruce Bochy","display":"<span class=\"mw-page-title-main\">Bruce Bochy</span>"},"pageid":2194854,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/a/a6/Bruce_Bochy_by_Gage_Skidmore.jpg/320px-Bruce_Bochy_by_Gage_Skidmore.jpg","width":320,"height":401},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/a/a6/Bruce_Bochy_by_Gage_Skidmore.jpg","width":2904,"height":3640},"lang":"en","dir":"ltr","revision":"1183238679","tid":"1a958d10-79ee-11ee-8268-931a85950667","timestamp":"2023-11-03T01:33:14Z","description":"French-American baseball player and manager (born 1955)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Bruce_Bochy","revisions":"https://en.wikipedia.org/wiki/Bruce_Bochy?action=history","edit":"https://en.wikipedia.org/wiki/Bruce_Bochy?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Bruce_Bochy"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Bruce_Bochy","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Bruce_Bochy","edit":"https://en.m.wikipedia.org/wiki/Bruce_Bochy?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Bruce_Bochy"}},"extract":"Bruce Douglas Bochy is an American professional baseball manager and former player who is the manager of the Texas Rangers of Major League Baseball (MLB). During his playing career, Bochy was a catcher for the Houston Astros, New York Mets, and San Diego Padres. After retiring as a player, Bochy managed the Padres for 12 seasons, from 1995 to 2006, and the San Francisco Giants for 13 seasons, from 2007 to 2019. As manager, Bochy led the Giants to three World Series championships, the Padres to one World Series appearance, and the Rangers to the franchise's first World Series championship in his first season with the club. He is one of only three managers to win a World Series championship in both leagues, joining Sparky Anderson and Tony LaRussa as the others. Bochy is the 11th manager in MLB history to achieve 2,000 wins.","extract_html":"<p><b>Bruce Douglas Bochy</b> is an American professional baseball manager and former player who is the manager of the Texas Rangers of Major League Baseball (MLB). During his playing career, Bochy was a catcher for the Houston Astros, New York Mets, and San Diego Padres. After retiring as a player, Bochy managed the Padres for 12 seasons, from 1995 to 2006, and the San Francisco Giants for 13 seasons, from 2007 to 2019. As manager, Bochy led the Giants to three World Series championships, the Padres to one World Series appearance, and the Rangers to the franchise's first World Series championship in his first season with the club. He is one of only three managers to win a World Series championship in both leagues, joining Sparky Anderson and Tony LaRussa as the others. Bochy is the 11th manager in MLB history to achieve 2,000 wins.</p>","normalizedtitle":"Bruce Bochy"},{"views":258406,"rank":12,"view_history":[{"date":"2023-10-29Z","views":10644},{"date":"2023-10-30Z","views":2754},{"date":"2023-10-31Z","views":31957},{"date":"2023-11-01Z","views":58133},{"date":"2023-11-02Z","views":258406}],"type":"standard","title":"Corey_Seager","displaytitle":"<span class=\"mw-page-title-main\">Corey Seager</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q17403431","titles":{"canonical":"Corey_Seager","normalized":"Corey Seager","display":"<span class=\"mw-page-title-main\">Corey Seager</span>"},"pageid":36297060,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/0/0f/Corey_Seager_answers_a_question_during_the_T-Mobile_-HRDerby_press_conference._%2828215398950%29.jpg/320px-Corey_Seager_answers_a_question_during_the_T-Mobile_-HRDerby_press_conference._%2828215398950%29.jpg","width":320,"height":213},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/0/0f/Corey_Seager_answers_a_question_during_the_T-Mobile_-HRDerby_press_conference._%2828215398950%29.jpg","width":5472,"height":3648},"lang":"en","dir":"ltr","revision":"1183288675","tid":"c6d10b50-7a38-11ee-ac7e-9d9f8364129c","timestamp":"2023-11-03T11:04:32Z","description":"American baseball player (born 1994)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Corey_Seager","revisions":"https://en.wikipedia.org/wiki/Corey_Seager?action=history","edit":"https://en.wikipedia.org/wiki/Corey_Seager?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Corey_Seager"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Corey_Seager","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Corey_Seager","edit":"https://en.m.wikipedia.org/wiki/Corey_Seager?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Corey_Seager"}},"extract":"Corey Drew Seager is an American professional baseball shortstop for the Texas Rangers of Major League Baseball (MLB). He previously played in MLB for the Los Angeles Dodgers.","extract_html":"<p><b>Corey Drew Seager</b> is an American professional baseball shortstop for the Texas Rangers of Major League Baseball (MLB). He previously played in MLB for the Los Angeles Dodgers.</p>","normalizedtitle":"Corey Seager"},{"views":256933,"rank":13,"view_history":[{"date":"2023-10-29Z","views":24856},{"date":"2023-10-30Z","views":9172},{"date":"2023-10-31Z","views":26589},{"date":"2023-11-01Z","views":57907},{"date":"2023-11-02Z","views":256933}],"type":"standard","title":"Texas_Rangers_(baseball)","displaytitle":"<span class=\"mw-page-title-main\">Texas Rangers (baseball)</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q329816","titles":{"canonical":"Texas_Rangers_(baseball)","normalized":"Texas Rangers (baseball)","display":"<span class=\"mw-page-title-main\">Texas Rangers (baseball)</span>"},"pageid":30857,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/4/41/Texas_Rangers.svg/320px-Texas_Rangers.svg.png","width":320,"height":320},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/4/41/Texas_Rangers.svg/200px-Texas_Rangers.svg.png","width":200,"height":200},"lang":"en","dir":"ltr","revision":"1183289802","tid":"a8960580-7a3a-11ee-8c87-47bb05da06b5","timestamp":"2023-11-03T11:18:00Z","description":"Major League Baseball franchise","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Texas_Rangers_(baseball)","revisions":"https://en.wikipedia.org/wiki/Texas_Rangers_(baseball)?action=history","edit":"https://en.wikipedia.org/wiki/Texas_Rangers_(baseball)?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Texas_Rangers_(baseball)"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Texas_Rangers_(baseball)","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Texas_Rangers_(baseball)","edit":"https://en.m.wikipedia.org/wiki/Texas_Rangers_(baseball)?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Texas_Rangers_(baseball)"}},"extract":"The Texas Rangers are an American professional baseball team based in Arlington, Texas. The Rangers compete in Major League Baseball (MLB) as a member club of the American League (AL) West division. In 2020, the Rangers moved to the new Globe Life Field in Arlington after having played at Globe Life Park from 1994 to 2019. The team's name derives from a historic law enforcement agency.","extract_html":"<p>The <b>Texas Rangers</b> are an American professional baseball team based in Arlington, Texas. The Rangers compete in Major League Baseball (MLB) as a member club of the American League (AL) West division. In 2020, the Rangers moved to the new Globe Life Field in Arlington after having played at Globe Life Park from 1994 to 2019. The team's name derives from a historic law enforcement agency.</p>","normalizedtitle":"Texas Rangers (baseball)"},{"views":216702,"rank":14,"view_history":[{"date":"2023-10-29Z","views":238864},{"date":"2023-10-30Z","views":212327},{"date":"2023-10-31Z","views":213220},{"date":"2023-11-01Z","views":231033},{"date":"2023-11-02Z","views":216702}],"type":"standard","title":"YouTube","displaytitle":"<span class=\"mw-page-title-main\">YouTube</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q866","titles":{"canonical":"YouTube","normalized":"YouTube","display":"<span class=\"mw-page-title-main\">YouTube</span>"},"pageid":3524766,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/b/b1/YouTube_screenshot.webp/320px-YouTube_screenshot.webp.png","width":320,"height":200},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/b/b1/YouTube_screenshot.webp/400px-YouTube_screenshot.webp.png","width":400,"height":250},"lang":"en","dir":"ltr","revision":"1183055882","tid":"90949ff0-7909-11ee-96aa-65e460afb8de","timestamp":"2023-11-01T22:53:47Z","description":"American video-sharing platform owned by Google","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/YouTube","revisions":"https://en.wikipedia.org/wiki/YouTube?action=history","edit":"https://en.wikipedia.org/wiki/YouTube?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:YouTube"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/YouTube","revisions":"https://en.m.wikipedia.org/wiki/Special:History/YouTube","edit":"https://en.m.wikipedia.org/wiki/YouTube?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:YouTube"}},"extract":"YouTube is an online video sharing and social media platform headquartered in San Bruno, California, United States. Accessible worldwide, it was launched on February 14, 2005, by Steve Chen, Chad Hurley, and Jawed Karim. It is owned by Google and is the second most visited website in the world, after Google Search. YouTube has more than 2.5 billion monthly users, who collectively watch more than one billion hours of videos every day. As of May 2019, videos were being uploaded to the platform at a rate of more than 500 hours of content per minute.","extract_html":"<p><b>YouTube</b> is an online video sharing and social media platform headquartered in San Bruno, California, United States. Accessible worldwide, it was launched on February 14, 2005, by Steve Chen, Chad Hurley, and Jawed Karim. It is owned by Google and is the second most visited website in the world, after Google Search. YouTube has more than 2.5 billion monthly users, who collectively watch more than one billion hours of videos every day. As of May 2019, videos were being uploaded to the platform at a rate of more than 500 hours of content per minute.</p>","normalizedtitle":"YouTube"},{"views":172513,"rank":15,"view_history":[{"date":"2023-10-29Z","views":34631},{"date":"2023-10-30Z","views":46501},{"date":"2023-10-31Z","views":74928},{"date":"2023-11-01Z","views":329066},{"date":"2023-11-02Z","views":172513}],"type":"standard","title":"Day_of_the_Dead","displaytitle":"<span class=\"mw-page-title-main\">Day of the Dead</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q309256","titles":{"canonical":"Day_of_the_Dead","normalized":"Day of the Dead","display":"<span class=\"mw-page-title-main\">Day of the Dead</span>"},"pageid":52303,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/1/1e/Altardediademuertos.jpg/320px-Altardediademuertos.jpg","width":320,"height":478},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/1/1e/Altardediademuertos.jpg","width":2541,"height":3796},"lang":"en","dir":"ltr","revision":"1183170515","tid":"e3070050-799c-11ee-b744-ef7e28d9be16","timestamp":"2023-11-02T16:28:35Z","description":"Mexican multi-day holiday","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Day_of_the_Dead","revisions":"https://en.wikipedia.org/wiki/Day_of_the_Dead?action=history","edit":"https://en.wikipedia.org/wiki/Day_of_the_Dead?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Day_of_the_Dead"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Day_of_the_Dead","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Day_of_the_Dead","edit":"https://en.m.wikipedia.org/wiki/Day_of_the_Dead?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Day_of_the_Dead"}},"extract":"The Day of the Dead is a holiday traditionally celebrated on November 1 and 2, though other days, such as October 31 or November 6, may be included depending on the locality. It is widely observed in Mexico, where it largely developed, and is also observed in other places, especially by people of Mexican heritage. Although related to the simultaneous Christian remembrances for Hallowtide, it has a much less solemn tone and is portrayed as a holiday of joyful celebration rather than mourning. Some argue that there are Indigenous Mexican or ancient Aztec influences that account for the custom, and it has become a way to remember those forebears of Mexican culture. The multi-day holiday involves family and friends gathering to pay respects and to remember friends and family members who have died. These celebrations can take a humorous tone, as celebrants remember funny events and anecdotes about the departed.","extract_html":"<p>The <b>Day of the Dead</b> is a holiday traditionally celebrated on November 1 and 2, though other days, such as October 31 or November 6, may be included depending on the locality. It is widely observed in Mexico, where it largely developed, and is also observed in other places, especially by people of Mexican heritage. Although related to the simultaneous Christian remembrances for Hallowtide, it has a much less solemn tone and is portrayed as a holiday of joyful celebration rather than mourning. Some argue that there are Indigenous Mexican or ancient Aztec influences that account for the custom, and it has become a way to remember those forebears of Mexican culture. The multi-day holiday involves family and friends gathering to pay respects and to remember friends and family members who have died. These celebrations can take a humorous tone, as celebrants remember funny events and anecdotes about the departed.</p>","normalizedtitle":"Day of the Dead"},{"views":170228,"rank":16,"view_history":[{"date":"2023-10-29Z","views":148296},{"date":"2023-10-30Z","views":163776},{"date":"2023-10-31Z","views":171334},{"date":"2023-11-01Z","views":178882},{"date":"2023-11-02Z","views":170228}],"type":"standard","title":"2023_Israel–Hamas_war","displaytitle":"<span class=\"mw-page-title-main\">2023 Israel–Hamas war</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q122962941","titles":{"canonical":"2023_Israel–Hamas_war","normalized":"2023 Israel–Hamas war","display":"<span class=\"mw-page-title-main\">2023 Israel–Hamas war</span>"},"pageid":74998519,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/3/3d/October_2023_Gaza%E2%88%92Israel_conflict.svg/320px-October_2023_Gaza%E2%88%92Israel_conflict.svg.png","width":320,"height":277},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/3/3d/October_2023_Gaza%E2%88%92Israel_conflict.svg/3763px-October_2023_Gaza%E2%88%92Israel_conflict.svg.png","width":3763,"height":3258},"lang":"en","dir":"ltr","revision":"1183294038","tid":"6f0d0050-7a41-11ee-85ae-cb7b1bd4977a","timestamp":"2023-11-03T12:04:59Z","description":"Ongoing armed conflict in the Middle East","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/2023_Israel%E2%80%93Hamas_war","revisions":"https://en.wikipedia.org/wiki/2023_Israel%E2%80%93Hamas_war?action=history","edit":"https://en.wikipedia.org/wiki/2023_Israel%E2%80%93Hamas_war?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:2023_Israel%E2%80%93Hamas_war"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/2023_Israel%E2%80%93Hamas_war","revisions":"https://en.m.wikipedia.org/wiki/Special:History/2023_Israel%E2%80%93Hamas_war","edit":"https://en.m.wikipedia.org/wiki/2023_Israel%E2%80%93Hamas_war?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:2023_Israel%E2%80%93Hamas_war"}},"extract":"An armed conflict between Hamas-led Palestinian militant groups and Israeli military forces broke out on 7 October 2023, with a Hamas attack on southern Israel, to which Israeli military forces retaliated with extensive strikes against Palestine's Gaza Strip and a subsequent invasion of Gaza. By the end of October, more than 1,500 Israelis and more than 8,000 Palestinians had been killed, including more than 3,000 children, while over 230 Israelis and foreign nationals remained captured or taken as hostages.","extract_html":"<p>An armed conflict between Hamas-led Palestinian militant groups and Israeli military forces broke out on 7 October 2023, with a Hamas attack on southern Israel, to which Israeli military forces retaliated with extensive strikes against Palestine's Gaza Strip and a subsequent invasion of Gaza. By the end of October, more than 1,500 Israelis and more than 8,000 Palestinians had been killed, including more than 3,000 children, while over 230 Israelis and foreign nationals remained captured or taken as hostages.</p>","normalizedtitle":"2023 Israel–Hamas war"},{"views":161985,"rank":17,"view_history":[{"date":"2023-10-29Z","views":6701},{"date":"2023-10-30Z","views":26150},{"date":"2023-10-31Z","views":5494},{"date":"2023-11-01Z","views":6492},{"date":"2023-11-02Z","views":161985}],"type":"standard","title":"Sri_Lanka_national_cricket_team","displaytitle":"<span class=\"mw-page-title-main\">Sri Lanka national cricket team</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q203092","titles":{"canonical":"Sri_Lanka_national_cricket_team","normalized":"Sri Lanka national cricket team","display":"<span class=\"mw-page-title-main\">Sri Lanka national cricket team</span>"},"pageid":397246,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/e/eb/Sri_Lanka_Cricket_Cap_Insignia.svg/320px-Sri_Lanka_Cricket_Cap_Insignia.svg.png","width":320,"height":320},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/e/eb/Sri_Lanka_Cricket_Cap_Insignia.svg/283px-Sri_Lanka_Cricket_Cap_Insignia.svg.png","width":283,"height":283},"lang":"en","dir":"ltr","revision":"1183278155","tid":"0a1665d0-7a26-11ee-9121-056253bd5ec5","timestamp":"2023-11-03T08:50:20Z","description":"Cricket team","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Sri_Lanka_national_cricket_team","revisions":"https://en.wikipedia.org/wiki/Sri_Lanka_national_cricket_team?action=history","edit":"https://en.wikipedia.org/wiki/Sri_Lanka_national_cricket_team?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Sri_Lanka_national_cricket_team"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Sri_Lanka_national_cricket_team","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Sri_Lanka_national_cricket_team","edit":"https://en.m.wikipedia.org/wiki/Sri_Lanka_national_cricket_team?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Sri_Lanka_national_cricket_team"}},"extract":"The Sri Lanka men's national cricket team, nicknamed The Lions, represents Sri Lanka in men's international cricket. It is a Full Member of the International Cricket Council (ICC) with Test, One-Day International (ODI) and T20 International (T20I) status. The team first played international cricket in 1926–27 and became an associate member of ICC in 1965. They were later awarded Test status in 1981, which made Sri Lanka the eighth Test cricket-playing nation. The team is administered by Sri Lanka Cricket.","extract_html":"<p>The <b>Sri Lanka men's national cricket team</b>, nicknamed <b>The Lions</b>, represents Sri Lanka in men's international cricket. It is a Full Member of the International Cricket Council (ICC) with Test, One-Day International (ODI) and T20 International (T20I) status. The team first played international cricket in 1926–27 and became an associate member of ICC in 1965. They were later awarded Test status in 1981, which made Sri Lanka the eighth Test cricket-playing nation. The team is administered by Sri Lanka Cricket.</p>","normalizedtitle":"Sri Lanka national cricket team"},{"views":159000,"rank":18,"view_history":[{"date":"2023-10-29Z","views":2060},{"date":"2023-10-30Z","views":34065},{"date":"2023-10-31Z","views":111610},{"date":"2023-11-01Z","views":110421},{"date":"2023-11-02Z","views":159000}],"type":"disambiguation","title":"XXXX","displaytitle":"<span class=\"mw-page-title-main\">XXXX</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q8042634","titles":{"canonical":"XXXX","normalized":"XXXX","display":"<span class=\"mw-page-title-main\">XXXX</span>"},"pageid":1384520,"lang":"en","dir":"ltr","revision":"1106366030","tid":"4d547790-3bfd-11ee-bd51-b72dfc6e8bd0","timestamp":"2022-08-24T07:15:26Z","description":"Topics referred to by the same term","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/XXXX","revisions":"https://en.wikipedia.org/wiki/XXXX?action=history","edit":"https://en.wikipedia.org/wiki/XXXX?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:XXXX"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/XXXX","revisions":"https://en.m.wikipedia.org/wiki/Special:History/XXXX","edit":"https://en.m.wikipedia.org/wiki/XXXX?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:XXXX"}},"extract":"XXXX may refer to:","extract_html":"<p><b>XXXX</b> may refer to:</p>","normalizedtitle":"XXXX"},{"views":157921,"rank":19,"view_history":[{"date":"2023-10-29Z","views":49391},{"date":"2023-10-30Z","views":44836},{"date":"2023-10-31Z","views":46308},{"date":"2023-11-01Z","views":64097},{"date":"2023-11-02Z","views":157921}],"type":"standard","title":"Jawan_(film)","displaytitle":"<i>Jawan</i> (film)","namespace":{"id":0,"text":""},"wikibase_item":"Q113493289","titles":{"canonical":"Jawan_(film)","normalized":"Jawan (film)","display":"<i>Jawan</i> (film)"},"pageid":70937790,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/3/39/Jawan_film_poster.jpg","width":283,"height":354},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/3/39/Jawan_film_poster.jpg","width":283,"height":354},"lang":"en","dir":"ltr","revision":"1183285354","tid":"971683e0-7a33-11ee-93f8-df94fe664196","timestamp":"2023-11-03T10:27:23Z","description":"2023 Indian Hindi action thriller film by Atlee","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Jawan_(film)","revisions":"https://en.wikipedia.org/wiki/Jawan_(film)?action=history","edit":"https://en.wikipedia.org/wiki/Jawan_(film)?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Jawan_(film)"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Jawan_(film)","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Jawan_(film)","edit":"https://en.m.wikipedia.org/wiki/Jawan_(film)?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Jawan_(film)"}},"extract":"Jawan ( transl. Soldier) is a 2023 Indian Hindi-language action thriller film co-written and directed by Atlee in his Hindi film debut. It is produced by Gauri Khan and Gaurav Verma under Red Chillies Entertainment. The film stars Shah Rukh Khan in a dual role as father and son who team up to rectify corruption in society. Nayanthara, Vijay Sethupathi, Deepika Padukone, Priyamani and Sanya Malhotra appear in supporting roles.","extract_html":"<p><i><b>Jawan</b></i> ( <abbr>transl.</abbr> Soldier) is a 2023 Indian Hindi-language action thriller film co-written and directed by Atlee in his Hindi film debut. It is produced by Gauri Khan and Gaurav Verma under Red Chillies Entertainment. The film stars Shah Rukh Khan in a dual role as father and son who team up to rectify corruption in society. Nayanthara, Vijay Sethupathi, Deepika Padukone, Priyamani and Sanya Malhotra appear in supporting roles.</p>","normalizedtitle":"Jawan (film)"},{"views":154169,"rank":20,"view_history":[{"date":"2023-10-29Z","views":159024},{"date":"2023-10-30Z","views":154157},{"date":"2023-10-31Z","views":157012},{"date":"2023-11-01Z","views":156983},{"date":"2023-11-02Z","views":154169}],"type":"standard","title":"Cleopatra","displaytitle":"<span class=\"mw-page-title-main\">Cleopatra</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q635","titles":{"canonical":"Cleopatra","normalized":"Cleopatra","display":"<span class=\"mw-page-title-main\">Cleopatra</span>"},"pageid":60827,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/3/3e/Kleopatra-VII.-Altes-Museum-Berlin1.jpg/320px-Kleopatra-VII.-Altes-Museum-Berlin1.jpg","width":320,"height":424},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/3/3e/Kleopatra-VII.-Altes-Museum-Berlin1.jpg","width":1149,"height":1523},"lang":"en","dir":"ltr","revision":"1182409579","tid":"a8c40c90-7617-11ee-ab26-a394457b4b34","timestamp":"2023-10-29T04:57:11Z","description":"Queen of Egypt from 51 to 30 BC","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Cleopatra","revisions":"https://en.wikipedia.org/wiki/Cleopatra?action=history","edit":"https://en.wikipedia.org/wiki/Cleopatra?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Cleopatra"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Cleopatra","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Cleopatra","edit":"https://en.m.wikipedia.org/wiki/Cleopatra?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Cleopatra"}},"extract":"Cleopatra VII Thea Philopator was Queen of the Ptolemaic Kingdom of Egypt from 51 to 30 BC, and its last active ruler. A member of the Ptolemaic dynasty, she was a descendant of its founder Ptolemy I Soter, a Macedonian Greek general and companion of Alexander the Great. After the death of Cleopatra, Egypt became a province of the Roman Empire, marking the end of the last Hellenistic-period state in the Mediterranean and of the age that had lasted since the reign of Alexander. Her first language was Koine Greek and she is the only known Ptolemaic ruler to learn the Egyptian language.","extract_html":"<p><b>Cleopatra VII Thea Philopator</b> was Queen of the Ptolemaic Kingdom of Egypt from 51 to 30 BC, and its last active ruler. A member of the Ptolemaic dynasty, she was a descendant of its founder Ptolemy I Soter, a Macedonian Greek general and companion of Alexander the Great. After the death of Cleopatra, Egypt became a province of the Roman Empire, marking the end of the last Hellenistic-period state in the Mediterranean and of the age that had lasted since the reign of Alexander. Her first language was Koine Greek and she is the only known Ptolemaic ruler to learn the Egyptian language.</p>","normalizedtitle":"Cleopatra"},{"views":147921,"rank":21,"view_history":[{"date":"2023-10-29Z","views":155726},{"date":"2023-10-30Z","views":38972},{"date":"2023-10-31Z","views":22740},{"date":"2023-11-01Z","views":24909},{"date":"2023-11-02Z","views":147921}],"type":"standard","title":"India_national_cricket_team","displaytitle":"<span class=\"mw-page-title-main\">India national cricket team</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q1143793","titles":{"canonical":"India_national_cricket_team","normalized":"India national cricket team","display":"<span class=\"mw-page-title-main\">India national cricket team</span>"},"pageid":407754,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/4/41/Flag_of_India.svg/320px-Flag_of_India.svg.png","width":320,"height":213},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/4/41/Flag_of_India.svg/900px-Flag_of_India.svg.png","width":900,"height":600},"lang":"en","dir":"ltr","revision":"1183200531","tid":"bd2b5410-79bc-11ee-8ad5-3b5acf1dbf95","timestamp":"2023-11-02T20:16:31Z","description":"Men's cricket team","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/India_national_cricket_team","revisions":"https://en.wikipedia.org/wiki/India_national_cricket_team?action=history","edit":"https://en.wikipedia.org/wiki/India_national_cricket_team?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:India_national_cricket_team"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/India_national_cricket_team","revisions":"https://en.m.wikipedia.org/wiki/Special:History/India_national_cricket_team","edit":"https://en.m.wikipedia.org/wiki/India_national_cricket_team?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:India_national_cricket_team"}},"extract":"The India men's international cricket team represents India in men's international cricket. It is governed by the Board of Control for Cricket in India (BCCI), and is a Full Member of the International Cricket Council (ICC) with Test, One Day International (ODI) and Twenty20 International (T20I) status.","extract_html":"<p>The <b>India men's international cricket team</b> represents India in men's international cricket. It is governed by the Board of Control for Cricket in India (BCCI), and is a Full Member of the International Cricket Council (ICC) with Test, One Day International (ODI) and Twenty20 International (T20I) status.</p>","normalizedtitle":"India national cricket team"},{"views":140978,"rank":22,"view_history":[{"date":"2023-10-29Z","views":6407},{"date":"2023-10-30Z","views":8056},{"date":"2023-10-31Z","views":8962},{"date":"2023-11-01Z","views":30447},{"date":"2023-11-02Z","views":140978}],"type":"standard","title":"Now_and_Then_(Beatles_song)","displaytitle":"<span class=\"mw-page-title-main\">Now and Then (Beatles song)</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q3293037","titles":{"canonical":"Now_and_Then_(Beatles_song)","normalized":"Now and Then (Beatles song)","display":"<span class=\"mw-page-title-main\">Now and Then (Beatles song)</span>"},"pageid":11010122,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/7/79/Now_and_Then.png","width":300,"height":300},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/7/79/Now_and_Then.png","width":300,"height":300},"lang":"en","dir":"ltr","revision":"1183287252","tid":"b6f31270-7a36-11ee-9d7b-5169b507ab73","timestamp":"2023-11-03T10:49:49Z","description":"2023 single by the Beatles","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Now_and_Then_(Beatles_song)","revisions":"https://en.wikipedia.org/wiki/Now_and_Then_(Beatles_song)?action=history","edit":"https://en.wikipedia.org/wiki/Now_and_Then_(Beatles_song)?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Now_and_Then_(Beatles_song)"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Now_and_Then_(Beatles_song)","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Now_and_Then_(Beatles_song)","edit":"https://en.m.wikipedia.org/wiki/Now_and_Then_(Beatles_song)?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Now_and_Then_(Beatles_song)"}},"extract":"\"Now and Then\" is a single by the English rock band the Beatles. It was released on 2 November 2023 as a double A-side single, paired with a new mix of the band's first single, \"Love Me Do\" (1962). Dubbed \"the last Beatles song\", it is also to be included on the expanded re-issue of the 1973 compilation 1967–1970, to be released on 10 November 2023.","extract_html":"<p>\"<b>Now and Then</b>\" is a single by the English rock band the Beatles. It was released on 2 November 2023 as a double A-side single, paired with a new mix of the band's first single, \"Love Me Do\" (1962). Dubbed \"the last Beatles song\", it is also to be included on the expanded re-issue of the 1973 compilation <i>1967–1970</i>, to be released on 10 November 2023.</p>","normalizedtitle":"Now and Then (Beatles song)"},{"views":140886,"rank":23,"view_history":[{"date":"2023-10-29Z","views":232217},{"date":"2023-10-30Z","views":204671},{"date":"2023-10-31Z","views":181036},{"date":"2023-11-01Z","views":162038},{"date":"2023-11-02Z","views":140886}],"type":"standard","title":"Leo_(2023_Indian_film)","displaytitle":"<i>Leo</i> (2023 Indian film)","namespace":{"id":0,"text":""},"wikibase_item":"Q116536092","titles":{"canonical":"Leo_(2023_Indian_film)","normalized":"Leo (2023 Indian film)","display":"<i>Leo</i> (2023 Indian film)"},"pageid":72891124,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/7/75/Leo_%282023_Indian_film%29.jpg","width":258,"height":387},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/7/75/Leo_%282023_Indian_film%29.jpg","width":258,"height":387},"lang":"en","dir":"ltr","revision":"1183287708","tid":"62fecdc0-7a37-11ee-adf6-97bc3ce4c27d","timestamp":"2023-11-03T10:54:34Z","description":"Indian film by Lokesh Kanagaraj","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Leo_(2023_Indian_film)","revisions":"https://en.wikipedia.org/wiki/Leo_(2023_Indian_film)?action=history","edit":"https://en.wikipedia.org/wiki/Leo_(2023_Indian_film)?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Leo_(2023_Indian_film)"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Leo_(2023_Indian_film)","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Leo_(2023_Indian_film)","edit":"https://en.m.wikipedia.org/wiki/Leo_(2023_Indian_film)?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Leo_(2023_Indian_film)"}},"extract":"Leo is a 2023 Indian Tamil-language action thriller film directed by Lokesh Kanagaraj and produced by Seven Screen Studio. The film stars Vijay in the titular role, alongside Sanjay Dutt, Arjun, Trisha, Gautham Vasudev Menon, Mysskin, Madonna Sebastian, George Maryan, Mansoor Ali Khan, Priya Anand and Mathew Thomas. It is the third installment in the Lokesh Cinematic Universe and is inspired by A History of Violence (2005), an adaptation of the graphic novel of the same name. The film follows Parthi, a café owner and animal rescuer in Theog, who is pursued by gangsters Antony and Harold Das who suspect him to be Antony's estranged son, Leo.","extract_html":"<p><i><b>Leo</b></i> is a 2023 Indian Tamil-language action thriller film directed by Lokesh Kanagaraj and produced by Seven Screen Studio. The film stars Vijay in the titular role, alongside Sanjay Dutt, Arjun, Trisha, Gautham Vasudev Menon, Mysskin, Madonna Sebastian, George Maryan, Mansoor Ali Khan, Priya Anand and Mathew Thomas. It is the third installment in the Lokesh Cinematic Universe and is inspired by <i>A History of Violence</i> (2005), an adaptation of the graphic novel of the same name. The film follows Parthi, a café owner and animal rescuer in Theog, who is pursued by gangsters Antony and Harold Das who suspect him to be Antony's estranged son, Leo.</p>","normalizedtitle":"Leo (2023 Indian film)"},{"views":138127,"rank":24,"view_history":[{"date":"2023-10-29Z","views":361229},{"date":"2023-10-30Z","views":299740},{"date":"2023-10-31Z","views":221330},{"date":"2023-11-01Z","views":186335},{"date":"2023-11-02Z","views":138127}],"type":"standard","title":"Five_Nights_at_Freddy's_(film)","displaytitle":"<i>Five Nights at Freddy's</i> (film)","namespace":{"id":0,"text":""},"wikibase_item":"Q21512706","titles":{"canonical":"Five_Nights_at_Freddy's_(film)","normalized":"Five Nights at Freddy's (film)","display":"<i>Five Nights at Freddy's</i> (film)"},"pageid":48672356,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/d/d6/Five_Nights_At_Freddy%27s_poster.jpeg","width":247,"height":390},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/d/d6/Five_Nights_At_Freddy%27s_poster.jpeg","width":247,"height":390},"lang":"en","dir":"ltr","revision":"1183291311","tid":"fcaebac0-7a3c-11ee-9b5e-77ccaff57d56","timestamp":"2023-11-03T11:34:42Z","description":"2023 film directed by Emma Tammi","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Five_Nights_at_Freddy's_(film)","revisions":"https://en.wikipedia.org/wiki/Five_Nights_at_Freddy's_(film)?action=history","edit":"https://en.wikipedia.org/wiki/Five_Nights_at_Freddy's_(film)?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Five_Nights_at_Freddy's_(film)"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Five_Nights_at_Freddy's_(film)","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Five_Nights_at_Freddy's_(film)","edit":"https://en.m.wikipedia.org/wiki/Five_Nights_at_Freddy's_(film)?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Five_Nights_at_Freddy's_(film)"}},"extract":"Five Nights at Freddy's is a 2023 American supernatural horror film based on the video game series and franchise of the same name created by Scott Cawthon. Directed by Emma Tammi, who co-wrote the screenplay with Cawthon and Seth Cuddeback, from a story by Cawthon, Chris Lee Hill, and Tyler MacIntyre, the film stars Josh Hutcherson as a troubled security guard who accepts a night-time job at an abandoned family entertainment center, where he discovers its four animatronic mascots come alive and are inclined to commit murder. Elizabeth Lail, Piper Rubio, Mary Stuart Masterson, and Matthew Lillard appear in supporting roles.","extract_html":"<p><i><b>Five Nights at Freddy's</b></i> is a 2023 American supernatural horror film based on the video game series and franchise of the same name created by Scott Cawthon. Directed by Emma Tammi, who co-wrote the screenplay with Cawthon and Seth Cuddeback, from a story by Cawthon, Chris Lee Hill, and Tyler MacIntyre, the film stars Josh Hutcherson as a troubled security guard who accepts a night-time job at an abandoned family entertainment center, where he discovers its four animatronic mascots come alive and are inclined to commit murder. Elizabeth Lail, Piper Rubio, Mary Stuart Masterson, and Matthew Lillard appear in supporting roles.</p>","normalizedtitle":"Five Nights at Freddy's (film)"},{"views":136129,"rank":25,"view_history":[{"date":"2023-10-29Z","views":168799},{"date":"2023-10-30Z","views":139086},{"date":"2023-10-31Z","views":132313},{"date":"2023-11-01Z","views":137466},{"date":"2023-11-02Z","views":136129}],"type":"standard","title":"Deaths_in_2023","displaytitle":"<span class=\"mw-page-title-main\">Deaths in 2023</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q114929139","titles":{"canonical":"Deaths_in_2023","normalized":"Deaths in 2023","display":"<span class=\"mw-page-title-main\">Deaths in 2023</span>"},"pageid":72389466,"lang":"en","dir":"ltr","revision":"1183293016","tid":"b433dc50-7a3f-11ee-b22e-73c03494475b","timestamp":"2023-11-03T11:54:06Z","description":"Notable deaths in 2023","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Deaths_in_2023","revisions":"https://en.wikipedia.org/wiki/Deaths_in_2023?action=history","edit":"https://en.wikipedia.org/wiki/Deaths_in_2023?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Deaths_in_2023"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Deaths_in_2023","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Deaths_in_2023","edit":"https://en.m.wikipedia.org/wiki/Deaths_in_2023?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Deaths_in_2023"}},"extract":"\n\nThe following notable deaths occurred in 2023. Names are reported under the date of death, in alphabetical order. A typical entry reports information in the following sequence:Name, age, country of citizenship at birth, subsequent nationality, what subject was noted for, cause of death, and reference.","extract_html":"<p>\n\nThe following notable deaths occurred in 2023. Names are reported under the date of death, in alphabetical order. A typical entry reports information in the following sequence:</p><ul><li>Name, age, country of citizenship at birth, subsequent nationality, what subject was noted for, cause of death, and reference.</li></ul>","normalizedtitle":"Deaths in 2023"},{"views":127544,"rank":26,"view_history":[{"date":"2023-10-29Z","views":2201},{"date":"2023-10-30Z","views":2071},{"date":"2023-10-31Z","views":1924},{"date":"2023-11-01Z","views":21919},{"date":"2023-11-02Z","views":127544}],"type":"standard","title":"Kingdom_of_the_Planet_of_the_Apes","displaytitle":"<i>Kingdom of the Planet of the Apes</i>","namespace":{"id":0,"text":""},"wikibase_item":"Q114314695","titles":{"canonical":"Kingdom_of_the_Planet_of_the_Apes","normalized":"Kingdom of the Planet of the Apes","display":"<i>Kingdom of the Planet of the Apes</i>"},"pageid":63138261,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/c/cf/Kingdom_of_the_Planet_of_the_Apes_poster.jpg","width":259,"height":384},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/c/cf/Kingdom_of_the_Planet_of_the_Apes_poster.jpg","width":259,"height":384},"lang":"en","dir":"ltr","revision":"1183277727","tid":"3d27ef30-7a25-11ee-b2e2-6d1a3e08c59e","timestamp":"2023-11-03T08:44:42Z","description":"2024 American film by Wes Ball","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Kingdom_of_the_Planet_of_the_Apes","revisions":"https://en.wikipedia.org/wiki/Kingdom_of_the_Planet_of_the_Apes?action=history","edit":"https://en.wikipedia.org/wiki/Kingdom_of_the_Planet_of_the_Apes?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Kingdom_of_the_Planet_of_the_Apes"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Kingdom_of_the_Planet_of_the_Apes","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Kingdom_of_the_Planet_of_the_Apes","edit":"https://en.m.wikipedia.org/wiki/Kingdom_of_the_Planet_of_the_Apes?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Kingdom_of_the_Planet_of_the_Apes"}},"extract":"Kingdom of the Planet of the Apes is an upcoming American science fiction action film directed by Wes Ball from a screenplay by Josh Friedman, Rick Jaffa, Amanda Silver, and Patrick Aison, and produced by Joe Hartwick Jr., Jaffa, Silver, and Jason Reed. It is intended to be the sequel to War for the Planet of the Apes (2017) and the fourth installment in the Planet of the Apes reboot franchise. The film stars Owen Teague in the lead role alongside Freya Allan, Kevin Durand, Peter Macon, and William H. Macy.","extract_html":"<p><i><b>Kingdom of the Planet of the Apes</b></i> is an upcoming American science fiction action film directed by Wes Ball from a screenplay by Josh Friedman, Rick Jaffa, Amanda Silver, and Patrick Aison, and produced by Joe Hartwick Jr., Jaffa, Silver, and Jason Reed. It is intended to be the sequel to <i>War for the Planet of the Apes</i> (2017) and the fourth installment in the <span><i>Planet of the Apes</i> reboot franchise</span>. The film stars Owen Teague in the lead role alongside Freya Allan, Kevin Durand, Peter Macon, and William H. Macy.</p>","normalizedtitle":"Kingdom of the Planet of the Apes"},{"views":122108,"rank":27,"view_history":[{"date":"2023-10-29Z","views":12253},{"date":"2023-10-30Z","views":20875},{"date":"2023-10-31Z","views":67447},{"date":"2023-11-01Z","views":156070},{"date":"2023-11-02Z","views":122108}],"type":"standard","title":"No_Nut_November","displaytitle":"<span class=\"mw-page-title-main\">No Nut November</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q75669158","titles":{"canonical":"No_Nut_November","normalized":"No Nut November","display":"<span class=\"mw-page-title-main\">No Nut November</span>"},"pageid":58962368,"lang":"en","dir":"ltr","revision":"1183178810","tid":"9b1fa090-79a5-11ee-9f37-c16f6c4fbac0","timestamp":"2023-11-02T17:31:06Z","description":"Annual internet challenge of male sexual abstinence during November","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/No_Nut_November","revisions":"https://en.wikipedia.org/wiki/No_Nut_November?action=history","edit":"https://en.wikipedia.org/wiki/No_Nut_November?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:No_Nut_November"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/No_Nut_November","revisions":"https://en.m.wikipedia.org/wiki/Special:History/No_Nut_November","edit":"https://en.m.wikipedia.org/wiki/No_Nut_November?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:No_Nut_November"}},"extract":"\nNo Nut November, often abbreviated to NNN, is an annual internet challenge of sexual abstinence during the month of November. It originated in 2011 and grew in popularity among male users of social media during and after 2017.","extract_html":"<p>\n<b>No Nut November</b>, often abbreviated to <b>NNN</b>, is an annual internet challenge of sexual abstinence during the month of November. It originated in 2011 and grew in popularity among male users of social media during and after 2017.</p>","normalizedtitle":"No Nut November"},{"views":110731,"rank":28,"view_history":[{"date":"2023-10-29Z","views":68797},{"date":"2023-10-30Z","views":43854},{"date":"2023-10-31Z","views":26024},{"date":"2023-11-01Z","views":16394},{"date":"2023-11-02Z","views":110731}],"type":"standard","title":"Mohammed_Shami","displaytitle":"<span class=\"mw-page-title-main\">Mohammed Shami</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q7487531","titles":{"canonical":"Mohammed_Shami","normalized":"Mohammed Shami","display":"<span class=\"mw-page-title-main\">Mohammed Shami</span>"},"pageid":1455839,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/b/bc/Mohammed_Shami_%28cropped%29.jpg","width":308,"height":410},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/b/bc/Mohammed_Shami_%28cropped%29.jpg","width":308,"height":410},"lang":"en","dir":"ltr","revision":"1183283433","tid":"62c87fb0-7a30-11ee-a5bc-ade7611edfb7","timestamp":"2023-11-03T10:04:27Z","description":"Indian cricketer","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Mohammed_Shami","revisions":"https://en.wikipedia.org/wiki/Mohammed_Shami?action=history","edit":"https://en.wikipedia.org/wiki/Mohammed_Shami?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Mohammed_Shami"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Mohammed_Shami","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Mohammed_Shami","edit":"https://en.m.wikipedia.org/wiki/Mohammed_Shami?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Mohammed_Shami"}},"extract":"Mohammed Shami is an Indian international cricketer who plays for the Indian national cricket team in all formats as a right-arm fast bowler. He plays in the Indian Premier League, for Gujarat Titans.","extract_html":"<p><b>Mohammed Shami</b> is an Indian international cricketer who plays for the Indian national cricket team in all formats as a right-arm fast bowler. He plays in the Indian Premier League, for Gujarat Titans.</p>","normalizedtitle":"Mohammed Shami"},{"views":110140,"rank":29,"view_history":[{"date":"2023-10-29Z","views":68574},{"date":"2023-10-30Z","views":38741},{"date":"2023-10-31Z","views":38662},{"date":"2023-11-01Z","views":39169},{"date":"2023-11-02Z","views":110140}],"type":"standard","title":"Virat_Kohli","displaytitle":"<span class=\"mw-page-title-main\">Virat Kohli</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q213854","titles":{"canonical":"Virat_Kohli","normalized":"Virat Kohli","display":"<span class=\"mw-page-title-main\">Virat Kohli</span>"},"pageid":16017429,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/e/ef/Virat_Kohli_during_the_India_vs_Aus_4th_Test_match_at_Narendra_Modi_Stadium_on_09_March_2023.jpg/320px-Virat_Kohli_during_the_India_vs_Aus_4th_Test_match_at_Narendra_Modi_Stadium_on_09_March_2023.jpg","width":320,"height":399},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/e/ef/Virat_Kohli_during_the_India_vs_Aus_4th_Test_match_at_Narendra_Modi_Stadium_on_09_March_2023.jpg","width":524,"height":654},"lang":"en","dir":"ltr","revision":"1183143656","tid":"64b9ff70-7980-11ee-a060-4f3ef8b5556a","timestamp":"2023-11-02T13:04:25Z","description":"Indian cricketer (born 1988)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Virat_Kohli","revisions":"https://en.wikipedia.org/wiki/Virat_Kohli?action=history","edit":"https://en.wikipedia.org/wiki/Virat_Kohli?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Virat_Kohli"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Virat_Kohli","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Virat_Kohli","edit":"https://en.m.wikipedia.org/wiki/Virat_Kohli?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Virat_Kohli"}},"extract":"Virat Kohli is an Indian international cricketer and the former captain of the Indian national cricket team. He currently represents Royal Challengers Bangalore in the IPL and Delhi in domestic cricket. Kohli is widely regarded as one of the greatest batsmen in the history of the sport. In 2020, the International Cricket Council named him the male cricketer of the decade. Kohli has also contributed to India's successes, captaining the team from 2014 to 2022, and winning the 2011 World Cup and the 2013 Champions trophy. He is among the only four Indian cricketers who have played over 500 matches for India. Kohli is the fourth-highest run-scorer in international cricket and stands second in the list of cricketers by number of international centuries scored.","extract_html":"<p><b>Virat Kohli</b> is an Indian international cricketer and the former captain of the Indian national cricket team. He currently represents Royal Challengers Bangalore in the IPL and Delhi in domestic cricket. Kohli is widely regarded as one of the greatest batsmen in the history of the sport. In 2020, the International Cricket Council named him the male cricketer of the decade. Kohli has also contributed to India's successes, captaining the team from 2014 to 2022, and winning the 2011 World Cup and the 2013 Champions trophy. He is among the only four Indian cricketers who have played over 500 matches for India. Kohli is the fourth-highest run-scorer in international cricket and stands second in the list of cricketers by number of international centuries scored.</p>","normalizedtitle":"Virat Kohli"},{"views":109713,"rank":30,"view_history":[{"date":"2023-10-29Z","views":209724},{"date":"2023-10-30Z","views":163655},{"date":"2023-10-31Z","views":120333},{"date":"2023-11-01Z","views":118930},{"date":"2023-11-02Z","views":109713}],"type":"standard","title":"Killers_of_the_Flower_Moon_(film)","displaytitle":"<i>Killers of the Flower Moon</i> (film)","namespace":{"id":0,"text":""},"wikibase_item":"Q66316924","titles":{"canonical":"Killers_of_the_Flower_Moon_(film)","normalized":"Killers of the Flower Moon (film)","display":"<i>Killers of the Flower Moon</i> (film)"},"pageid":53852886,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/8/88/Killers_of_the_Flower_Moon_film_poster.jpg","width":258,"height":387},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/8/88/Killers_of_the_Flower_Moon_film_poster.jpg","width":258,"height":387},"lang":"en","dir":"ltr","revision":"1183222494","tid":"ecc3a0f0-79d6-11ee-b839-e5af855224dc","timestamp":"2023-11-02T23:24:05Z","description":"2023 film by Martin Scorsese","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Killers_of_the_Flower_Moon_(film)","revisions":"https://en.wikipedia.org/wiki/Killers_of_the_Flower_Moon_(film)?action=history","edit":"https://en.wikipedia.org/wiki/Killers_of_the_Flower_Moon_(film)?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Killers_of_the_Flower_Moon_(film)"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Killers_of_the_Flower_Moon_(film)","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Killers_of_the_Flower_Moon_(film)","edit":"https://en.m.wikipedia.org/wiki/Killers_of_the_Flower_Moon_(film)?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Killers_of_the_Flower_Moon_(film)"}},"extract":"Killers of the Flower Moon is a 2023 American epic western crime drama film directed by Martin Scorsese from a screenplay he co-wrote with Eric Roth, based on the 2017 non-fiction book of the same name by David Grann. Set in 1920s Oklahoma, it focuses on a series of murders of Osage members and relations in the Osage Nation after oil was being produced on tribal land. Tribal members had retained mineral rights on their reservation, and whites sought to gain their wealth.","extract_html":"<p><i><b>Killers of the Flower Moon</b></i> is a 2023 American epic western crime drama film directed by Martin Scorsese from a screenplay he co-wrote with Eric Roth, based on the 2017 non-fiction book of the same name by David Grann. Set in 1920s Oklahoma, it focuses on a series of murders of Osage members and relations in the Osage Nation after oil was being produced on tribal land. Tribal members had retained mineral rights on their reservation, and whites sought to gain their wealth.</p>","normalizedtitle":"Killers of the Flower Moon (film)"},{"views":98678,"rank":31,"view_history":[{"date":"2023-10-29Z","views":15725},{"date":"2023-10-30Z","views":15229},{"date":"2023-10-31Z","views":17626},{"date":"2023-11-01Z","views":39895},{"date":"2023-11-02Z","views":98678}],"type":"standard","title":"Shah_Rukh_Khan","displaytitle":"<span class=\"mw-page-title-main\">Shah Rukh Khan</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q9535","titles":{"canonical":"Shah_Rukh_Khan","normalized":"Shah Rukh Khan","display":"<span class=\"mw-page-title-main\">Shah Rukh Khan</span>"},"pageid":352699,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/6/6e/Shah_Rukh_Khan_graces_the_launch_of_the_new_Santro.jpg/320px-Shah_Rukh_Khan_graces_the_launch_of_the_new_Santro.jpg","width":320,"height":459},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/6/6e/Shah_Rukh_Khan_graces_the_launch_of_the_new_Santro.jpg","width":369,"height":529},"lang":"en","dir":"ltr","revision":"1183116965","tid":"da695020-7955-11ee-9e05-edc06f712ade","timestamp":"2023-11-02T08:00:01Z","description":"Indian actor (born 1965)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Shah_Rukh_Khan","revisions":"https://en.wikipedia.org/wiki/Shah_Rukh_Khan?action=history","edit":"https://en.wikipedia.org/wiki/Shah_Rukh_Khan?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Shah_Rukh_Khan"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Shah_Rukh_Khan","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Shah_Rukh_Khan","edit":"https://en.m.wikipedia.org/wiki/Shah_Rukh_Khan?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Shah_Rukh_Khan"}},"extract":"Shah Rukh Khan, also known by the initialism SRK, is an Indian actor and film producer who works in Hindi films. Referred to in the media as the \"Baadshah of Bollywood\" and \"King Khan\", he has appeared in more than 90 films, and earned numerous accolades, including 14 Filmfare Awards. He has been awarded the Padma Shri by the Government of India, as well as the Ordre des Arts et des Lettres and Legion of Honour by the Government of France. Khan has a significant following in Asia and the Indian diaspora worldwide. In terms of audience size and income, several media outlets have described him as one of the most successful film stars in the world. Many of his films thematise Indian national identity and connections with diaspora communities, or gender, racial, social and religious differences and grievances.","extract_html":"<p><b>Shah Rukh Khan</b>, also known by the initialism <b>SRK</b>, is an Indian actor and film producer who works in Hindi films. Referred to in the media as the \"Baadshah of Bollywood\" and \"King Khan\", he has appeared in more than 90 films, and earned numerous accolades, including 14 Filmfare Awards. He has been awarded the Padma Shri by the Government of India, as well as the Ordre des Arts et des Lettres and Legion of Honour by the Government of France. Khan has a significant following in Asia and the Indian diaspora worldwide. In terms of audience size and income, several media outlets have described him as one of the most successful film stars in the world. Many of his films thematise Indian national identity and connections with diaspora communities, or gender, racial, social and religious differences and grievances.</p>","normalizedtitle":"Shah Rukh Khan"},{"views":94897,"rank":32,"view_history":[{"date":"2023-10-29Z","views":228},{"date":"2023-10-30Z","views":159},{"date":"2023-10-31Z","views":104},{"date":"2023-11-01Z","views":729},{"date":"2023-11-02Z","views":94897}],"type":"standard","title":"Carmen_Amaya","displaytitle":"<span class=\"mw-page-title-main\">Carmen Amaya</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q242023","titles":{"canonical":"Carmen_Amaya","normalized":"Carmen Amaya","display":"<span class=\"mw-page-title-main\">Carmen Amaya</span>"},"pageid":174046,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/f/f0/1942_-_Lyric_Theater_-_8_Dec_MC_-_Allentown_PA.jpg/320px-1942_-_Lyric_Theater_-_8_Dec_MC_-_Allentown_PA.jpg","width":320,"height":190},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/f/f0/1942_-_Lyric_Theater_-_8_Dec_MC_-_Allentown_PA.jpg","width":957,"height":569},"lang":"en","dir":"ltr","revision":"1183276897","tid":"7950da50-7a23-11ee-b9cc-6ddd98786fe1","timestamp":"2023-11-03T08:32:04Z","description":"Spanish flamenco dancer and singer (1913–1963)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Carmen_Amaya","revisions":"https://en.wikipedia.org/wiki/Carmen_Amaya?action=history","edit":"https://en.wikipedia.org/wiki/Carmen_Amaya?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Carmen_Amaya"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Carmen_Amaya","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Carmen_Amaya","edit":"https://en.m.wikipedia.org/wiki/Carmen_Amaya?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Carmen_Amaya"}},"extract":"Carmen Amaya Amaya was a Spanish Romani flamenco dancer and singer, born in the Somorrostro district of Barcelona, Catalonia, Spain.","extract_html":"<p><b>Carmen Amaya Amaya</b> was a Spanish Romani flamenco dancer and singer, born in the Somorrostro district of Barcelona, Catalonia, Spain.</p>","normalizedtitle":"Carmen Amaya"},{"views":89450,"rank":33,"view_history":[{"date":"2023-10-29Z","views":189706},{"date":"2023-10-30Z","views":178202},{"date":"2023-10-31Z","views":141882},{"date":"2023-11-01Z","views":119573},{"date":"2023-11-02Z","views":89450}],"type":"standard","title":"Five_Nights_at_Freddy's","displaytitle":"<i>Five Nights at Freddy's</i>","namespace":{"id":0,"text":""},"wikibase_item":"Q19847113","titles":{"canonical":"Five_Nights_at_Freddy's","normalized":"Five Nights at Freddy's","display":"<i>Five Nights at Freddy's</i>"},"pageid":46731550,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/1/1e/Five_Nights_at_Freddy%27s.svg/320px-Five_Nights_at_Freddy%27s.svg.png","width":320,"height":159},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/1/1e/Five_Nights_at_Freddy%27s.svg/1000px-Five_Nights_at_Freddy%27s.svg.png","width":1000,"height":496},"lang":"en","dir":"ltr","revision":"1183203444","tid":"22c14fc0-79c0-11ee-b414-5f17fbf64ecd","timestamp":"2023-11-02T20:40:52Z","description":"Media franchise created by Scott Cawthon","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Five_Nights_at_Freddy's","revisions":"https://en.wikipedia.org/wiki/Five_Nights_at_Freddy's?action=history","edit":"https://en.wikipedia.org/wiki/Five_Nights_at_Freddy's?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Five_Nights_at_Freddy's"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Five_Nights_at_Freddy's","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Five_Nights_at_Freddy's","edit":"https://en.m.wikipedia.org/wiki/Five_Nights_at_Freddy's?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Five_Nights_at_Freddy's"}},"extract":"Five Nights at Freddy's (FNaF) is a video game series and media franchise created by Scott Cawthon. The first video game was released on August 8, 2014, and the resultant series has since gained worldwide popularity.","extract_html":"<p><i><b>Five Nights at Freddy's</b></i> (<i><b>FNaF</b></i>) is a video game series and media franchise created by Scott Cawthon. The first video game was released on August 8, 2014, and the resultant series has since gained worldwide popularity.</p>","normalizedtitle":"Five Nights at Freddy's"},{"views":87510,"rank":34,"view_history":[{"date":"2023-10-29Z","views":33508},{"date":"2023-10-30Z","views":13995},{"date":"2023-10-31Z","views":10091},{"date":"2023-11-01Z","views":11536},{"date":"2023-11-02Z","views":87510}],"type":"standard","title":"Shubman_Gill","displaytitle":"<span class=\"mw-page-title-main\">Shubman Gill</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q28840013","titles":{"canonical":"Shubman_Gill","normalized":"Shubman Gill","display":"<span class=\"mw-page-title-main\">Shubman Gill</span>"},"pageid":53303803,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/2/29/Shubman_Gill.jpg/320px-Shubman_Gill.jpg","width":320,"height":284},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/2/29/Shubman_Gill.jpg","width":1054,"height":935},"lang":"en","dir":"ltr","revision":"1183258237","tid":"52e05c30-7a03-11ee-915e-af2640bf7fea","timestamp":"2023-11-03T04:41:55Z","description":"Indian cricketer (born 1999)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Shubman_Gill","revisions":"https://en.wikipedia.org/wiki/Shubman_Gill?action=history","edit":"https://en.wikipedia.org/wiki/Shubman_Gill?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Shubman_Gill"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Shubman_Gill","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Shubman_Gill","edit":"https://en.m.wikipedia.org/wiki/Shubman_Gill?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Shubman_Gill"}},"extract":"Shubman Gill is an Indian cricketer. Representing Indian cricket team at the international level, he also plays for Gujarat Titans in the Indian Premier League and Punjab in domestic cricket. Gill served as the vice-captain of the Indian Under-19 cricket team in the 2018 Under-19 Cricket World Cup and won Player of the Tournament award. A right-handed opening batsman, Gill holds the record for youngest cricketer to score a double century in One Day International cricket and the highest T20I score by an individual for the Indian team. He also holds the record for the fastest player to score 2000 runs in ODIs.","extract_html":"<p><b>Shubman Gill</b> is an Indian cricketer. Representing Indian cricket team at the international level, he also plays for Gujarat Titans in the Indian Premier League and Punjab in domestic cricket. Gill served as the vice-captain of the Indian Under-19 cricket team in the 2018 Under-19 Cricket World Cup and won Player of the Tournament award. A right-handed opening batsman, Gill holds the record for youngest cricketer to score a double century in One Day International cricket and the highest T20I score by an individual for the Indian team. He also holds the record for the fastest player to score 2000 runs in ODIs.</p>","normalizedtitle":"Shubman Gill"},{"views":86949,"rank":35,"view_history":[{"date":"2023-10-29Z","views":1381},{"date":"2023-10-30Z","views":577},{"date":"2023-10-31Z","views":37498},{"date":"2023-11-01Z","views":303618},{"date":"2023-11-02Z","views":86949}],"type":"standard","title":"Tyler_Christopher_(actor)","displaytitle":"<span class=\"mw-page-title-main\">Tyler Christopher (actor)</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q3546016","titles":{"canonical":"Tyler_Christopher_(actor)","normalized":"Tyler Christopher (actor)","display":"<span class=\"mw-page-title-main\">Tyler Christopher (actor)</span>"},"pageid":889163,"lang":"en","dir":"ltr","revision":"1183240529","tid":"ffa00790-79ea-11ee-8691-e9e56e647f48","timestamp":"2023-11-03T01:47:49Z","description":"American actor (1972–2023)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Tyler_Christopher_(actor)","revisions":"https://en.wikipedia.org/wiki/Tyler_Christopher_(actor)?action=history","edit":"https://en.wikipedia.org/wiki/Tyler_Christopher_(actor)?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Tyler_Christopher_(actor)"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Tyler_Christopher_(actor)","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Tyler_Christopher_(actor)","edit":"https://en.m.wikipedia.org/wiki/Tyler_Christopher_(actor)?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Tyler_Christopher_(actor)"}},"extract":"Tyler Christopher Baker, known professionally as Tyler Christopher, was an American actor. He was best known for his roles as Nikolas Cassadine and Connor Bishop (2004–2005) on the ABC soap opera General Hospital.","extract_html":"<p><b>Tyler Christopher Baker</b>, known professionally as <b>Tyler Christopher</b>, was an American actor. He was best known for his roles as Nikolas Cassadine and Connor Bishop (2004–2005) on the ABC soap opera <i>General Hospital</i>.</p>","normalizedtitle":"Tyler Christopher (actor)"},{"views":85791,"rank":36,"view_history":[{"date":"2023-10-29Z","views":100604},{"date":"2023-10-30Z","views":96788},{"date":"2023-10-31Z","views":93528},{"date":"2023-11-01Z","views":91671},{"date":"2023-11-02Z","views":85791}],"type":"standard","title":"Israel","displaytitle":"<span class=\"mw-page-title-main\">Israel</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q801","titles":{"canonical":"Israel","normalized":"Israel","display":"<span class=\"mw-page-title-main\">Israel</span>"},"pageid":9282173,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/d/d4/Flag_of_Israel.svg/320px-Flag_of_Israel.svg.png","width":320,"height":233},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/d/d4/Flag_of_Israel.svg/1100px-Flag_of_Israel.svg.png","width":1100,"height":800},"lang":"en","dir":"ltr","revision":"1183149126","tid":"ca1f45d0-7991-11ee-b10f-e7966dae1764","timestamp":"2023-11-02T13:46:05Z","description":"Country in West Asia","description_source":"local","coordinates":{"lat":31,"lon":35},"content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Israel","revisions":"https://en.wikipedia.org/wiki/Israel?action=history","edit":"https://en.wikipedia.org/wiki/Israel?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Israel"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Israel","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Israel","edit":"https://en.m.wikipedia.org/wiki/Israel?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Israel"}},"extract":"Israel, officially the State of Israel, is a country in West Asia. It is bordered by Lebanon to the north, by Syria to the northeast, by Jordan to the east, by the Red Sea to the south, by Egypt to the southwest, by the Mediterranean Sea to the west, and by the Palestinian territories – the West Bank along the east and the Gaza Strip along the southwest. Tel Aviv is the financial, economic, and technological center of the country, while its seat of government is in its proclaimed capital of Jerusalem, although Israeli sovereignty over East Jerusalem is unrecognized internationally.","extract_html":"<p><b>Israel</b>, officially the <b>State of Israel</b>, is a country in West Asia. It is bordered by Lebanon to the north, by Syria to the northeast, by Jordan to the east, by the Red Sea to the south, by Egypt to the southwest, by the Mediterranean Sea to the west, and by the Palestinian territories – the West Bank along the east and the Gaza Strip along the southwest. Tel Aviv is the financial, economic, and technological center of the country, while its seat of government is in its proclaimed capital of Jerusalem, although Israeli sovereignty over East Jerusalem is unrecognized internationally.</p>","normalizedtitle":"Israel"},{"views":84697,"rank":37,"view_history":[{"date":"2023-10-29Z","views":106153},{"date":"2023-10-30Z","views":93223},{"date":"2023-10-31Z","views":87008},{"date":"2023-11-01Z","views":91049},{"date":"2023-11-02Z","views":84697}],"type":"standard","title":"State_of_Palestine","displaytitle":"<span class=\"mw-page-title-main\">State of Palestine</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q219060","titles":{"canonical":"State_of_Palestine","normalized":"State of Palestine","display":"<span class=\"mw-page-title-main\">State of Palestine</span>"},"pageid":241405,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/0/00/Flag_of_Palestine.svg/320px-Flag_of_Palestine.svg.png","width":320,"height":160},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/0/00/Flag_of_Palestine.svg/1200px-Flag_of_Palestine.svg.png","width":1200,"height":600},"lang":"en","dir":"ltr","revision":"1183237693","tid":"a08008d0-7a28-11ee-b2f1-d5ae09043456","timestamp":"2023-11-03T01:25:39Z","description":"State in West Asia","description_source":"local","coordinates":{"lat":32,"lon":35.25},"content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/State_of_Palestine","revisions":"https://en.wikipedia.org/wiki/State_of_Palestine?action=history","edit":"https://en.wikipedia.org/wiki/State_of_Palestine?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:State_of_Palestine"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/State_of_Palestine","revisions":"https://en.m.wikipedia.org/wiki/Special:History/State_of_Palestine","edit":"https://en.m.wikipedia.org/wiki/State_of_Palestine?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:State_of_Palestine"}},"extract":"Palestine, officially the State of Palestine, is a state located in the Southern Levant region of West Asia. Officially governed by the Palestine Liberation Organization (PLO), it claims the West Bank and the Gaza Strip as its territory, though the entirety of that territory has been under Israeli occupation since the 1967 Six-Day War. The West Bank is currently divided into 165 Palestinian enclaves that are under partial Palestinian rule, but the remainder, including 200 Israeli settlements, is under full Israeli control. The Gaza Strip is ruled by the militant group Hamas and has been blockaded by Israel and Egypt since 2007.","extract_html":"<p><b>Palestine</b>, officially the <b>State of Palestine</b>, is a state located in the Southern Levant region of West Asia. Officially governed by the Palestine Liberation Organization (PLO), it claims the West Bank and the Gaza Strip as its territory, though the entirety of that territory has been under Israeli occupation since the 1967 Six-Day War. The West Bank is currently divided into 165 Palestinian enclaves that are under partial Palestinian rule, but the remainder, including 200 Israeli settlements, is under full Israeli control. The Gaza Strip is ruled by the militant group Hamas and has been blockaded by Israel and Egypt since 2007.</p>","normalizedtitle":"State of Palestine"},{"views":84088,"rank":38,"view_history":[{"date":"2023-10-29Z","views":15570},{"date":"2023-10-30Z","views":9468},{"date":"2023-10-31Z","views":14601},{"date":"2023-11-01Z","views":27242},{"date":"2023-11-02Z","views":84088}],"type":"standard","title":"List_of_World_Series_champions","displaytitle":"<span class=\"mw-page-title-main\">List of World Series champions</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q862958","titles":{"canonical":"List_of_World_Series_champions","normalized":"List of World Series champions","display":"<span class=\"mw-page-title-main\">List of World Series champions</span>"},"pageid":7599168,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/4/49/1903_World_Series_-_Boston_Americans.jpg/320px-1903_World_Series_-_Boston_Americans.jpg","width":320,"height":177},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/4/49/1903_World_Series_-_Boston_Americans.jpg","width":1069,"height":592},"lang":"en","dir":"ltr","revision":"1183279198","tid":"262fa040-7a28-11ee-b367-4fe5137f5f86","timestamp":"2023-11-03T09:05:31Z","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/List_of_World_Series_champions","revisions":"https://en.wikipedia.org/wiki/List_of_World_Series_champions?action=history","edit":"https://en.wikipedia.org/wiki/List_of_World_Series_champions?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:List_of_World_Series_champions"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/List_of_World_Series_champions","revisions":"https://en.m.wikipedia.org/wiki/Special:History/List_of_World_Series_champions","edit":"https://en.m.wikipedia.org/wiki/List_of_World_Series_champions?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:List_of_World_Series_champions"}},"extract":"The World Series is the annual championship series of Major League Baseball (MLB) and concludes the MLB postseason. First played in 1903, the World Series championship is a best-of-seven playoff and is a contest between the champions of baseball's National League (NL) and American League (AL). Often referred to as the \"Fall Classic\", the modern World Series has been played every year since 1903 with two exceptions: in 1904, when the NL champion New York Giants declined to play the AL champion Boston Americans; and in 1994, when the series was canceled due to the players' strike.The best-of-seven style has been the format of all World Series except in 1903, 1919, 1920, 1921, when the winner was determined through a best-of-nine playoff. Although the large majority of contests have been played entirely during the month of October, a small number of Series have also had games played during September and November. The Series-winning team is awarded the Commissioner's Trophy. Players, coaches and others associated with the team are generally given World Series rings to commemorate their victory; however, they have received other items such as pocket watches and medallions in the past. The winning team is traditionally invited to the White House to meet the President of the United States.","extract_html":"<p>The World Series is the annual championship series of Major League Baseball (MLB) and concludes the MLB postseason. First played in 1903, the World Series championship is a best-of-seven playoff and is a contest between the champions of baseball's National League (NL) and American League (AL). Often referred to as the \"Fall Classic\", the modern World Series has been played every year since 1903 with two exceptions: in 1904, when the NL champion New York Giants declined to play the AL champion Boston Americans; and in 1994, when the series was canceled due to the players' strike.The best-of-seven style has been the format of all World Series except in 1903, 1919, 1920, 1921, when the winner was determined through a best-of-nine playoff. Although the large majority of contests have been played entirely during the month of October, a small number of Series have also had games played during September and November. The Series-winning team is awarded the Commissioner's Trophy. Players, coaches and others associated with the team are generally given World Series rings to commemorate their victory; however, they have received other items such as pocket watches and medallions in the past. The winning team is traditionally invited to the White House to meet the President of the United States.</p>","normalizedtitle":"List of World Series champions"},{"views":84042,"rank":39,"view_history":[{"date":"2023-10-29Z","views":22611},{"date":"2023-10-30Z","views":13966},{"date":"2023-10-31Z","views":18261},{"date":"2023-11-01Z","views":23815},{"date":"2023-11-02Z","views":84042}],"type":"standard","title":"All_the_Light_We_Cannot_See","displaytitle":"<i>All the Light We Cannot See</i>","namespace":{"id":0,"text":""},"wikibase_item":"Q18109559","titles":{"canonical":"All_the_Light_We_Cannot_See","normalized":"All the Light We Cannot See","display":"<i>All the Light We Cannot See</i>"},"pageid":43853567,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/2/22/All_the_Light_We_Cannot_See_%28Doerr_novel%29.jpg","width":260,"height":390},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/2/22/All_the_Light_We_Cannot_See_%28Doerr_novel%29.jpg","width":260,"height":390},"lang":"en","dir":"ltr","revision":"1183251601","tid":"a0496940-79f8-11ee-b5d4-8d37f3f36e2e","timestamp":"2023-11-03T03:25:21Z","description":"2014 novel by Anthony Doerr","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/All_the_Light_We_Cannot_See","revisions":"https://en.wikipedia.org/wiki/All_the_Light_We_Cannot_See?action=history","edit":"https://en.wikipedia.org/wiki/All_the_Light_We_Cannot_See?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:All_the_Light_We_Cannot_See"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/All_the_Light_We_Cannot_See","revisions":"https://en.m.wikipedia.org/wiki/Special:History/All_the_Light_We_Cannot_See","edit":"https://en.m.wikipedia.org/wiki/All_the_Light_We_Cannot_See?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:All_the_Light_We_Cannot_See"}},"extract":"All the Light We Cannot See is a 2014 war novel by American author Anthony Doerr. The novel is set during World War II. It revolves around the characters Marie-Laure LeBlanc, a blind French girl who takes refuge in her uncle's house in Saint-Malo after Paris is invaded by Nazi Germany, and Werner Pfennig, a bright German boy who is accepted into a military school because of his skills in radio technology. The book alternates between paralleling chapters depicting Marie-Laure and Werner, framed with a nonlinear structure. The novel has a lyrical writing style, with critics noting extensive sensory details. The story has ethical themes, portraying the destructive nature of war and Doerr's fascination with science and nature.","extract_html":"<p><i><b>All the Light We Cannot See</b></i> is a 2014 war novel by American author Anthony Doerr. The novel is set during World War II. It revolves around the characters Marie-Laure LeBlanc, a blind French girl who takes refuge in her uncle's house in Saint-Malo after Paris is invaded by Nazi Germany, and Werner Pfennig, a bright German boy who is accepted into a military school because of his skills in radio technology. The book alternates between paralleling chapters depicting Marie-Laure and Werner, framed with a nonlinear structure. The novel has a lyrical writing style, with critics noting extensive sensory details. The story has ethical themes, portraying the destructive nature of war and Doerr's fascination with science and nature.</p>","normalizedtitle":"All the Light We Cannot See"},{"views":82998,"rank":40,"view_history":[{"date":"2023-10-29Z","views":1764},{"date":"2023-10-30Z","views":753},{"date":"2023-10-31Z","views":995},{"date":"2023-11-01Z","views":6339},{"date":"2023-11-02Z","views":82998}],"type":"standard","title":"Nathan_Eovaldi","displaytitle":"<span class=\"mw-page-title-main\">Nathan Eovaldi</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q133391","titles":{"canonical":"Nathan_Eovaldi","normalized":"Nathan Eovaldi","display":"<span class=\"mw-page-title-main\">Nathan Eovaldi</span>"},"pageid":32651444,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/8/8e/Nathan_Eovaldi_2020.png","width":289,"height":300},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/8/8e/Nathan_Eovaldi_2020.png","width":289,"height":300},"lang":"en","dir":"ltr","revision":"1183219128","tid":"19d8ccc0-79ee-11ee-8f86-3d2239efeb9d","timestamp":"2023-11-02T22:52:29Z","description":"American baseball player (born 1990)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Nathan_Eovaldi","revisions":"https://en.wikipedia.org/wiki/Nathan_Eovaldi?action=history","edit":"https://en.wikipedia.org/wiki/Nathan_Eovaldi?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Nathan_Eovaldi"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Nathan_Eovaldi","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Nathan_Eovaldi","edit":"https://en.m.wikipedia.org/wiki/Nathan_Eovaldi?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Nathan_Eovaldi"}},"extract":"Nathan Edward Eovaldi is an American professional baseball pitcher for the Texas Rangers of Major League Baseball (MLB). He has previously played in MLB for the Los Angeles Dodgers, Miami Marlins, New York Yankees, Tampa Bay Rays and Boston Red Sox. Eovaldi made his MLB debut in 2011. He was a World Series champion with the Red Sox in 2018 and the Rangers in 2023 and has been selected as an All-Star in 2021 and 2023.","extract_html":"<p><b>Nathan Edward Eovaldi</b> is an American professional baseball pitcher for the Texas Rangers of Major League Baseball (MLB). He has previously played in MLB for the Los Angeles Dodgers, Miami Marlins, New York Yankees, Tampa Bay Rays and Boston Red Sox. Eovaldi made his MLB debut in 2011. He was a World Series champion with the Red Sox in 2018 and the Rangers in 2023 and has been selected as an All-Star in 2021 and 2023.</p>","normalizedtitle":"Nathan Eovaldi"},{"views":76686,"rank":41,"view_history":[{"date":"2023-10-29Z","views":90937},{"date":"2023-10-30Z","views":89480},{"date":"2023-10-31Z","views":87869},{"date":"2023-11-01Z","views":79630},{"date":"2023-11-02Z","views":76686}],"type":"standard","title":"Hamas","displaytitle":"<span class=\"mw-page-title-main\">Hamas</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q38799","titles":{"canonical":"Hamas","normalized":"Hamas","display":"<span class=\"mw-page-title-main\">Hamas</span>"},"pageid":13913,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/b/b4/Hamas_logo.png","width":301,"height":331},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/b/b4/Hamas_logo.png","width":301,"height":331},"lang":"en","dir":"ltr","revision":"1183278865","tid":"7d7050d0-7a27-11ee-9c8d-4177649bb7c6","timestamp":"2023-11-03T09:00:35Z","description":"Palestinian political and military organization","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Hamas","revisions":"https://en.wikipedia.org/wiki/Hamas?action=history","edit":"https://en.wikipedia.org/wiki/Hamas?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Hamas"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Hamas","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Hamas","edit":"https://en.m.wikipedia.org/wiki/Hamas?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Hamas"}},"extract":"Hamas, an acronym of its official name, the Islamic Resistance Movement, is a Sunni Islamist political and military organization governing the Gaza Strip of the Israeli-occupied Palestinian territories. Headquartered in Gaza City, it also has a presence in the West Bank, in which its secular rival Fatah exercises control. Hamas is widely considered to be the \"dominant political force\" within the Palestinian territories.","extract_html":"<p><b>Hamas</b>, an acronym of its official name, the <b>Islamic Resistance Movement</b>, is a Sunni Islamist political and military organization governing the Gaza Strip of the Israeli-occupied Palestinian territories. Headquartered in Gaza City, it also has a presence in the West Bank, in which its secular rival Fatah exercises control. Hamas is widely considered to be the \"dominant political force\" within the Palestinian territories.</p>","normalizedtitle":"Hamas"},{"views":75252,"rank":42,"view_history":[{"date":"2023-10-29Z","views":13241},{"date":"2023-10-30Z","views":7697},{"date":"2023-10-31Z","views":11259},{"date":"2023-11-01Z","views":16793},{"date":"2023-11-02Z","views":75252}],"type":"standard","title":"2023_World_Series","displaytitle":"<span class=\"mw-page-title-main\">2023 World Series</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q122708808","titles":{"canonical":"2023_World_Series","normalized":"2023 World Series","display":"<span class=\"mw-page-title-main\">2023 World Series</span>"},"pageid":74861818,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/b/bf/2023_World_Series_logo.svg/320px-2023_World_Series_logo.svg.png","width":320,"height":210},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/b/bf/2023_World_Series_logo.svg/365px-2023_World_Series_logo.svg.png","width":365,"height":240},"lang":"en","dir":"ltr","revision":"1183282358","tid":"5ded9680-7a2e-11ee-bccc-8f4d09a42d68","timestamp":"2023-11-03T09:50:00Z","description":"119th edition of Major League Baseball's championship series","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/2023_World_Series","revisions":"https://en.wikipedia.org/wiki/2023_World_Series?action=history","edit":"https://en.wikipedia.org/wiki/2023_World_Series?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:2023_World_Series"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/2023_World_Series","revisions":"https://en.m.wikipedia.org/wiki/Special:History/2023_World_Series","edit":"https://en.m.wikipedia.org/wiki/2023_World_Series?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:2023_World_Series"}},"extract":"The 2023 World Series was the championship series of Major League Baseball's (MLB) 2023 season, and the 119th edition of the World Series. It was a best-of-seven playoff played between the American League (AL) champion Texas Rangers and the National League (NL) champion Arizona Diamondbacks. The series began on October 27, and ended on November 1 with Texas winning in five games. The Rangers won their first World Series title since their founding in 1961.","extract_html":"<p>The <b>2023 World Series</b> was the championship series of Major League Baseball's (MLB) 2023 season, and the 119th edition of the World Series. It was a best-of-seven playoff played between the American League (AL) champion Texas Rangers and the National League (NL) champion Arizona Diamondbacks. The series began on October 27, and ended on November 1 with Texas winning in five games. The Rangers won their first World Series title since their founding in 1961.</p>","normalizedtitle":"2023 World Series"},{"views":71515,"rank":43,"view_history":[{"date":"2023-10-29Z","views":18480},{"date":"2023-10-30Z","views":18317},{"date":"2023-10-31Z","views":77507},{"date":"2023-11-01Z","views":103735},{"date":"2023-11-02Z","views":71515}],"type":"standard","title":"A_Haunting_in_Venice","displaytitle":"<i>A Haunting in Venice</i>","namespace":{"id":0,"text":""},"wikibase_item":"Q114589148","titles":{"canonical":"A_Haunting_in_Venice","normalized":"A Haunting in Venice","display":"<i>A Haunting in Venice</i>"},"pageid":71967969,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/d/d6/A_Haunting_in_Venice_%282023%29_poster.jpg","width":259,"height":384},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/d/d6/A_Haunting_in_Venice_%282023%29_poster.jpg","width":259,"height":384},"lang":"en","dir":"ltr","revision":"1183225399","tid":"38e1b9a0-79db-11ee-b69b-db7251446f1e","timestamp":"2023-11-02T23:54:52Z","description":"2023 film by Kenneth Branagh","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/A_Haunting_in_Venice","revisions":"https://en.wikipedia.org/wiki/A_Haunting_in_Venice?action=history","edit":"https://en.wikipedia.org/wiki/A_Haunting_in_Venice?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:A_Haunting_in_Venice"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/A_Haunting_in_Venice","revisions":"https://en.m.wikipedia.org/wiki/Special:History/A_Haunting_in_Venice","edit":"https://en.m.wikipedia.org/wiki/A_Haunting_in_Venice?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:A_Haunting_in_Venice"}},"extract":"A Haunting in Venice is a 2023 American mystery film produced and directed by Kenneth Branagh from a screenplay by Michael Green, loosely based on the 1969 Agatha Christie novel Hallowe'en Party. It serves as a sequel to Death on the Nile (2022) and is the third film in which Branagh reprises his role as the Belgian detective Hercule Poirot. The ensemble cast includes Kyle Allen, Camille Cottin, Jamie Dornan, Tina Fey, Jude Hill, Ali Khan, Emma Laird, Kelly Reilly, Riccardo Scamarcio, and Michelle Yeoh.","extract_html":"<p><i><b>A Haunting in Venice</b></i> is a 2023 American mystery film produced and directed by Kenneth Branagh from a screenplay by Michael Green, loosely based on the 1969 Agatha Christie novel <i>Hallowe'en Party</i>. It serves as a sequel to <i>Death on the Nile</i> (2022) and is the third film in which Branagh reprises his role as the Belgian detective Hercule Poirot. The ensemble cast includes Kyle Allen, Camille Cottin, Jamie Dornan, Tina Fey, Jude Hill, Ali Khan, Emma Laird, Kelly Reilly, Riccardo Scamarcio, and Michelle Yeoh.</p>","normalizedtitle":"A Haunting in Venice"},{"views":70849,"rank":44,"view_history":[{"date":"2023-10-29Z","views":3171},{"date":"2023-10-30Z","views":826},{"date":"2023-10-31Z","views":8295},{"date":"2023-11-01Z","views":11690},{"date":"2023-11-02Z","views":70849}],"type":"standard","title":"Marcus_Semien","displaytitle":"<span class=\"mw-page-title-main\">Marcus Semien</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q15946610","titles":{"canonical":"Marcus_Semien","normalized":"Marcus Semien","display":"<span class=\"mw-page-title-main\">Marcus Semien</span>"},"pageid":40001136,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/f/fd/Marcus_Semien_on_August_15%2C_2015_%28cropped%29.jpg/320px-Marcus_Semien_on_August_15%2C_2015_%28cropped%29.jpg","width":320,"height":416},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/f/fd/Marcus_Semien_on_August_15%2C_2015_%28cropped%29.jpg","width":2294,"height":2983},"lang":"en","dir":"ltr","revision":"1183143966","tid":"1992c310-79ee-11ee-a7d1-4bc80b4b0eb2","timestamp":"2023-11-02T13:07:29Z","description":"American baseball player (born 1990)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Marcus_Semien","revisions":"https://en.wikipedia.org/wiki/Marcus_Semien?action=history","edit":"https://en.wikipedia.org/wiki/Marcus_Semien?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Marcus_Semien"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Marcus_Semien","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Marcus_Semien","edit":"https://en.m.wikipedia.org/wiki/Marcus_Semien?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Marcus_Semien"}},"extract":"Marcus Andrew Semien is an American professional baseball shortstop and second baseman for the Texas Rangers of Major League Baseball (MLB). He previously played in MLB for the Chicago White Sox, Oakland Athletics and Toronto Blue Jays. Semien was an All-Star in 2021 with the Toronto Blue Jays, when he also won the Gold Glove Award and Silver Slugger Award. Semien won the 2023 World Series with the Texas Rangers over the Arizona Diamondbacks.","extract_html":"<p><b>Marcus Andrew Semien</b> is an American professional baseball shortstop and second baseman for the Texas Rangers of Major League Baseball (MLB). He previously played in MLB for the Chicago White Sox, Oakland Athletics and Toronto Blue Jays. Semien was an All-Star in 2021 with the Toronto Blue Jays, when he also won the Gold Glove Award and Silver Slugger Award. Semien won the 2023 World Series with the Texas Rangers over the Arizona Diamondbacks.</p>","normalizedtitle":"Marcus Semien"},{"views":68685,"rank":45,"view_history":[{"date":"2023-10-29Z","views":1715},{"date":"2023-10-30Z","views":667},{"date":"2023-10-31Z","views":3155},{"date":"2023-11-01Z","views":2523},{"date":"2023-11-02Z","views":68685}],"type":"standard","title":"Chris_Young_(pitcher)","displaytitle":"<span class=\"mw-page-title-main\">Chris Young (pitcher)</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q2964905","titles":{"canonical":"Chris_Young_(pitcher)","normalized":"Chris Young (pitcher)","display":"<span class=\"mw-page-title-main\">Chris Young (pitcher)</span>"},"pageid":5740330,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/d/db/Chris_Young_on_March_11%2C_2016.jpg/320px-Chris_Young_on_March_11%2C_2016.jpg","width":320,"height":521},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/d/db/Chris_Young_on_March_11%2C_2016.jpg","width":1510,"height":2460},"lang":"en","dir":"ltr","revision":"1183109927","tid":"188b7ec0-794a-11ee-83fc-2f8fb65a7dd7","timestamp":"2023-11-02T06:35:55Z","description":"American baseball player (born 1979)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Chris_Young_(pitcher)","revisions":"https://en.wikipedia.org/wiki/Chris_Young_(pitcher)?action=history","edit":"https://en.wikipedia.org/wiki/Chris_Young_(pitcher)?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Chris_Young_(pitcher)"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Chris_Young_(pitcher)","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Chris_Young_(pitcher)","edit":"https://en.m.wikipedia.org/wiki/Chris_Young_(pitcher)?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Chris_Young_(pitcher)"}},"extract":"Christopher Ryan Young is an American former professional baseball pitcher and general manager of the Texas Rangers since 2020. He played in Major League Baseball as a right-handed pitcher from 2000 to 2017 for the Texas Rangers, San Diego Padres, New York Mets, Seattle Mariners and the Kansas City Royals. Young was a 2007 National League (NL) All-Star player as a member of the Padres, and was a member of the 2015 World Series winning Kansas City Royals team. After his playing career, he worked for the Major League Baseball front office before becoming the general manager of the Rangers in 2020.","extract_html":"<p><b>Christopher Ryan Young</b> is an American former professional baseball pitcher and general manager of the Texas Rangers since 2020. He played in Major League Baseball as a right-handed pitcher from 2000 to 2017 for the Texas Rangers, San Diego Padres, New York Mets, Seattle Mariners and the Kansas City Royals. Young was a 2007 National League (NL) All-Star player as a member of the Padres, and was a member of the 2015 World Series winning Kansas City Royals team. After his playing career, he worked for the Major League Baseball front office before becoming the general manager of the Rangers in 2020.</p>","normalizedtitle":"Chris Young (pitcher)"},{"views":66745,"rank":46,"view_history":[{"date":"2023-10-29Z","views":2},{"date":"2023-10-30Z","views":4},{"date":"2023-10-31Z","views":153},{"date":"2023-11-01Z","views":3483},{"date":"2023-11-02Z","views":66745}],"type":"standard","title":"Sony_Computer_Entertainment,_Inc._v._Connectix_Corp.","displaytitle":"<i>Sony Computer Entertainment, Inc. v. Connectix Corp.</i>","namespace":{"id":0,"text":""},"wikibase_item":"Q7562449","titles":{"canonical":"Sony_Computer_Entertainment,_Inc._v._Connectix_Corp.","normalized":"Sony Computer Entertainment, Inc. v. Connectix Corp.","display":"<i>Sony Computer Entertainment, Inc. v. Connectix Corp.</i>"},"pageid":31859078,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/c/cf/Seal_of_the_United_States_Courts%2C_Ninth_Judicial_Circuit.svg/320px-Seal_of_the_United_States_Courts%2C_Ninth_Judicial_Circuit.svg.png","width":320,"height":320},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/c/cf/Seal_of_the_United_States_Courts%2C_Ninth_Judicial_Circuit.svg/512px-Seal_of_the_United_States_Courts%2C_Ninth_Judicial_Circuit.svg.png","width":512,"height":512},"lang":"en","dir":"ltr","revision":"1183233714","tid":"642aaec0-79e3-11ee-9567-4b5d02ed2e2c","timestamp":"2023-11-03T00:53:22Z","description":"Decision by the Ninth Circuit Court of Appeals","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Sony_Computer_Entertainment%2C_Inc._v._Connectix_Corp.","revisions":"https://en.wikipedia.org/wiki/Sony_Computer_Entertainment%2C_Inc._v._Connectix_Corp.?action=history","edit":"https://en.wikipedia.org/wiki/Sony_Computer_Entertainment%2C_Inc._v._Connectix_Corp.?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Sony_Computer_Entertainment%2C_Inc._v._Connectix_Corp."},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Sony_Computer_Entertainment%2C_Inc._v._Connectix_Corp.","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Sony_Computer_Entertainment%2C_Inc._v._Connectix_Corp.","edit":"https://en.m.wikipedia.org/wiki/Sony_Computer_Entertainment%2C_Inc._v._Connectix_Corp.?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Sony_Computer_Entertainment%2C_Inc._v._Connectix_Corp."}},"extract":"Sony Computer Entertainment v. Connectix Corporation, 203 F.3d 596 (2000), is a decision by the Ninth Circuit Court of Appeals which ruled that the copying of a copyrighted BIOS software during the development of an emulator software does not constitute copyright infringement, but is covered by fair use. The court also ruled that Sony's PlayStation trademark had not been tarnished by Connectix Corp.'s sale of its emulator software, the Virtual Game Station.","extract_html":"<p><i><b>Sony Computer Entertainment v. Connectix Corporation</b></i>, 203 F.3d 596 (2000), is a decision by the Ninth Circuit Court of Appeals which ruled that the copying of a copyrighted BIOS software during the development of an emulator software does not constitute copyright infringement, but is covered by fair use. The court also ruled that Sony's PlayStation trademark had not been tarnished by Connectix Corp.'s sale of its emulator software, the Virtual Game Station.</p>","normalizedtitle":"Sony Computer Entertainment, Inc. v. Connectix Corp."},{"views":66250,"rank":47,"view_history":[{"date":"2023-10-29Z","views":100416},{"date":"2023-10-30Z","views":96556},{"date":"2023-10-31Z","views":76862},{"date":"2023-11-01Z","views":69704},{"date":"2023-11-02Z","views":66250}],"type":"standard","title":"David_Beckham","displaytitle":"<span class=\"mw-page-title-main\">David Beckham</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q10520","titles":{"canonical":"David_Beckham","normalized":"David Beckham","display":"<span class=\"mw-page-title-main\">David Beckham</span>"},"pageid":8618,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/9/9e/Beckswimbledon.jpg/320px-Beckswimbledon.jpg","width":320,"height":411},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/9/9e/Beckswimbledon.jpg","width":1548,"height":1988},"lang":"en","dir":"ltr","revision":"1183140108","tid":"7bcf3720-797b-11ee-b648-65a240cc36a6","timestamp":"2023-11-02T12:29:25Z","description":"English footballer (born 1975)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/David_Beckham","revisions":"https://en.wikipedia.org/wiki/David_Beckham?action=history","edit":"https://en.wikipedia.org/wiki/David_Beckham?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:David_Beckham"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/David_Beckham","revisions":"https://en.m.wikipedia.org/wiki/Special:History/David_Beckham","edit":"https://en.m.wikipedia.org/wiki/David_Beckham?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:David_Beckham"}},"extract":"David Robert Joseph Beckham is an English former professional footballer, the current president and co-owner of Inter Miami and co-owner of Salford City. Known for his range of passing, crossing ability, and bending free-kicks as a right winger, Beckham has been hailed as one of the greatest and most recognisable midfielders of his generation, as well as one of the best set-piece specialists of all time. Due to his talent and achievements for both club and country, Beckham is lauded as one of the greatest Manchester United footballers of all time, as well as one of the best English players in the history of the sport. He is the first English player to win league titles in four countries: England, Spain, the United States and France.","extract_html":"<p><b>David Robert Joseph Beckham</b> is an English former professional footballer, the current president and co-owner of Inter Miami and co-owner of Salford City. Known for his range of passing, crossing ability, and bending free-kicks as a right winger, Beckham has been hailed as one of the greatest and most recognisable midfielders of his generation, as well as one of the best set-piece specialists of all time. Due to his talent and achievements for both club and country, Beckham is lauded as one of the greatest Manchester United footballers of all time, as well as one of the best English players in the history of the sport. He is the first English player to win league titles in four countries: England, Spain, the United States and France.</p>","normalizedtitle":"David Beckham"},{"views":65637,"rank":48,"view_history":[{"date":"2023-10-29Z","views":116234},{"date":"2023-10-30Z","views":89824},{"date":"2023-10-31Z","views":72409},{"date":"2023-11-01Z","views":64155},{"date":"2023-11-02Z","views":65637}],"type":"standard","title":"Taylor_Swift","displaytitle":"<span class=\"mw-page-title-main\">Taylor Swift</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q26876","titles":{"canonical":"Taylor_Swift","normalized":"Taylor Swift","display":"<span class=\"mw-page-title-main\">Taylor Swift</span>"},"pageid":5422144,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/b/b1/Taylor_Swift_at_the_2023_MTV_Video_Music_Awards_%283%29.png/320px-Taylor_Swift_at_the_2023_MTV_Video_Music_Awards_%283%29.png","width":320,"height":473},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/b/b1/Taylor_Swift_at_the_2023_MTV_Video_Music_Awards_%283%29.png","width":1703,"height":2516},"lang":"en","dir":"ltr","revision":"1183203397","tid":"1bb0aff0-79c0-11ee-8402-efeeec58af08","timestamp":"2023-11-02T20:40:31Z","description":"American singer-songwriter (born 1989)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Taylor_Swift","revisions":"https://en.wikipedia.org/wiki/Taylor_Swift?action=history","edit":"https://en.wikipedia.org/wiki/Taylor_Swift?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Taylor_Swift"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Taylor_Swift","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Taylor_Swift","edit":"https://en.m.wikipedia.org/wiki/Taylor_Swift?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Taylor_Swift"}},"extract":"Taylor Alison Swift is an American singer-songwriter. Recognized for her songwriting, musical versatility, artistic reinventions, and influence on the music industry, she is a prominent cultural figure of the 21st century.","extract_html":"<p><b>Taylor Alison Swift</b> is an American singer-songwriter. Recognized for her songwriting, musical versatility, artistic reinventions, and influence on the music industry, she is a prominent cultural figure of the 21st century.</p>","normalizedtitle":"Taylor Swift"},{"views":65453,"rank":49,"view_history":[{"date":"2023-10-29Z","views":48028},{"date":"2023-10-30Z","views":65156},{"date":"2023-10-31Z","views":60799},{"date":"2023-11-01Z","views":60800},{"date":"2023-11-02Z","views":65453}],"type":"standard","title":"ChatGPT","displaytitle":"<span class=\"mw-page-title-main\">ChatGPT</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q115564437","titles":{"canonical":"ChatGPT","normalized":"ChatGPT","display":"<span class=\"mw-page-title-main\">ChatGPT</span>"},"pageid":72417803,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/0/04/ChatGPT_logo.svg/320px-ChatGPT_logo.svg.png","width":320,"height":320},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/0/04/ChatGPT_logo.svg/512px-ChatGPT_logo.svg.png","width":512,"height":512},"lang":"en","dir":"ltr","revision":"1183178806","tid":"9d947120-79a5-11ee-aebc-bd5892e20d36","timestamp":"2023-11-02T17:31:02Z","description":"AI chatbot developed by OpenAI","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/ChatGPT","revisions":"https://en.wikipedia.org/wiki/ChatGPT?action=history","edit":"https://en.wikipedia.org/wiki/ChatGPT?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:ChatGPT"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/ChatGPT","revisions":"https://en.m.wikipedia.org/wiki/Special:History/ChatGPT","edit":"https://en.m.wikipedia.org/wiki/ChatGPT?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:ChatGPT"}},"extract":"ChatGPT, which stands for Chat Generative Pre-trained Transformer, is a large language model-based chatbot developed by OpenAI and launched on November 30, 2022, which enables users to refine and steer a conversation towards a desired length, format, style, level of detail, and language. Successive prompts and replies, known as prompt engineering, are considered at each conversation stage as a context.","extract_html":"<p><b>ChatGPT</b>, which stands for <b>Chat Generative Pre-trained Transformer</b>, is a large language model-based chatbot developed by OpenAI and launched on November 30, 2022, which enables users to refine and steer a conversation towards a desired length, format, style, level of detail, and language. Successive prompts and replies, known as prompt engineering, are considered at each conversation stage as a context.</p>","normalizedtitle":"ChatGPT"},{"views":64784,"rank":50,"view_history":[{"date":"2023-10-29Z","views":9618},{"date":"2023-10-30Z","views":9683},{"date":"2023-10-31Z","views":10435},{"date":"2023-11-01Z","views":12717},{"date":"2023-11-02Z","views":64784}],"type":"standard","title":"Dunki_(film)","displaytitle":"<i>Dunki</i> (film)","namespace":{"id":0,"text":""},"wikibase_item":"Q122341144","titles":{"canonical":"Dunki_(film)","normalized":"Dunki (film)","display":"<i>Dunki</i> (film)"},"pageid":74829553,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/4/4f/Dunki_poster.jpg","width":285,"height":350},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/4/4f/Dunki_poster.jpg","width":285,"height":350},"lang":"en","dir":"ltr","revision":"1183266919","tid":"b65c0cf0-7a12-11ee-bd6b-878a8eacf86d","timestamp":"2023-11-03T06:32:06Z","description":"2023 Indian comedy drama film directed by Rajkumar Hirani","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Dunki_(film)","revisions":"https://en.wikipedia.org/wiki/Dunki_(film)?action=history","edit":"https://en.wikipedia.org/wiki/Dunki_(film)?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Dunki_(film)"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Dunki_(film)","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Dunki_(film)","edit":"https://en.m.wikipedia.org/wiki/Dunki_(film)?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Dunki_(film)"}},"extract":"Dunki is an upcoming Indian Hindi-language comedy-drama film based on an illegal immigration technique named, \"Donkey Flight\". It is directed by Rajkumar Hirani, who co-wrote the screenplay with Abhijat Joshi and Kanika Dhillon. Produced under the banner of Red Chillies Entertainment and Jio Studios, it stars Shah Rukh Khan, Taapsee Pannu, Vicky Kaushal, and Boman Irani.","extract_html":"<p><i><b>Dunki</b></i> is an upcoming Indian Hindi-language comedy-drama film based on an illegal immigration technique named, \"Donkey Flight\". It is directed by Rajkumar Hirani, who co-wrote the screenplay with Abhijat Joshi and Kanika Dhillon. Produced under the banner of Red Chillies Entertainment and Jio Studios, it stars Shah Rukh Khan, Taapsee Pannu, Vicky Kaushal, and Boman Irani.</p>","normalizedtitle":"Dunki (film)"}]},"image":{"title":"File:Rosy ermine moth (Trosia nigropunctigera).jpg","thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/1/13/Rosy_ermine_moth_%28Trosia_nigropunctigera%29.jpg/640px-Rosy_ermine_moth_%28Trosia_nigropunctigera%29.jpg","width":640,"height":427},"image":{"source":"https://upload.wikimedia.org/wikipedia/commons/1/13/Rosy_ermine_moth_%28Trosia_nigropunctigera%29.jpg","width":3491,"height":2328},"file_page":"https://commons.wikimedia.org/wiki/File:Rosy_ermine_moth_(Trosia_nigropunctigera).jpg","artist":{"html":"<bdi><a href=\"https://www.wikidata.org/wiki/Q54800218\" class=\"extiw\" title=\"d:Q54800218\"><span title=\"Scottish wildlife photographer\">Charles J. Sharp</span></a>\n</bdi>","text":"Charles J. Sharp"},"credit":{"html":"<span class=\"int-own-work\" lang=\"en\">Own work</span>, from <a rel=\"nofollow\" class=\"external text\" href=\"https://www.sharpphotography.co.uk/\">Sharp Photography, sharpphotography.co.uk</a>","text":"Own work, from Sharp Photography, sharpphotography.co.uk"},"license":{"type":"CC BY-SA 4.0","code":"cc-by-sa-4.0","url":"https://creativecommons.org/licenses/by-sa/4.0"},"description":{"html":"<a rel=\"mw:WikiLink/Interwiki\" href=\"https://en.wikipedia.org/wiki/Rosy%20ermine%20moth\" title=\"en:Rosy ermine moth\" class=\"extiw\">Rosy ermine moth</a> (<i>Trosia nigropunctigera</i>), Mount Totumas <a rel=\"mw:WikiLink/Interwiki\" href=\"https://en.wikipedia.org/wiki/cloud%20forest\" title=\"en:cloud forest\" class=\"extiw\">cloud forest</a>, <a rel=\"mw:WikiLink/Interwiki\" href=\"https://en.wikipedia.org/wiki/Panama\" title=\"en:Panama\" class=\"extiw\">Panama</a>.","text":"Rosy ermine moth (Trosia nigropunctigera), Mount Totumas cloud forest, Panama.","lang":"en"},"wb_entity_id":"M80249419","structured":{"captions":{"en":"Rosy ermine moth (Trosia nigropunctigera)","bn":"রোজি এরমাইন মথ (ট্রোসিয়া নিগ্রোপাঙ্কটিগেরা), মাউন্ট টোটুমাস ক্লাউড ফরেস্ট, পানামা"}}},"news":[{"links":[{"type":"standard","title":"2023_World_Series","displaytitle":"<span class=\"mw-page-title-main\">2023 World Series</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q122708808","titles":{"canonical":"2023_World_Series","normalized":"2023 World Series","display":"<span class=\"mw-page-title-main\">2023 World Series</span>"},"pageid":74861818,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/b/bf/2023_World_Series_logo.svg/320px-2023_World_Series_logo.svg.png","width":320,"height":210},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/b/bf/2023_World_Series_logo.svg/365px-2023_World_Series_logo.svg.png","width":365,"height":240},"lang":"en","dir":"ltr","revision":"1183282358","tid":"5ded9680-7a2e-11ee-bccc-8f4d09a42d68","timestamp":"2023-11-03T09:50:00Z","description":"119th edition of Major League Baseball's championship series","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/2023_World_Series","revisions":"https://en.wikipedia.org/wiki/2023_World_Series?action=history","edit":"https://en.wikipedia.org/wiki/2023_World_Series?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:2023_World_Series"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/2023_World_Series","revisions":"https://en.m.wikipedia.org/wiki/Special:History/2023_World_Series","edit":"https://en.m.wikipedia.org/wiki/2023_World_Series?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:2023_World_Series"}},"extract":"The 2023 World Series was the championship series of Major League Baseball's (MLB) 2023 season, and the 119th edition of the World Series. It was a best-of-seven playoff played between the American League (AL) champion Texas Rangers and the National League (NL) champion Arizona Diamondbacks. The series began on October 27, and ended on November 1 with Texas winning in five games. The Rangers won their first World Series title since their founding in 1961.","extract_html":"<p>The <b>2023 World Series</b> was the championship series of Major League Baseball's (MLB) 2023 season, and the 119th edition of the World Series. It was a best-of-seven playoff played between the American League (AL) champion Texas Rangers and the National League (NL) champion Arizona Diamondbacks. The series began on October 27, and ended on November 1 with Texas winning in five games. The Rangers won their first World Series title since their founding in 1961.</p>","normalizedtitle":"2023 World Series"},{"type":"standard","title":"Texas_Rangers_(baseball)","displaytitle":"<span class=\"mw-page-title-main\">Texas Rangers (baseball)</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q329816","titles":{"canonical":"Texas_Rangers_(baseball)","normalized":"Texas Rangers (baseball)","display":"<span class=\"mw-page-title-main\">Texas Rangers (baseball)</span>"},"pageid":30857,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/4/41/Texas_Rangers.svg/320px-Texas_Rangers.svg.png","width":320,"height":320},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/4/41/Texas_Rangers.svg/200px-Texas_Rangers.svg.png","width":200,"height":200},"lang":"en","dir":"ltr","revision":"1183289802","tid":"a8960580-7a3a-11ee-8c87-47bb05da06b5","timestamp":"2023-11-03T11:18:00Z","description":"Major League Baseball franchise","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Texas_Rangers_(baseball)","revisions":"https://en.wikipedia.org/wiki/Texas_Rangers_(baseball)?action=history","edit":"https://en.wikipedia.org/wiki/Texas_Rangers_(baseball)?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Texas_Rangers_(baseball)"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Texas_Rangers_(baseball)","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Texas_Rangers_(baseball)","edit":"https://en.m.wikipedia.org/wiki/Texas_Rangers_(baseball)?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Texas_Rangers_(baseball)"}},"extract":"The Texas Rangers are an American professional baseball team based in Arlington, Texas. The Rangers compete in Major League Baseball (MLB) as a member club of the American League (AL) West division. In 2020, the Rangers moved to the new Globe Life Field in Arlington after having played at Globe Life Park from 1994 to 2019. The team's name derives from a historic law enforcement agency.","extract_html":"<p>The <b>Texas Rangers</b> are an American professional baseball team based in Arlington, Texas. The Rangers compete in Major League Baseball (MLB) as a member club of the American League (AL) West division. In 2020, the Rangers moved to the new Globe Life Field in Arlington after having played at Globe Life Park from 1994 to 2019. The team's name derives from a historic law enforcement agency.</p>","normalizedtitle":"Texas Rangers (baseball)"},{"type":"standard","title":"Arizona_Diamondbacks","displaytitle":"<span class=\"mw-page-title-main\">Arizona Diamondbacks</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q670376","titles":{"canonical":"Arizona_Diamondbacks","normalized":"Arizona Diamondbacks","display":"<span class=\"mw-page-title-main\">Arizona Diamondbacks</span>"},"pageid":2129,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/8/89/Arizona_Diamondbacks_logo.svg/320px-Arizona_Diamondbacks_logo.svg.png","width":320,"height":275},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/8/89/Arizona_Diamondbacks_logo.svg/270px-Arizona_Diamondbacks_logo.svg.png","width":270,"height":232},"lang":"en","dir":"ltr","revision":"1183246178","tid":"43a72210-79f1-11ee-bedf-a36a99a9dc1f","timestamp":"2023-11-03T02:32:37Z","description":"Major League Baseball franchise in Phoenix, Arizona","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Arizona_Diamondbacks","revisions":"https://en.wikipedia.org/wiki/Arizona_Diamondbacks?action=history","edit":"https://en.wikipedia.org/wiki/Arizona_Diamondbacks?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Arizona_Diamondbacks"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Arizona_Diamondbacks","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Arizona_Diamondbacks","edit":"https://en.m.wikipedia.org/wiki/Arizona_Diamondbacks?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Arizona_Diamondbacks"}},"extract":"The Arizona Diamondbacks are an American professional baseball team based in Phoenix, Arizona. The Diamondbacks compete in Major League Baseball (MLB) as a member of the National League (NL) West division. The franchise was established on March 9, 1995, and began play in 1998 as an expansion team. The team plays its home games at Chase Field. Along with the Tampa Bay Rays, the Diamondbacks are one of the newest teams in MLB and are the youngest team to win the World Series.","extract_html":"<p>The <b>Arizona Diamondbacks</b> are an American professional baseball team based in Phoenix, Arizona. The Diamondbacks compete in Major League Baseball (MLB) as a member of the National League (NL) West division. The franchise was established on March 9, 1995, and began play in 1998 as an expansion team. The team plays its home games at Chase Field. Along with the Tampa Bay Rays, the Diamondbacks are one of the newest teams in MLB and are the youngest team to win the World Series.</p>","normalizedtitle":"Arizona Diamondbacks"},{"type":"standard","title":"World_Series_Most_Valuable_Player_Award","displaytitle":"<span class=\"mw-page-title-main\">World Series Most Valuable Player Award</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q1372040","titles":{"canonical":"World_Series_Most_Valuable_Player_Award","normalized":"World Series Most Valuable Player Award","display":"<span class=\"mw-page-title-main\">World Series Most Valuable Player Award</span>"},"pageid":1732246,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/b/bd/Johnny_Podres_-_Los_Angeles_Dodgers_-_1961.jpg/320px-Johnny_Podres_-_Los_Angeles_Dodgers_-_1961.jpg","width":320,"height":394},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/b/bd/Johnny_Podres_-_Los_Angeles_Dodgers_-_1961.jpg","width":365,"height":449},"lang":"en","dir":"ltr","revision":"1183187342","tid":"ac29b930-79ae-11ee-a3d0-cb619448d321","timestamp":"2023-11-02T18:35:55Z","description":"Major League Baseball award","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/World_Series_Most_Valuable_Player_Award","revisions":"https://en.wikipedia.org/wiki/World_Series_Most_Valuable_Player_Award?action=history","edit":"https://en.wikipedia.org/wiki/World_Series_Most_Valuable_Player_Award?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:World_Series_Most_Valuable_Player_Award"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/World_Series_Most_Valuable_Player_Award","revisions":"https://en.m.wikipedia.org/wiki/Special:History/World_Series_Most_Valuable_Player_Award","edit":"https://en.m.wikipedia.org/wiki/World_Series_Most_Valuable_Player_Award?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:World_Series_Most_Valuable_Player_Award"}},"extract":"The Willie Mays World Series Most Valuable Player (MVP) Award is given to the Major League Baseball (MLB) player deemed to have the most impact on his team's performance in the World Series, which is the final round of the MLB postseason. The award was first presented in 1955 as the SPORT Magazine Award, but is now decided during the final game of the Series by a committee of reporters and officials present at the game.","extract_html":"<p>The <b>Willie Mays World Series Most Valuable Player (MVP) Award</b> is given to the Major League Baseball (MLB) player deemed to have the most impact on his team's performance in the World Series, which is the final round of the MLB postseason. The award was first presented in 1955 as the <span><i>SPORT</i> Magazine</span> Award, but is now decided during the final game of the Series by a committee of reporters and officials present at the game.</p>","normalizedtitle":"World Series Most Valuable Player Award"},{"type":"standard","title":"Corey_Seager","displaytitle":"<span class=\"mw-page-title-main\">Corey Seager</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q17403431","titles":{"canonical":"Corey_Seager","normalized":"Corey Seager","display":"<span class=\"mw-page-title-main\">Corey Seager</span>"},"pageid":36297060,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/0/0f/Corey_Seager_answers_a_question_during_the_T-Mobile_-HRDerby_press_conference._%2828215398950%29.jpg/320px-Corey_Seager_answers_a_question_during_the_T-Mobile_-HRDerby_press_conference._%2828215398950%29.jpg","width":320,"height":213},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/0/0f/Corey_Seager_answers_a_question_during_the_T-Mobile_-HRDerby_press_conference._%2828215398950%29.jpg","width":5472,"height":3648},"lang":"en","dir":"ltr","revision":"1183288675","tid":"c6d10b50-7a38-11ee-ac7e-9d9f8364129c","timestamp":"2023-11-03T11:04:32Z","description":"American baseball player (born 1994)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Corey_Seager","revisions":"https://en.wikipedia.org/wiki/Corey_Seager?action=history","edit":"https://en.wikipedia.org/wiki/Corey_Seager?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Corey_Seager"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Corey_Seager","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Corey_Seager","edit":"https://en.m.wikipedia.org/wiki/Corey_Seager?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Corey_Seager"}},"extract":"Corey Drew Seager is an American professional baseball shortstop for the Texas Rangers of Major League Baseball (MLB). He previously played in MLB for the Los Angeles Dodgers.","extract_html":"<p><b>Corey Drew Seager</b> is an American professional baseball shortstop for the Texas Rangers of Major League Baseball (MLB). He previously played in MLB for the Los Angeles Dodgers.</p>","normalizedtitle":"Corey Seager"}],"story":"<!--Nov 01-->In baseball, the <a rel=\"mw:WikiLink\" href=\"./Texas_Rangers_(baseball)\" title=\"Texas Rangers (baseball)\" id=\"mwBg\">Texas Rangers</a> defeat the <a rel=\"mw:WikiLink\" href=\"./Arizona_Diamondbacks\" title=\"Arizona Diamondbacks\" id=\"mwBw\">Arizona Diamondbacks</a> to win <b id=\"mwCA\"><a rel=\"mw:WikiLink\" href=\"./2023_World_Series\" title=\"2023 World Series\" id=\"mwCQ\">the World Series</a></b> (<i id=\"mwCg\"><a rel=\"mw:WikiLink\" href=\"./World_Series_Most_Valuable_Player_Award\" title=\"World Series Most Valuable Player Award\" id=\"mwCw\">MVP</a> <a rel=\"mw:WikiLink\" href=\"./Corey_Seager\" title=\"Corey Seager\" id=\"mwDA\">Corey Seager</a> pictured)</i>."},{"links":[{"type":"standard","title":"2023_World_Rally_Championship","displaytitle":"<span class=\"mw-page-title-main\">2023 World Rally Championship</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q115434312","titles":{"canonical":"2023_World_Rally_Championship","normalized":"2023 World Rally Championship","display":"<span class=\"mw-page-title-main\">2023 World Rally Championship</span>"},"pageid":71607494,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/e/e9/Kalle_Rovanper%C3%A4_Interview.jpg/320px-Kalle_Rovanper%C3%A4_Interview.jpg","width":320,"height":219},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/e/e9/Kalle_Rovanper%C3%A4_Interview.jpg","width":1258,"height":861},"lang":"en","dir":"ltr","revision":"1183135187","tid":"ae6adbf0-7974-11ee-b10f-e7966dae1764","timestamp":"2023-11-02T11:40:48Z","description":"51st running of the World Rally Championship","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/2023_World_Rally_Championship","revisions":"https://en.wikipedia.org/wiki/2023_World_Rally_Championship?action=history","edit":"https://en.wikipedia.org/wiki/2023_World_Rally_Championship?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:2023_World_Rally_Championship"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/2023_World_Rally_Championship","revisions":"https://en.m.wikipedia.org/wiki/Special:History/2023_World_Rally_Championship","edit":"https://en.m.wikipedia.org/wiki/2023_World_Rally_Championship?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:2023_World_Rally_Championship"}},"extract":"The 2023 FIA World Rally Championship is the fifty-first season of the World Rally Championship, a motorsport competition organised by the Fédération Internationale de l'Automobile (FIA) as the highest class of international rallying. Teams and crews compete for the World Rally Championships for Drivers, Co-drivers and Manufacturers. Crews are free to compete in cars complying with Groups Rally1 to Rally5 regulations; however, only manufacturers competing with Rally1 cars homologated are eligible to score points in the manufacturers' championship. The championship began in January 2023 with the Monte Carlo Rally and is set to conclude in November 2023 with the Rally Japan. The series is supported by the World Rally Championship-2 and World Rally Championship-3 categories at every round of the championship and by the Junior World Rally Championship at selected events.","extract_html":"<p>The <b>2023 FIA World Rally Championship</b> is the fifty-first season of the World Rally Championship, a motorsport competition organised by the Fédération Internationale de l'Automobile (FIA) as the highest class of international rallying. Teams and crews compete for the World Rally Championships for Drivers, Co-drivers and Manufacturers. Crews are free to compete in cars complying with Groups Rally1 to Rally5 regulations; however, only manufacturers competing with Rally1 cars homologated are eligible to score points in the manufacturers' championship. The championship began in January 2023 with the Monte Carlo Rally and is set to conclude in November 2023 with the Rally Japan. The series is supported by the World Rally Championship-2 and World Rally Championship-3 categories at every round of the championship and by the Junior World Rally Championship at selected events.</p>","normalizedtitle":"2023 World Rally Championship"},{"type":"standard","title":"Motorsport","displaytitle":"<span class=\"mw-page-title-main\">Motorsport</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q5367","titles":{"canonical":"Motorsport","normalized":"Motorsport","display":"<span class=\"mw-page-title-main\">Motorsport</span>"},"pageid":293861,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/e/e3/United-autosports-le-mans-race-010.jpg/320px-United-autosports-le-mans-race-010.jpg","width":320,"height":213},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/e/e3/United-autosports-le-mans-race-010.jpg","width":3600,"height":2400},"lang":"en","dir":"ltr","revision":"1183272120","tid":"9384db00-7a1a-11ee-a4f8-4b9cb53f3721","timestamp":"2023-11-03T07:28:22Z","description":"Sport primarily involving the use of motorised vehicles","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Motorsport","revisions":"https://en.wikipedia.org/wiki/Motorsport?action=history","edit":"https://en.wikipedia.org/wiki/Motorsport?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Motorsport"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Motorsport","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Motorsport","edit":"https://en.m.wikipedia.org/wiki/Motorsport?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Motorsport"}},"extract":"Motorsport(s) or motor sport(s) are sporting events, competitions and other activities that primarily involve the use of automobiles. Historically, these terms have encompassed sporting use of other vehicles with a motor, including motorcycles, motorboats and powered aircraft. Today, more specific terms are for these sports, such as motorcycle sport, motorboat racing and air racing.","extract_html":"<p><b>Motorsport(s)</b> or <b>motor sport(s)</b> are sporting events, competitions and other activities that primarily involve the use of automobiles. Historically, these terms have encompassed sporting use of other vehicles with a motor, including motorcycles, motorboats and powered aircraft. Today, more specific terms are for these sports, such as motorcycle sport, motorboat racing and air racing.</p>","normalizedtitle":"Motorsport"},{"type":"standard","title":"Kalle_Rovanperä","displaytitle":"<span class=\"mw-page-title-main\">Kalle Rovanperä</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q20914862","titles":{"canonical":"Kalle_Rovanperä","normalized":"Kalle Rovanperä","display":"<span class=\"mw-page-title-main\">Kalle Rovanperä</span>"},"pageid":55634334,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/3/30/Kalle_Rovanper%C3%A4_Interview_%28cropped%29.jpg/320px-Kalle_Rovanper%C3%A4_Interview_%28cropped%29.jpg","width":320,"height":427},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/3/30/Kalle_Rovanper%C3%A4_Interview_%28cropped%29.jpg","width":646,"height":861},"lang":"en","dir":"ltr","revision":"1183120709","tid":"11ea3d60-795c-11ee-b6a7-112d7adde16e","timestamp":"2023-11-02T08:44:39Z","description":"Finnish rally driver (born 2000)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Kalle_Rovanper%C3%A4","revisions":"https://en.wikipedia.org/wiki/Kalle_Rovanper%C3%A4?action=history","edit":"https://en.wikipedia.org/wiki/Kalle_Rovanper%C3%A4?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Kalle_Rovanper%C3%A4"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Kalle_Rovanper%C3%A4","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Kalle_Rovanper%C3%A4","edit":"https://en.m.wikipedia.org/wiki/Kalle_Rovanper%C3%A4?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Kalle_Rovanper%C3%A4"}},"extract":"Kalle Rovanperä is a Finnish professional rally driver who competes in the World Rally Championship (WRC) for Toyota Gazoo Racing WRT, alongside co-driver Jonne Halttunen. He is the double reigning World Champion. As the son of former WRC driver Harri Rovanperä, he garnered international attention by starting rallying at an exceptionally young age.","extract_html":"<p><b>Kalle Rovanperä</b> is a Finnish professional rally driver who competes in the World Rally Championship (WRC) for Toyota Gazoo Racing WRT, alongside co-driver Jonne Halttunen. He is the double reigning World Champion. As the son of former WRC driver Harri Rovanperä, he garnered international attention by starting rallying at an exceptionally young age.</p>","normalizedtitle":"Kalle Rovanperä"},{"type":"standard","title":"Jonne_Halttunen","displaytitle":"<span class=\"mw-page-title-main\">Jonne Halttunen</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q64409984","titles":{"canonical":"Jonne_Halttunen","normalized":"Jonne Halttunen","display":"<span class=\"mw-page-title-main\">Jonne Halttunen</span>"},"pageid":60959839,"lang":"en","dir":"ltr","revision":"1182843249","tid":"45008990-781a-11ee-b509-3bd3619fa61a","timestamp":"2023-10-31T18:21:08Z","description":"Finnish rally co-driver","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Jonne_Halttunen","revisions":"https://en.wikipedia.org/wiki/Jonne_Halttunen?action=history","edit":"https://en.wikipedia.org/wiki/Jonne_Halttunen?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Jonne_Halttunen"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Jonne_Halttunen","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Jonne_Halttunen","edit":"https://en.m.wikipedia.org/wiki/Jonne_Halttunen?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Jonne_Halttunen"}},"extract":"Jonne Halttunen is a Finnish rally co-driver. Currently, he is the co-driver of Kalle Rovanperä, driving the Toyota GR Yaris Rally1. Previously, they represented Škoda Motorsport to participate in the World Rally Championship-2 Pro category.","extract_html":"<p><b>Jonne Halttunen</b> is a Finnish rally co-driver. Currently, he is the co-driver of Kalle Rovanperä, driving the Toyota GR Yaris Rally1. Previously, they represented Škoda Motorsport to participate in the World Rally Championship-2 Pro category.</p>","normalizedtitle":"Jonne Halttunen"}],"story":"<!--Oct 29-->In <a rel=\"mw:WikiLink\" href=\"./Motorsport\" title=\"Motorsport\" id=\"mwDg\">motorsport</a>, <a rel=\"mw:WikiLink\" href=\"./Kalle_Rovanperä\" title=\"Kalle Rovanperä\" id=\"mwDw\">Kalle Rovanperä</a> and <a rel=\"mw:WikiLink\" href=\"./Jonne_Halttunen\" title=\"Jonne Halttunen\" id=\"mwEA\">Jonne Halttunen</a> win <b id=\"mwEQ\"><a rel=\"mw:WikiLink\" href=\"./2023_World_Rally_Championship\" title=\"2023 World Rally Championship\" id=\"mwEg\">the World Rally Championship</a></b>."},{"links":[{"type":"standard","title":"2023_Rugby_World_Cup_final","displaytitle":"<span class=\"mw-page-title-main\">2023 Rugby World Cup final</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q98855455","titles":{"canonical":"2023_Rugby_World_Cup_final","normalized":"2023 Rugby World Cup final","display":"<span class=\"mw-page-title-main\">2023 Rugby World Cup final</span>"},"pageid":73245711,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/8/88/South_Africa_RWC2023_Celebration.jpg/320px-South_Africa_RWC2023_Celebration.jpg","width":320,"height":180},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/8/88/South_Africa_RWC2023_Celebration.jpg","width":1600,"height":900},"lang":"en","dir":"ltr","revision":"1183266062","tid":"0efcc1b0-7a1d-11ee-82c2-e1f431fca5de","timestamp":"2023-11-03T06:21:47Z","description":"Final 2023 Rugby World Cup match won by South Africa","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/2023_Rugby_World_Cup_final","revisions":"https://en.wikipedia.org/wiki/2023_Rugby_World_Cup_final?action=history","edit":"https://en.wikipedia.org/wiki/2023_Rugby_World_Cup_final?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:2023_Rugby_World_Cup_final"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/2023_Rugby_World_Cup_final","revisions":"https://en.m.wikipedia.org/wiki/Special:History/2023_Rugby_World_Cup_final","edit":"https://en.m.wikipedia.org/wiki/2023_Rugby_World_Cup_final?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:2023_Rugby_World_Cup_final"}},"extract":"The 2023 Rugby World Cup final was a rugby union match played on 28 October 2023 at the Stade de France in Saint-Denis, France. It marked the culmination of the 2023 Rugby World Cup and was played between New Zealand and South Africa, with the latter winning by a single point to claim their fourth Webb Ellis Cup, becoming the first nation to do so.","extract_html":"<p>The <b>2023 Rugby World Cup final</b> was a rugby union match played on 28 October 2023 at the Stade de France in Saint-Denis, France. It marked the culmination of the 2023 Rugby World Cup and was played between New Zealand and South Africa, with the latter winning by a single point to claim their fourth Webb Ellis Cup, becoming the first nation to do so.</p>","normalizedtitle":"2023 Rugby World Cup final"},{"type":"standard","title":"Rugby_union","displaytitle":"<span class=\"mw-page-title-main\">Rugby union</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q5849","titles":{"canonical":"Rugby_union","normalized":"Rugby union","display":"<span class=\"mw-page-title-main\">Rugby union</span>"},"pageid":25405,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/b/b7/New_Zealand_vs_South_Africa_2006_Tri_Nations_Line_Out.JPG/320px-New_Zealand_vs_South_Africa_2006_Tri_Nations_Line_Out.JPG","width":320,"height":213},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/b/b7/New_Zealand_vs_South_Africa_2006_Tri_Nations_Line_Out.JPG","width":3008,"height":2000},"lang":"en","dir":"ltr","revision":"1183265267","tid":"e04d1430-7a0f-11ee-9735-c31662d5972c","timestamp":"2023-11-03T06:11:40Z","description":"Team sport, code of rugby football","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Rugby_union","revisions":"https://en.wikipedia.org/wiki/Rugby_union?action=history","edit":"https://en.wikipedia.org/wiki/Rugby_union?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Rugby_union"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Rugby_union","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Rugby_union","edit":"https://en.m.wikipedia.org/wiki/Rugby_union?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Rugby_union"}},"extract":"Rugby union football, commonly known simply as rugby union or more often just rugby, is a close-contact team sport that originated at Rugby School in the first half of the 19th century. Rugby is simply based on running with the ball in hand. In its most common form, a game is played between two teams of 15 players each, using an oval-shaped ball on a rectangular field called a pitch. The field has H-shaped goalposts at both ends.","extract_html":"<p><b>Rugby union football</b>, commonly known simply as <b>rugby union</b> or more often just <b>rugby</b>, is a close-contact team sport that originated at Rugby School in the first half of the 19th century. Rugby is simply based on running with the ball in hand. In its most common form, a game is played between two teams of 15 players each, using an oval-shaped ball on a rectangular field called a pitch. The field has H-shaped goalposts at both ends.</p>","normalizedtitle":"Rugby union"},{"type":"standard","title":"South_Africa_national_rugby_union_team","displaytitle":"<span class=\"mw-page-title-main\">South Africa national rugby union team</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q498478","titles":{"canonical":"South_Africa_national_rugby_union_team","normalized":"South Africa national rugby union team","display":"<span class=\"mw-page-title-main\">South Africa national rugby union team</span>"},"pageid":376115,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/8/83/South_Africa_national_rugby_union_team.svg/320px-South_Africa_national_rugby_union_team.svg.png","width":320,"height":273},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/8/83/South_Africa_national_rugby_union_team.svg/240px-South_Africa_national_rugby_union_team.svg.png","width":240,"height":205},"lang":"en","dir":"ltr","revision":"1183282013","tid":"b0297cd0-7a2d-11ee-b863-e5abd9f08761","timestamp":"2023-11-03T09:45:05Z","description":"National sports team","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/South_Africa_national_rugby_union_team","revisions":"https://en.wikipedia.org/wiki/South_Africa_national_rugby_union_team?action=history","edit":"https://en.wikipedia.org/wiki/South_Africa_national_rugby_union_team?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:South_Africa_national_rugby_union_team"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/South_Africa_national_rugby_union_team","revisions":"https://en.m.wikipedia.org/wiki/Special:History/South_Africa_national_rugby_union_team","edit":"https://en.m.wikipedia.org/wiki/South_Africa_national_rugby_union_team?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:South_Africa_national_rugby_union_team"}},"extract":"The South Africa national rugby union team, commonly known as the Springboks, is the country's national team governed by the South African Rugby Union. The Springboks play in green and gold jerseys with white shorts. Their emblem is a native antelope, the Springbok, which is the national animal of South Africa. The team has been representing South African Rugby Union in international rugby union since 30 July 1891, when they played their first test match against a British Isles touring team. They are currently the number one ranked rugby team in the world and the reigning World Champions, having won the World Cup on a record four occasions. They are also the second nation to win the World Cup consecutively.","extract_html":"<p>The <b>South Africa national rugby union team</b>, commonly known as the <b>Springboks</b>, is the country's national team governed by the South African Rugby Union. The Springboks play in green and gold jerseys with white shorts. Their emblem is a native antelope, the Springbok, which is the national animal of South Africa. The team has been representing South African Rugby Union in international rugby union since 30 July 1891, when they played their first test match against a British Isles touring team. They are currently the number one ranked rugby team in the world and the reigning World Champions, having won the World Cup on a record four occasions. They are also the second nation to win the World Cup consecutively.</p>","normalizedtitle":"South Africa national rugby union team"},{"type":"standard","title":"New_Zealand_national_rugby_union_team","displaytitle":"<span class=\"mw-page-title-main\">New Zealand national rugby union team</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q55801","titles":{"canonical":"New_Zealand_national_rugby_union_team","normalized":"New Zealand national rugby union team","display":"<span class=\"mw-page-title-main\">New Zealand national rugby union team</span>"},"pageid":154957,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/f/fb/All_Blacks_logo.svg/320px-All_Blacks_logo.svg.png","width":320,"height":237},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/f/fb/All_Blacks_logo.svg/368px-All_Blacks_logo.svg.png","width":368,"height":272},"lang":"en","dir":"ltr","revision":"1182877320","tid":"14d1ea20-7842-11ee-992c-b74ca0394ef2","timestamp":"2023-10-31T23:05:56Z","description":"Men's rugby union team of New Zealand","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/New_Zealand_national_rugby_union_team","revisions":"https://en.wikipedia.org/wiki/New_Zealand_national_rugby_union_team?action=history","edit":"https://en.wikipedia.org/wiki/New_Zealand_national_rugby_union_team?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:New_Zealand_national_rugby_union_team"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/New_Zealand_national_rugby_union_team","revisions":"https://en.m.wikipedia.org/wiki/Special:History/New_Zealand_national_rugby_union_team","edit":"https://en.m.wikipedia.org/wiki/New_Zealand_national_rugby_union_team?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:New_Zealand_national_rugby_union_team"}},"extract":"The New Zealand national rugby union team, commonly known as the All Blacks, represents New Zealand in men's international rugby union, which is considered the country's national sport. Famed for their international success, the All Blacks have often been regarded as the most successful sports team in history.","extract_html":"<p>The <b>New Zealand national rugby union team</b>, commonly known as the <b>All Blacks</b>, represents New Zealand in men's international rugby union, which is considered the country's national sport. Famed for their international success, the All Blacks have often been regarded as the most successful sports team in history.</p>","normalizedtitle":"New Zealand national rugby union team"}],"story":"<!--Oct 28-->In <a rel=\"mw:WikiLink\" href=\"./Rugby_union\" title=\"Rugby union\" id=\"mwFA\">rugby union</a>, <a rel=\"mw:WikiLink\" href=\"./South_Africa_national_rugby_union_team\" title=\"South Africa national rugby union team\" id=\"mwFQ\">South Africa</a> beat <a rel=\"mw:WikiLink\" href=\"./New_Zealand_national_rugby_union_team\" title=\"New Zealand national rugby union team\" id=\"mwFg\">New Zealand</a> in <b id=\"mwFw\"><a rel=\"mw:WikiLink\" href=\"./2023_Rugby_World_Cup_final\" title=\"2023 Rugby World Cup final\" id=\"mwGA\">the World Cup final</a></b>."},{"links":[{"type":"standard","title":"Kostenko_mine_disaster","displaytitle":"<span class=\"mw-page-title-main\">Kostenko mine disaster</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q123224458","titles":{"canonical":"Kostenko_mine_disaster","normalized":"Kostenko mine disaster","display":"<span class=\"mw-page-title-main\">Kostenko mine disaster</span>"},"pageid":75167773,"lang":"en","dir":"ltr","revision":"1183290861","tid":"4cd618f0-7a3c-11ee-a6f0-4d0c210c8070","timestamp":"2023-11-03T11:29:48Z","description":"2023 coal mining disaster in Karaganda, Kazakhstan","description_source":"local","coordinates":{"lat":49.86,"lon":73.115},"content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Kostenko_mine_disaster","revisions":"https://en.wikipedia.org/wiki/Kostenko_mine_disaster?action=history","edit":"https://en.wikipedia.org/wiki/Kostenko_mine_disaster?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Kostenko_mine_disaster"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Kostenko_mine_disaster","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Kostenko_mine_disaster","edit":"https://en.m.wikipedia.org/wiki/Kostenko_mine_disaster?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Kostenko_mine_disaster"}},"extract":"On the morning of 28 October 2023, a fire started at the Kostenko mine in the Karaganda Region of Kazakhstan. The fire killed 46 miners. The fire was presumably caused by a methane gas explosion underground. The President of Kazakhstan, Kassym-Jomart Tokayev, ordered the termination of all investment with the company ArcelorMittal Temirtau, which owns the mine, and 29 October was declared a national day of mourning in Kazakhstan.","extract_html":"<p>On the morning of 28 October 2023, a fire started at the Kostenko mine in the Karaganda Region of Kazakhstan. The fire killed 46 miners. The fire was presumably caused by a methane gas explosion underground. The President of Kazakhstan, Kassym-Jomart Tokayev, ordered the termination of all investment with the company ArcelorMittal Temirtau, which owns the mine, and 29 October was declared a national day of mourning in Kazakhstan.</p>","normalizedtitle":"Kostenko mine disaster"},{"type":"standard","title":"Karaganda_Region","displaytitle":"<span class=\"mw-page-title-main\">Karaganda Region</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q485429","titles":{"canonical":"Karaganda_Region","normalized":"Karaganda Region","display":"<span class=\"mw-page-title-main\">Karaganda Region</span>"},"pageid":13226356,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/c/c4/%D0%92%D0%B8%D0%B4_%D0%91%D0%B5%D0%BA%D1%82%D0%B0%D1%83-%D0%90%D1%82%D0%B0.png/320px-%D0%92%D0%B8%D0%B4_%D0%91%D0%B5%D0%BA%D1%82%D0%B0%D1%83-%D0%90%D1%82%D0%B0.png","width":320,"height":213},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/c/c4/%D0%92%D0%B8%D0%B4_%D0%91%D0%B5%D0%BA%D1%82%D0%B0%D1%83-%D0%90%D1%82%D0%B0.png","width":1000,"height":667},"lang":"en","dir":"ltr","revision":"1182954076","tid":"89a87250-78ac-11ee-9e6b-f97a8bbc337f","timestamp":"2023-11-01T11:48:09Z","description":"Region of Kazakhstan","description_source":"local","coordinates":{"lat":48,"lon":71},"content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Karaganda_Region","revisions":"https://en.wikipedia.org/wiki/Karaganda_Region?action=history","edit":"https://en.wikipedia.org/wiki/Karaganda_Region?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Karaganda_Region"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Karaganda_Region","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Karaganda_Region","edit":"https://en.m.wikipedia.org/wiki/Karaganda_Region?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Karaganda_Region"}},"extract":"Karaganda Region, also spelled Qaraghandy Region, is a region of Kazakhstan. Its capital is Karaganda.","extract_html":"<p><b>Karaganda Region</b>, also spelled <b>Qaraghandy Region</b>, is a region of Kazakhstan. Its capital is Karaganda.</p>","normalizedtitle":"Karaganda Region"}],"story":"<!--Oct 28--><b id=\"mwGg\"><a rel=\"mw:WikiLink\" href=\"./Kostenko_mine_disaster\" title=\"Kostenko mine disaster\" id=\"mwGw\">A coal mine fire</a></b> in <a rel=\"mw:WikiLink\" href=\"./Karaganda_Region\" title=\"Karaganda Region\" id=\"mwHA\">Karaganda Region</a>, Kazakhstan, kills 46 people."}],"onthisday":[{"text":"Abdullah Çatlı, a leader of the ultra-nationalist Grey Wolves, was killed in a car crash near Susurluk, Turkey, sparking a scandal that exposed the depth of the state's complicity in organized crime.","pages":[{"type":"standard","title":"Abdullah_Çatlı","displaytitle":"<span class=\"mw-page-title-main\">Abdullah Çatlı</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q317793","titles":{"canonical":"Abdullah_Çatlı","normalized":"Abdullah Çatlı","display":"<span class=\"mw-page-title-main\">Abdullah Çatlı</span>"},"pageid":2784657,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/d/d7/Abdullah_%C3%87atl%C4%B1.jpg","width":250,"height":338},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/d/d7/Abdullah_%C3%87atl%C4%B1.jpg","width":250,"height":338},"lang":"en","dir":"ltr","revision":"1177905558","tid":"e2af6880-67d7-11ee-bb2b-5dd862db0f34","timestamp":"2023-09-30T10:56:52Z","description":"Turkish secret government agent","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Abdullah_%C3%87atl%C4%B1","revisions":"https://en.wikipedia.org/wiki/Abdullah_%C3%87atl%C4%B1?action=history","edit":"https://en.wikipedia.org/wiki/Abdullah_%C3%87atl%C4%B1?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Abdullah_%C3%87atl%C4%B1"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Abdullah_%C3%87atl%C4%B1","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Abdullah_%C3%87atl%C4%B1","edit":"https://en.m.wikipedia.org/wiki/Abdullah_%C3%87atl%C4%B1?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Abdullah_%C3%87atl%C4%B1"}},"extract":"\nAbdullah Çatlı was a Turkish secret government agent, as well as a contract killer for the National Intelligence Organization (MİT). He led the Grey Wolves, the youth branch of the Nationalist Movement Party (MHP), during the 1970s. His death in the Susurluk car crash, while travelling in a car with state officials, revealed the depth of the state's complicity in organized crime in what became known as the Susurluk scandal. He was a hitman for the state, and was involved in the killings of suspected members of the Kurdistan Workers' Party (PKK) and the Armenian Secret Army for the Liberation of Armenia (ASALA).","extract_html":"<p>\n<b>Abdullah Çatlı</b> was a Turkish secret government agent, as well as a contract killer for the National Intelligence Organization (MİT). He led the Grey Wolves, the youth branch of the Nationalist Movement Party (MHP), during the 1970s. His death in the Susurluk car crash, while travelling in a car with state officials, revealed the depth of the state's complicity in organized crime in what became known as the Susurluk scandal. He was a hitman for the state, and was involved in the killings of suspected members of the Kurdistan Workers' Party (PKK) and the Armenian Secret Army for the Liberation of Armenia (ASALA).</p>","normalizedtitle":"Abdullah Çatlı"},{"type":"standard","title":"Grey_Wolves_(organization)","displaytitle":"<span class=\"mw-page-title-main\">Grey Wolves (organization)</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q1142831","titles":{"canonical":"Grey_Wolves_(organization)","normalized":"Grey Wolves (organization)","display":"<span class=\"mw-page-title-main\">Grey Wolves (organization)</span>"},"pageid":793932,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/d/dc/Grey_Wolves_Logo.svg/320px-Grey_Wolves_Logo.svg.png","width":320,"height":320},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/d/dc/Grey_Wolves_Logo.svg/278px-Grey_Wolves_Logo.svg.png","width":278,"height":278},"lang":"en","dir":"ltr","revision":"1182624224","tid":"1f5938a0-771a-11ee-b667-138a1f1aa90e","timestamp":"2023-10-30T11:47:28Z","description":"Turkish ultra-nationalist political organization","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Grey_Wolves_(organization)","revisions":"https://en.wikipedia.org/wiki/Grey_Wolves_(organization)?action=history","edit":"https://en.wikipedia.org/wiki/Grey_Wolves_(organization)?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Grey_Wolves_(organization)"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Grey_Wolves_(organization)","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Grey_Wolves_(organization)","edit":"https://en.m.wikipedia.org/wiki/Grey_Wolves_(organization)?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Grey_Wolves_(organization)"}},"extract":"The Grey Wolves, officially known by the short name Idealist Hearths, is a Turkish far-right paramilitary organization and political movement affiliated with the Nationalist Movement Party (MHP). Commonly described as ultra-nationalist, neo-fascist, Islamonationalist, and racist, it is a youth organization that has been characterized as the MHP's paramilitary or militant wing. Its members deny its political nature and claim it to be a cultural and educational foundation, as per its full official name: Idealist Clubs Educational and Cultural Foundation.","extract_html":"<p>The <b>Grey Wolves</b>, officially known by the short name <b>Idealist Hearths</b>, is a Turkish far-right paramilitary organization and political movement affiliated with the Nationalist Movement Party (MHP). Commonly described as ultra-nationalist, neo-fascist, Islamonationalist, and racist, it is a youth organization that has been characterized as the MHP's paramilitary or militant wing. Its members deny its political nature and claim it to be a cultural and educational foundation, as per its full official name: <b>Idealist Clubs Educational and Cultural Foundation</b>.</p>","normalizedtitle":"Grey Wolves (organization)"},{"type":"standard","title":"Susurluk","displaytitle":"<span class=\"mw-page-title-main\">Susurluk</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q1023133","titles":{"canonical":"Susurluk","normalized":"Susurluk","display":"<span class=\"mw-page-title-main\">Susurluk</span>"},"pageid":1815032,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/1/1c/Bal%C4%B1kesir_location_Susurluk.svg/320px-Bal%C4%B1kesir_location_Susurluk.svg.png","width":320,"height":276},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/1/1c/Bal%C4%B1kesir_location_Susurluk.svg/590px-Bal%C4%B1kesir_location_Susurluk.svg.png","width":590,"height":508},"lang":"en","dir":"ltr","revision":"1181965996","tid":"ee542220-73da-11ee-939c-93d9b5f2a5b4","timestamp":"2023-10-26T08:37:41Z","description":"District and municipality in Balıkesir, Turkey","description_source":"local","coordinates":{"lat":39.91388889,"lon":28.16027778},"content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Susurluk","revisions":"https://en.wikipedia.org/wiki/Susurluk?action=history","edit":"https://en.wikipedia.org/wiki/Susurluk?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Susurluk"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Susurluk","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Susurluk","edit":"https://en.m.wikipedia.org/wiki/Susurluk?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Susurluk"}},"extract":"Susurluk is a municipality and district of Balıkesir Province, Turkey. Its area is 652 km2, and its population is 37,724 (2022). It is famous for its production of soap and dairy products. \nThe highway from Istanbul to İzmir passes through Susurluk. In Turkey Susurluk is known for its 'tost' - a toasted cheese sandwich with tomato paste, and for its foamy ayran. The mayor is Nurettin Güney (İYİ).","extract_html":"<p><b>Susurluk</b> is a municipality and district of Balıkesir Province, Turkey. Its area is 652 km<sup>2</sup>, and its population is 37,724 (2022). It is famous for its production of soap and dairy products. \nThe highway from Istanbul to İzmir passes through Susurluk. In Turkey Susurluk is known for its 'tost' - a toasted cheese sandwich with tomato paste, and for its foamy ayran. The mayor is Nurettin Güney (İYİ).</p>","normalizedtitle":"Susurluk"},{"type":"standard","title":"Susurluk_scandal","displaytitle":"<span class=\"mw-page-title-main\">Susurluk scandal</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q2825895","titles":{"canonical":"Susurluk_scandal","normalized":"Susurluk scandal","display":"<span class=\"mw-page-title-main\">Susurluk scandal</span>"},"pageid":10231243,"lang":"en","dir":"ltr","revision":"1181378846","tid":"b81a1730-7a3f-11ee-a778-e1c771b9d42e","timestamp":"2023-10-22T18:07:42Z","description":"Mid-1990s political scandal in Turkey","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Susurluk_scandal","revisions":"https://en.wikipedia.org/wiki/Susurluk_scandal?action=history","edit":"https://en.wikipedia.org/wiki/Susurluk_scandal?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Susurluk_scandal"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Susurluk_scandal","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Susurluk_scandal","edit":"https://en.m.wikipedia.org/wiki/Susurluk_scandal?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Susurluk_scandal"}},"extract":"The Susurluk scandal was a political scandal in Turkey that exposed a close relationship between the Turkish government, the ultra-nationalistic paramilitary Grey Wolves organization and the Turkish mafia. It took place during the peak of the Kurdish–Turkish conflict in the mid-1990s.","extract_html":"<p>The <b>Susurluk scandal</b> was a political scandal in Turkey that exposed a close relationship between the Turkish government, the ultra-nationalistic paramilitary Grey Wolves organization and the Turkish mafia. It took place during the peak of the Kurdish–Turkish conflict in the mid-1990s.</p>","normalizedtitle":"Susurluk scandal"}],"year":1996},{"text":"U.S. president Richard Nixon made a plea for support from the \"silent majority\", referring to those Americans who did not join in the large demonstrations against the Vietnam War at the time.","pages":[{"type":"standard","title":"Richard_Nixon","displaytitle":"<span class=\"mw-page-title-main\">Richard Nixon</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q9588","titles":{"canonical":"Richard_Nixon","normalized":"Richard Nixon","display":"<span class=\"mw-page-title-main\">Richard Nixon</span>"},"pageid":25473,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/2/2c/Richard_Nixon_presidential_portrait_%281%29.jpg/320px-Richard_Nixon_presidential_portrait_%281%29.jpg","width":320,"height":427},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/2/2c/Richard_Nixon_presidential_portrait_%281%29.jpg","width":2205,"height":2939},"lang":"en","dir":"ltr","revision":"1183215665","tid":"5ce35410-79ce-11ee-961e-955dd840d6ee","timestamp":"2023-11-02T22:22:37Z","description":"President of the United States from 1969 to 1974","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Richard_Nixon","revisions":"https://en.wikipedia.org/wiki/Richard_Nixon?action=history","edit":"https://en.wikipedia.org/wiki/Richard_Nixon?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Richard_Nixon"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Richard_Nixon","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Richard_Nixon","edit":"https://en.m.wikipedia.org/wiki/Richard_Nixon?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Richard_Nixon"}},"extract":"Richard Milhous Nixon was the 37th president of the United States, serving from 1969 to 1974. A lawyer and member of the Republican Party, he previously served as a representative and senator from California and was the 36th vice president from 1953 to 1961 under President Dwight D. Eisenhower. His five years in the White House saw reduction of U.S. involvement in the Vietnam War, détente with the Soviet Union and China, the Apollo 11 Moon landing, and the establishment of the Environmental Protection Agency and Occupational Safety and Health Administration. Nixon's second term ended early when he became the only U.S. president to resign from office, as a result of the Watergate scandal.","extract_html":"<p><b>Richard Milhous Nixon</b> was the 37th president of the United States, serving from 1969 to 1974. A lawyer and member of the Republican Party, he previously served as a representative and senator from California and was the 36th vice president from 1953 to 1961 under President Dwight D. Eisenhower. His five years in the White House saw reduction of U.S. involvement in the Vietnam War, <span><i>détente</i></span> with the Soviet Union and China, the Apollo 11 Moon landing, and the establishment of the Environmental Protection Agency and Occupational Safety and Health Administration. Nixon's second term ended early when he became the only U.S. president to resign from office, as a result of the Watergate scandal.</p>","normalizedtitle":"Richard Nixon"},{"type":"standard","title":"Silent_majority","displaytitle":"<span class=\"mw-page-title-main\">Silent majority</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q2555361","titles":{"canonical":"Silent_majority","normalized":"Silent majority","display":"<span class=\"mw-page-title-main\">Silent majority</span>"},"pageid":88270,"lang":"en","dir":"ltr","revision":"1176412745","tid":"4da66970-7798-11ee-9f2d-67b365612516","timestamp":"2023-09-21T15:39:05Z","description":"Concept in politics","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Silent_majority","revisions":"https://en.wikipedia.org/wiki/Silent_majority?action=history","edit":"https://en.wikipedia.org/wiki/Silent_majority?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Silent_majority"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Silent_majority","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Silent_majority","edit":"https://en.m.wikipedia.org/wiki/Silent_majority?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Silent_majority"}},"extract":"The silent majority is an unspecified large group of people in a country or group who do not express their opinions publicly. The term was popularized by U.S. President Richard Nixon in a televised address on November 3, 1969, in which he said, \"And so tonight—to you, the great silent majority of my fellow Americans—I ask for your support.\" In this usage it referred to those Americans who did not join in the large demonstrations against the Vietnam War at the time, who did not join in the counterculture, and who did not participate in public discourse. Nixon, along with many others, saw this group of Middle Americans as being overshadowed in the media by the more vocal minority.","extract_html":"<p>The <b>silent majority</b> is an unspecified large group of people in a country or group who do not express their opinions publicly. The term was popularized by U.S. President Richard Nixon in a televised address on November 3, 1969, in which he said, \"And so tonight—to you, the great silent majority of my fellow Americans—I ask for your support.\" In this usage it referred to those Americans who did not join in the large demonstrations against the Vietnam War at the time, who did not join in the counterculture, and who did not participate in public discourse. Nixon, along with many others, saw this group of Middle Americans as being overshadowed in the media by the more vocal minority.</p>","normalizedtitle":"Silent majority"},{"type":"standard","title":"Opposition_to_United_States_involvement_in_the_Vietnam_War","displaytitle":"<span class=\"mw-page-title-main\">Opposition to United States involvement in the Vietnam War</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q5254589","titles":{"canonical":"Opposition_to_United_States_involvement_in_the_Vietnam_War","normalized":"Opposition to United States involvement in the Vietnam War","display":"<span class=\"mw-page-title-main\">Opposition to United States involvement in the Vietnam War</span>"},"pageid":1854610,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/0/03/Vietnamdem.jpg/320px-Vietnamdem.jpg","width":320,"height":318},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/0/03/Vietnamdem.jpg","width":2400,"height":2384},"lang":"en","dir":"ltr","revision":"1183199397","tid":"8ea57f40-79bb-11ee-8f43-01071fad6853","timestamp":"2023-11-02T20:08:08Z","description":"1964–1973 anti-war movement","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Opposition_to_United_States_involvement_in_the_Vietnam_War","revisions":"https://en.wikipedia.org/wiki/Opposition_to_United_States_involvement_in_the_Vietnam_War?action=history","edit":"https://en.wikipedia.org/wiki/Opposition_to_United_States_involvement_in_the_Vietnam_War?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Opposition_to_United_States_involvement_in_the_Vietnam_War"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Opposition_to_United_States_involvement_in_the_Vietnam_War","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Opposition_to_United_States_involvement_in_the_Vietnam_War","edit":"https://en.m.wikipedia.org/wiki/Opposition_to_United_States_involvement_in_the_Vietnam_War?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Opposition_to_United_States_involvement_in_the_Vietnam_War"}},"extract":"Opposition to United States involvement in the Vietnam War began with demonstrations in 1965 against the escalating role of the United States in the Vietnam War and grew into a broad social movement over the ensuing several years. This movement informed and helped shape the vigorous and polarizing debate, primarily in the United States, during the second half of the 1960s and early 1970s on how to end the Vietnam War.","extract_html":"<p><b>Opposition to United States involvement in the Vietnam War</b> began with demonstrations in 1965 against the escalating role of the United States in the Vietnam War and grew into a broad social movement over the ensuing several years. This movement informed and helped shape the vigorous and polarizing debate, primarily in the United States, during the second half of the 1960s and early 1970s on how to end the Vietnam War.</p>","normalizedtitle":"Opposition to United States involvement in the Vietnam War"}],"year":1969},{"text":"The Soviet Union launched Sputnik 2, carrying the space dog Laika as the first living creature to enter orbit around Earth.","pages":[{"type":"standard","title":"Sputnik_2","displaytitle":"<span class=\"mw-page-title-main\">Sputnik 2</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q190555","titles":{"canonical":"Sputnik_2","normalized":"Sputnik 2","display":"<span class=\"mw-page-title-main\">Sputnik 2</span>"},"pageid":81978,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/3/33/Laika_ac_Sputnik_2_Replica_%286995685051%29.jpg/320px-Laika_ac_Sputnik_2_Replica_%286995685051%29.jpg","width":320,"height":480},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/3/33/Laika_ac_Sputnik_2_Replica_%286995685051%29.jpg","width":3456,"height":5184},"lang":"en","dir":"ltr","revision":"1183265364","tid":"0e1f45e0-7a10-11ee-8ac7-0516d150d245","timestamp":"2023-11-03T06:13:04Z","description":"Second spacecraft launched into Earth orbit (1957)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Sputnik_2","revisions":"https://en.wikipedia.org/wiki/Sputnik_2?action=history","edit":"https://en.wikipedia.org/wiki/Sputnik_2?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Sputnik_2"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Sputnik_2","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Sputnik_2","edit":"https://en.m.wikipedia.org/wiki/Sputnik_2?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Sputnik_2"}},"extract":"Sputnik 2, or Prosteyshiy Sputnik 2, launched on 3 November 1957, was the second spacecraft launched into Earth orbit, and the first to carry an animal into orbit, a Soviet space dog named Laika.","extract_html":"<p><b>Sputnik 2</b>, or <b>Prosteyshiy Sputnik 2</b>, launched on 3 November 1957, was the second spacecraft launched into Earth orbit, and the first to carry an animal into orbit, a Soviet space dog named Laika.</p>","normalizedtitle":"Sputnik 2"},{"type":"standard","title":"Soviet_space_dogs","displaytitle":"<span class=\"mw-page-title-main\">Soviet space dogs</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q327132","titles":{"canonical":"Soviet_space_dogs","normalized":"Soviet space dogs","display":"<span class=\"mw-page-title-main\">Soviet space dogs</span>"},"pageid":746647,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/6/64/Russian_space_dog_box.jpg/320px-Russian_space_dog_box.jpg","width":320,"height":402},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/6/64/Russian_space_dog_box.jpg","width":637,"height":800},"lang":"en","dir":"ltr","revision":"1175886144","tid":"ed623ed0-79be-11ee-a6cb-b1517952f798","timestamp":"2023-09-18T02:17:24Z","description":"Soviet-era program that sent dogs to space","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Soviet_space_dogs","revisions":"https://en.wikipedia.org/wiki/Soviet_space_dogs?action=history","edit":"https://en.wikipedia.org/wiki/Soviet_space_dogs?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Soviet_space_dogs"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Soviet_space_dogs","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Soviet_space_dogs","edit":"https://en.m.wikipedia.org/wiki/Soviet_space_dogs?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Soviet_space_dogs"}},"extract":"During the 1950s and 1960s the Soviet space program used dogs for sub-orbital and orbital space flights to determine whether human spaceflight was feasible. These dogs were surgically modified to provide the necessary information for human survival in space. The Soviet space program typically used female dogs due to their anatomical compatibility with the spacesuit. Similarly, they used mix-breed dogs due to their apparent hardiness.","extract_html":"<p>During the 1950s and 1960s the Soviet space program used dogs for sub-orbital and orbital space flights to determine whether human spaceflight was feasible. These dogs were surgically modified to provide the necessary information for human survival in space. The Soviet space program typically used female dogs due to their anatomical compatibility with the spacesuit. Similarly, they used mix-breed dogs due to their apparent hardiness.</p>","normalizedtitle":"Soviet space dogs"},{"type":"standard","title":"Laika","displaytitle":"<span class=\"mw-page-title-main\">Laika</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q53662","titles":{"canonical":"Laika","normalized":"Laika","display":"<span class=\"mw-page-title-main\">Laika</span>"},"pageid":18739,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/thumb/7/71/Laika_%28Soviet_dog%29.jpg/320px-Laika_%28Soviet_dog%29.jpg","width":320,"height":241},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/7/71/Laika_%28Soviet_dog%29.jpg","width":365,"height":275},"lang":"en","dir":"ltr","revision":"1183263918","tid":"54a3d290-7a0d-11ee-a7a1-3d40ba726de4","timestamp":"2023-11-03T05:53:33Z","description":"Soviet dog, first animal to orbit Earth (1957)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Laika","revisions":"https://en.wikipedia.org/wiki/Laika?action=history","edit":"https://en.wikipedia.org/wiki/Laika?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Laika"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Laika","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Laika","edit":"https://en.m.wikipedia.org/wiki/Laika?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Laika"}},"extract":"Laika was a Soviet space dog who was one of the first animals in space and the first to orbit the Earth. A stray mongrel from the streets of Moscow, she flew aboard the Sputnik 2 spacecraft, launched into low orbit on 3 November 1957. As the technology to de-orbit had not yet been developed, Laika's survival was never expected. She died of overheating hours into the flight, on the craft's fourth orbit.","extract_html":"<p><b>Laika</b> was a Soviet space dog who was one of the first animals in space and the first to orbit the Earth. A stray mongrel from the streets of Moscow, she flew aboard the Sputnik 2 spacecraft, launched into low orbit on 3 November 1957. As the technology to de-orbit had not yet been developed, Laika's survival was never expected. She died of overheating hours into the flight, on the craft's fourth orbit.</p>","normalizedtitle":"Laika"}],"year":1957},{"text":"Suez Crisis: During an invasion of the Gaza Strip, Israeli soldiers shot and killed hundreds of Palestinian refugees and local inhabitants in Khan Yunis.","pages":[{"type":"standard","title":"Suez_Crisis","displaytitle":"<span class=\"mw-page-title-main\">Suez Crisis</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q49101","titles":{"canonical":"Suez_Crisis","normalized":"Suez Crisis","display":"<span class=\"mw-page-title-main\">Suez Crisis</span>"},"pageid":58568,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/1/1d/Tanks_Destroyed_Sinai.jpg/320px-Tanks_Destroyed_Sinai.jpg","width":320,"height":204},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/1/1d/Tanks_Destroyed_Sinai.jpg","width":1566,"height":1000},"lang":"en","dir":"ltr","revision":"1183104328","tid":"db4760a0-7940-11ee-a5c0-ff1040f0f883","timestamp":"2023-11-02T05:29:49Z","description":"1956 British–French–Israeli invasion of Egypt","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Suez_Crisis","revisions":"https://en.wikipedia.org/wiki/Suez_Crisis?action=history","edit":"https://en.wikipedia.org/wiki/Suez_Crisis?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Suez_Crisis"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Suez_Crisis","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Suez_Crisis","edit":"https://en.m.wikipedia.org/wiki/Suez_Crisis?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Suez_Crisis"}},"extract":"The Suez Crisis, or the Second Arab–Israeli war, also called the Tripartite Aggression in the Arab world and the Sinai War in Israel, was an invasion of Egypt and the Gaza Strip in late 1956 by Israel, followed by the United Kingdom and France. The aims were to regain control of the Suez Canal for the Western powers and to remove Egyptian president Gamal Abdel Nasser, who had just nationalised the foreign-owned Suez Canal Company, which administered the canal. Israel's primary objective was to re-open the blocked Straits of Tiran. After the fighting had started, political pressure from the United States, the Soviet Union, and the United Nations led to a withdrawal by the three invaders. The episode humiliated the United Kingdom and France and strengthened Nasser.","extract_html":"<p>The <b>Suez Crisis</b>, or the <b>Second Arab–Israeli war</b>, also called the <b>Tripartite Aggression</b> in the Arab world and the <b>Sinai War</b> in Israel, was an invasion of Egypt and the Gaza Strip in late 1956 by Israel, followed by the United Kingdom and France. The aims were to regain control of the Suez Canal for the Western powers and to remove Egyptian president Gamal Abdel Nasser, who had just nationalised the foreign-owned Suez Canal Company, which administered the canal. Israel's primary objective was to re-open the blocked Straits of Tiran. After the fighting had started, political pressure from the United States, the Soviet Union, and the United Nations led to a withdrawal by the three invaders. The episode humiliated the United Kingdom and France and strengthened Nasser.</p>","normalizedtitle":"Suez Crisis"},{"type":"standard","title":"Gaza_Strip","displaytitle":"<span class=\"mw-page-title-main\">Gaza Strip</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q39760","titles":{"canonical":"Gaza_Strip","normalized":"Gaza Strip","display":"<span class=\"mw-page-title-main\">Gaza Strip</span>"},"pageid":12047,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/0/00/Flag_of_Palestine.svg/320px-Flag_of_Palestine.svg.png","width":320,"height":160},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/0/00/Flag_of_Palestine.svg/1200px-Flag_of_Palestine.svg.png","width":1200,"height":600},"lang":"en","dir":"ltr","revision":"1183294122","tid":"8e3ab8a0-7a41-11ee-a894-a90b0fe3c4e3","timestamp":"2023-11-03T12:07:19Z","description":"Self-governing Palestinian territory next to Egypt and Israel","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Gaza_Strip","revisions":"https://en.wikipedia.org/wiki/Gaza_Strip?action=history","edit":"https://en.wikipedia.org/wiki/Gaza_Strip?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Gaza_Strip"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Gaza_Strip","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Gaza_Strip","edit":"https://en.m.wikipedia.org/wiki/Gaza_Strip?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Gaza_Strip"}},"extract":"The Gaza Strip, or simply Gaza, is the smaller of the two Palestinian territories. Situated on the eastern coast of the Mediterranean Sea, the territory is bordered by Egypt on the southwest and Israel on the east and north. Gaza, along with the West Bank, have been under Israeli military occupation since 1967, which Israel disputes after its 2005 disengagement from the Strip.","extract_html":"<p>The <b>Gaza Strip</b>, or simply <b>Gaza</b>, is the smaller of the two Palestinian territories. Situated on the eastern coast of the Mediterranean Sea, the territory is bordered by Egypt on the southwest and Israel on the east and north. Gaza, along with the West Bank, have been under Israeli military occupation since 1967, which Israel disputes after its 2005 disengagement from the Strip.</p>","normalizedtitle":"Gaza Strip"},{"type":"standard","title":"Khan_Yunis_massacre","displaytitle":"<span class=\"mw-page-title-main\">Khan Yunis massacre</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q12241913","titles":{"canonical":"Khan_Yunis_massacre","normalized":"Khan Yunis massacre","display":"<span class=\"mw-page-title-main\">Khan Yunis massacre</span>"},"pageid":40346044,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/7/77/Khan_Yunis-1930s.jpg/320px-Khan_Yunis-1930s.jpg","width":320,"height":171},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/7/77/Khan_Yunis-1930s.jpg","width":604,"height":322},"lang":"en","dir":"ltr","revision":"1181797265","tid":"7fa8e140-730c-11ee-bdd4-3367d227f0f0","timestamp":"2023-10-25T07:59:59Z","description":"1956 mass killing of Palestinians by Israeli forces during the Suez Crisis","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Khan_Yunis_massacre","revisions":"https://en.wikipedia.org/wiki/Khan_Yunis_massacre?action=history","edit":"https://en.wikipedia.org/wiki/Khan_Yunis_massacre?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Khan_Yunis_massacre"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Khan_Yunis_massacre","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Khan_Yunis_massacre","edit":"https://en.m.wikipedia.org/wiki/Khan_Yunis_massacre?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Khan_Yunis_massacre"}},"extract":"The Khan Yunis massacre took place on 3 November 1956 perpetrated by the Israel Defense Forces in the Palestinian town of Khan Yunis and the nearby refugee camp of the same name in the Gaza Strip during the Suez Crisis.","extract_html":"<p>The <b>Khan Yunis massacre</b> took place on 3 November 1956 perpetrated by the Israel Defense Forces in the Palestinian town of Khan Yunis and the nearby refugee camp of the same name in the Gaza Strip during the Suez Crisis.</p>","normalizedtitle":"Khan Yunis massacre"},{"type":"standard","title":"Khan_Yunis","displaytitle":"<span class=\"mw-page-title-main\">Khan Yunis</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q309348","titles":{"canonical":"Khan_Yunis","normalized":"Khan Yunis","display":"<span class=\"mw-page-title-main\">Khan Yunis</span>"},"pageid":101330,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/b/b3/Khan_Yunis_panorama.jpg/320px-Khan_Yunis_panorama.jpg","width":320,"height":213},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/b/b3/Khan_Yunis_panorama.jpg","width":960,"height":640},"lang":"en","dir":"ltr","revision":"1183077893","tid":"3c606a10-7920-11ee-835f-8fe2449391f8","timestamp":"2023-11-02T01:36:21Z","description":"City in Gaza, Palestine","description_source":"local","coordinates":{"lat":31.34444444,"lon":34.30305556},"content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Khan_Yunis","revisions":"https://en.wikipedia.org/wiki/Khan_Yunis?action=history","edit":"https://en.wikipedia.org/wiki/Khan_Yunis?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Khan_Yunis"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Khan_Yunis","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Khan_Yunis","edit":"https://en.m.wikipedia.org/wiki/Khan_Yunis?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Khan_Yunis"}},"extract":"Khan Yunis is a city in the southern Gaza Strip; it is the capital of the Khan Yunis Governorate of the State of Palestine. According to the Palestinian Central Bureau of Statistics, Khan Yunis had a population of 205,125 in 2017. Khan Yunis, which lies only 4 kilometers east of the Mediterranean Sea, has a semi-arid climate with temperature of 30 degrees Celsius maximum in summer and 10 degrees Celsius maximum in winter, with an annual rainfall of approximately 260 mm (10.2 in).","extract_html":"<p><b>Khan Yunis</b> is a city in the southern Gaza Strip; it is the capital of the Khan Yunis Governorate of the State of Palestine. According to the Palestinian Central Bureau of Statistics, Khan Yunis had a population of 205,125 in 2017. Khan Yunis, which lies only 4 kilometers east of the Mediterranean Sea, has a semi-arid climate with temperature of 30 degrees Celsius maximum in summer and 10 degrees Celsius maximum in winter, with an annual rainfall of approximately 260 mm (10.2 in).</p>","normalizedtitle":"Khan Yunis"}],"year":1956},{"text":"The first film featuring the giant monster known as Godzilla was released nationwide in Japan.","pages":[{"type":"standard","title":"Godzilla_(1954_film)","displaytitle":"<i>Godzilla</i> (1954 film)","namespace":{"id":0,"text":""},"wikibase_item":"Q860461","titles":{"canonical":"Godzilla_(1954_film)","normalized":"Godzilla (1954 film)","display":"<i>Godzilla</i> (1954 film)"},"pageid":12004,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/9/95/Gojira_1954_Japanese_poster.jpg/320px-Gojira_1954_Japanese_poster.jpg","width":320,"height":450},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/9/95/Gojira_1954_Japanese_poster.jpg","width":2135,"height":3000},"lang":"en","dir":"ltr","revision":"1182225512","tid":"188aead0-751e-11ee-b87b-e395a96f2f98","timestamp":"2023-10-27T23:10:53Z","description":"Japanese monster film","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Godzilla_(1954_film)","revisions":"https://en.wikipedia.org/wiki/Godzilla_(1954_film)?action=history","edit":"https://en.wikipedia.org/wiki/Godzilla_(1954_film)?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Godzilla_(1954_film)"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Godzilla_(1954_film)","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Godzilla_(1954_film)","edit":"https://en.m.wikipedia.org/wiki/Godzilla_(1954_film)?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Godzilla_(1954_film)"}},"extract":"Godzilla  is a 1954 Japanese epic kaiju film directed and co-written by Ishirō Honda, with special effects by Eiji Tsuburaya. Produced and distributed by Toho Co., Ltd., it is the first film in the Godzilla franchise. The film stars Akira Takarada, Momoko Kōchi, Akihiko Hirata, and Takashi Shimura, with Haruo Nakajima and Katsumi Tezuka as Godzilla. In the film, Japan's authorities deal with the sudden appearance of a giant monster, whose attacks trigger fears of nuclear holocaust during post-war Japan.","extract_html":"<p><i><b>Godzilla</b></i><span style=\"font-weight:normal\"> </span> is a 1954 Japanese epic <i>kaiju</i> film directed and co-written by Ishirō Honda, with special effects by Eiji Tsuburaya. Produced and distributed by Toho Co., Ltd., it is the first film in the <span><i>Godzilla</i> franchise</span>. The film stars Akira Takarada, Momoko Kōchi, Akihiko Hirata, and Takashi Shimura, with Haruo Nakajima and Katsumi Tezuka as Godzilla. In the film, Japan's authorities deal with the sudden appearance of a giant monster, whose attacks trigger fears of nuclear holocaust during post-war Japan.</p>","normalizedtitle":"Godzilla (1954 film)"},{"type":"standard","title":"Kaiju","displaytitle":"<i>Kaiju</i>","namespace":{"id":0,"text":""},"wikibase_item":"Q1065444","titles":{"canonical":"Kaiju","normalized":"Kaiju","display":"<i>Kaiju</i>"},"pageid":64998,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/0/01/Gojira_1954_poster_3.jpg/320px-Gojira_1954_poster_3.jpg","width":320,"height":488},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/0/01/Gojira_1954_poster_3.jpg","width":2016,"height":3072},"lang":"en","dir":"ltr","revision":"1176309277","tid":"fefe6500-77a8-11ee-973c-bf5d37ca3cba","timestamp":"2023-09-20T21:44:19Z","description":"Japanese media genre","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Kaiju","revisions":"https://en.wikipedia.org/wiki/Kaiju?action=history","edit":"https://en.wikipedia.org/wiki/Kaiju?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Kaiju"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Kaiju","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Kaiju","edit":"https://en.m.wikipedia.org/wiki/Kaiju?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Kaiju"}},"extract":"Kaiju  is a Japanese term that is commonly associated with media involving giant monsters and monster movies. A subgenre of science fiction and fantasy, it was created by Eiji Tsuburaya and Ishirō Honda. The word can also refer to the giant monsters themselves, which are usually depicted attacking major cities and battling either the military or other monsters.","extract_html":"<p><i><b>Kaiju</b></i><span style=\"font-weight:normal\"> </span> is a Japanese term that is commonly associated with media involving giant monsters and monster movies. A subgenre of science fiction and fantasy, it was created by Eiji Tsuburaya and Ishirō Honda. The word can also refer to the giant monsters themselves, which are usually depicted attacking major cities and battling either the military or other monsters.</p>","normalizedtitle":"Kaiju"},{"type":"standard","title":"Godzilla","displaytitle":"<span class=\"mw-page-title-main\">Godzilla</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q6567","titles":{"canonical":"Godzilla","normalized":"Godzilla","display":"<span class=\"mw-page-title-main\">Godzilla</span>"},"pageid":11986,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/1/1d/Godzilla_%281954%29.jpg/320px-Godzilla_%281954%29.jpg","width":320,"height":247},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/1/1d/Godzilla_%281954%29.jpg","width":2617,"height":2022},"lang":"en","dir":"ltr","revision":"1182836901","tid":"40611f90-7814-11ee-bbdf-19cf1778a9d3","timestamp":"2023-10-31T17:38:00Z","description":"Godzilla kaiju","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Godzilla","revisions":"https://en.wikipedia.org/wiki/Godzilla?action=history","edit":"https://en.wikipedia.org/wiki/Godzilla?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Godzilla"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Godzilla","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Godzilla","edit":"https://en.m.wikipedia.org/wiki/Godzilla?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Godzilla"}},"extract":"Godzilla  is a fictional monster, or kaiju, that debuted in the eponymous 1954 film, directed and co-written by Ishirō Honda. The character has since become an international pop culture icon, appearing in various media: 33 Japanese films produced by Toho Co., Ltd., five American films and numerous video games, novels, comic books and television shows. Godzilla has been dubbed the \"King of the Monsters\", an epithet first used in Godzilla, King of the Monsters! (1956), the American localization of the 1954 film.","extract_html":"<p><b>Godzilla</b><span style=\"font-weight:normal\"> </span> is a fictional monster, or <i>kaiju</i>, that debuted in the eponymous 1954 film, directed and co-written by Ishirō Honda. The character has since become an international pop culture icon, appearing in various media: 33 Japanese films produced by Toho Co., Ltd., five American films and numerous video games, novels, comic books and television shows. Godzilla has been dubbed the \"<b>King of the Monsters</b>\", an epithet first used in <i>Godzilla, King of the Monsters!</i> (1956), the American localization of the 1954 film.</p>","normalizedtitle":"Godzilla"}],"year":1954},{"text":"The Chicago Daily Tribune published the erroneous headline \"Dewey Defeats Truman\" (pictured) in its early morning edition shortly after incumbent U.S. president Harry S. Truman officially upset the heavily favored governor of New York Thomas Dewey in the presidential election.","pages":[{"type":"standard","title":"Chicago_Tribune","displaytitle":"<i>Chicago Tribune</i>","namespace":{"id":0,"text":""},"wikibase_item":"Q47596","titles":{"canonical":"Chicago_Tribune","normalized":"Chicago Tribune","display":"<i>Chicago Tribune</i>"},"pageid":60961,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/en/b/b3/Chicagotribunejune162009.png","width":226,"height":441},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/en/b/b3/Chicagotribunejune162009.png","width":226,"height":441},"lang":"en","dir":"ltr","revision":"1181823217","tid":"6fb87530-7333-11ee-a386-27432a774ac0","timestamp":"2023-10-25T12:38:35Z","description":"Major American newspaper, founded 1847","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Chicago_Tribune","revisions":"https://en.wikipedia.org/wiki/Chicago_Tribune?action=history","edit":"https://en.wikipedia.org/wiki/Chicago_Tribune?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Chicago_Tribune"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Chicago_Tribune","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Chicago_Tribune","edit":"https://en.m.wikipedia.org/wiki/Chicago_Tribune?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Chicago_Tribune"}},"extract":"The Chicago Tribune is a daily newspaper based in Chicago, Illinois, United States, owned by Tribune Publishing. Founded in 1847, and formerly self-styled as the \"World's Greatest Newspaper\", it remains the most-read daily newspaper in the Chicago metropolitan area and the Great Lakes region. In 2022, it had the seventh-highest circulation of any American newspaper.","extract_html":"<p>The <i><b>Chicago Tribune</b></i> is a daily newspaper based in Chicago, Illinois, United States, owned by Tribune Publishing. Founded in 1847, and formerly self-styled as the \"World's Greatest Newspaper\", it remains the most-read daily newspaper in the Chicago metropolitan area and the Great Lakes region. In 2022, it had the seventh-highest circulation of any American newspaper.</p>","normalizedtitle":"Chicago Tribune"},{"type":"standard","title":"Dewey_Defeats_Truman","displaytitle":"<span class=\"mw-page-title-main\">Dewey Defeats Truman</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q740421","titles":{"canonical":"Dewey_Defeats_Truman","normalized":"Dewey Defeats Truman","display":"<span class=\"mw-page-title-main\">Dewey Defeats Truman</span>"},"pageid":2026987,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/0/09/Dewey_Defeats_Truman.jpg/320px-Dewey_Defeats_Truman.jpg","width":320,"height":246},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/0/09/Dewey_Defeats_Truman.jpg","width":3000,"height":2306},"lang":"en","dir":"ltr","revision":"1183270259","tid":"a80e9af0-7a17-11ee-b8e9-e9043fed950c","timestamp":"2023-11-03T07:07:30Z","description":"1948 incorrect American newspaper headline","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Dewey_Defeats_Truman","revisions":"https://en.wikipedia.org/wiki/Dewey_Defeats_Truman?action=history","edit":"https://en.wikipedia.org/wiki/Dewey_Defeats_Truman?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Dewey_Defeats_Truman"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Dewey_Defeats_Truman","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Dewey_Defeats_Truman","edit":"https://en.m.wikipedia.org/wiki/Dewey_Defeats_Truman?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Dewey_Defeats_Truman"}},"extract":"\"Dewey Defeats Truman\" was an incorrect banner headline on the front page of the Chicago Daily Tribune on November 3, 1948, the day after incumbent United States president Harry S. Truman won an upset victory over his opponent, Governor Thomas E. Dewey of New York, in the 1948 presidential election. It was famously held up by Truman at a stop at St. Louis Union Station following his successful election, smiling triumphantly at the error.","extract_html":"<p>\"<b>Dewey Defeats Truman</b>\" was an incorrect banner headline on the front page of the <i>Chicago Daily Tribune</i> on November 3, 1948, the day after incumbent United States president Harry S. Truman won an upset victory over his opponent, Governor Thomas E. Dewey of New York, in the 1948 presidential election. It was famously held up by Truman at a stop at St. Louis Union Station following his successful election, smiling triumphantly at the error.</p>","normalizedtitle":"Dewey Defeats Truman"},{"type":"standard","title":"Harry_S._Truman","displaytitle":"<span class=\"mw-page-title-main\">Harry S. Truman</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q11613","titles":{"canonical":"Harry_S._Truman","normalized":"Harry S. Truman","display":"<span class=\"mw-page-title-main\">Harry S. Truman</span>"},"pageid":3418303,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/0/0b/TRUMAN_58-766-06_%28cropped%29.jpg/320px-TRUMAN_58-766-06_%28cropped%29.jpg","width":320,"height":432},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/0/0b/TRUMAN_58-766-06_%28cropped%29.jpg","width":900,"height":1215},"lang":"en","dir":"ltr","revision":"1183288186","tid":"31988360-7a38-11ee-a3b7-13ac93c84c03","timestamp":"2023-11-03T11:00:16Z","description":"President of the United States from 1945 to 1953","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Harry_S._Truman","revisions":"https://en.wikipedia.org/wiki/Harry_S._Truman?action=history","edit":"https://en.wikipedia.org/wiki/Harry_S._Truman?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Harry_S._Truman"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Harry_S._Truman","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Harry_S._Truman","edit":"https://en.m.wikipedia.org/wiki/Harry_S._Truman?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Harry_S._Truman"}},"extract":"Harry S. Truman was the 33rd president of the United States, serving from 1945 to 1953. A member of the Democratic Party, he previously served as a United States senator from Missouri from 1935 to 1945 and briefly as the 34th vice president in 1945 under Franklin D. Roosevelt. Assuming the presidency after Roosevelt's death, Truman implemented the Marshall Plan to rebuild the economy of Western Europe and established both the Truman Doctrine and NATO to contain the expansion of Soviet communism. He proposed numerous liberal domestic reforms, but few were enacted by the conservative coalition that dominated the Congress.","extract_html":"<p><b>Harry S. Truman</b> was the 33rd president of the United States, serving from 1945 to 1953. A member of the Democratic Party, he previously served as a United States senator from Missouri from 1935 to 1945 and briefly as the 34th vice president in 1945 under Franklin D. Roosevelt. Assuming the presidency after Roosevelt's death, Truman implemented the Marshall Plan to rebuild the economy of Western Europe and established both the Truman Doctrine and NATO to contain the expansion of Soviet communism. He proposed numerous liberal domestic reforms, but few were enacted by the conservative coalition that dominated the Congress.</p>","normalizedtitle":"Harry S. Truman"},{"type":"standard","title":"Thomas_E._Dewey","displaytitle":"<span class=\"mw-page-title-main\">Thomas E. Dewey</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q320061","titles":{"canonical":"Thomas_E._Dewey","normalized":"Thomas E. Dewey","display":"<span class=\"mw-page-title-main\">Thomas E. Dewey</span>"},"pageid":45596,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/5/52/Thomas_Dewey_in_1944.jpg/320px-Thomas_Dewey_in_1944.jpg","width":320,"height":426},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/5/52/Thomas_Dewey_in_1944.jpg","width":460,"height":612},"lang":"en","dir":"ltr","revision":"1183007631","tid":"de2a8f90-78e1-11ee-8274-49919497dbb1","timestamp":"2023-11-01T18:09:53Z","description":"American politician (1902–1971)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Thomas_E._Dewey","revisions":"https://en.wikipedia.org/wiki/Thomas_E._Dewey?action=history","edit":"https://en.wikipedia.org/wiki/Thomas_E._Dewey?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Thomas_E._Dewey"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Thomas_E._Dewey","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Thomas_E._Dewey","edit":"https://en.m.wikipedia.org/wiki/Thomas_E._Dewey?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Thomas_E._Dewey"}},"extract":"Thomas Edmund Dewey was an American lawyer and politician who served as the 47th governor of New York from 1943 to 1954. He was the Republican Party's nominee for president of the United States in 1944 and in 1948, where he lost in a major upset to Harry Truman. The 288 combined electoral votes Dewey received from both elections place him second behind William Jennings Bryan as the candidate with the most electoral votes who never acceded to the presidency.","extract_html":"<p><b>Thomas Edmund Dewey</b> was an American lawyer and politician who served as the 47th governor of New York from 1943 to 1954. He was the Republican Party's nominee for president of the United States in 1944 and in 1948, where he lost in a major upset to Harry Truman. The 288 combined electoral votes Dewey received from both elections place him second behind William Jennings Bryan as the candidate with the most electoral votes who never acceded to the presidency.</p>","normalizedtitle":"Thomas E. Dewey"},{"type":"standard","title":"1948_United_States_presidential_election","displaytitle":"<span class=\"mw-page-title-main\">1948 United States presidential election</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q568973","titles":{"canonical":"1948_United_States_presidential_election","normalized":"1948 United States presidential election","display":"<span class=\"mw-page-title-main\">1948 United States presidential election</span>"},"pageid":40562,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/2/2f/ElectoralCollege1948.svg/320px-ElectoralCollege1948.svg.png","width":320,"height":186},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/2/2f/ElectoralCollege1948.svg/1020px-ElectoralCollege1948.svg.png","width":1020,"height":593},"lang":"en","dir":"ltr","revision":"1183264447","tid":"461a17b0-7a0e-11ee-b475-5723eb077785","timestamp":"2023-11-03T06:00:16Z","description":"41st quadrennial U.S. presidential election","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/1948_United_States_presidential_election","revisions":"https://en.wikipedia.org/wiki/1948_United_States_presidential_election?action=history","edit":"https://en.wikipedia.org/wiki/1948_United_States_presidential_election?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:1948_United_States_presidential_election"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/1948_United_States_presidential_election","revisions":"https://en.m.wikipedia.org/wiki/Special:History/1948_United_States_presidential_election","edit":"https://en.m.wikipedia.org/wiki/1948_United_States_presidential_election?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:1948_United_States_presidential_election"}},"extract":"The 1948 United States presidential election was the 41st quadrennial presidential election. It was held on Tuesday, November 2, 1948. In one of the greatest election upsets in American history, incumbent President Harry S. Truman, the Democratic nominee, defeated heavily favored Republican Governor of New York Thomas E. Dewey, and third-party candidates, becoming the third president to succeed to the presidency upon his predecessor’s death and be elected to a full term.","extract_html":"<p>The <b>1948 United States presidential election</b> was the 41st quadrennial presidential election. It was held on Tuesday, November 2, 1948. In one of the greatest election upsets in American history, incumbent President Harry S. Truman, the Democratic nominee, defeated heavily favored Republican Governor of New York Thomas E. Dewey, and third-party candidates, becoming the third president to succeed to the presidency upon his predecessor’s death and be elected to a full term.</p>","normalizedtitle":"1948 United States presidential election"}],"year":1948},{"text":"The Holocaust: The largest massacre of Jews by German forces began at Majdanek concentration camp (execution trenches pictured).","pages":[{"type":"standard","title":"The_Holocaust","displaytitle":"<span class=\"mw-page-title-main\">The Holocaust</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q2763","titles":{"canonical":"The_Holocaust","normalized":"The Holocaust","display":"<span class=\"mw-page-title-main\">The Holocaust</span>"},"pageid":10396793,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/3/3b/Selection_on_the_ramp_at_Auschwitz-Birkenau%2C_1944_%28Auschwitz_Album%29_1a.jpg/320px-Selection_on_the_ramp_at_Auschwitz-Birkenau%2C_1944_%28Auschwitz_Album%29_1a.jpg","width":320,"height":214},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/3/3b/Selection_on_the_ramp_at_Auschwitz-Birkenau%2C_1944_%28Auschwitz_Album%29_1a.jpg","width":4205,"height":2814},"lang":"en","dir":"ltr","revision":"1182686397","tid":"e2470150-79c0-11ee-b69b-db7251446f1e","timestamp":"2023-10-30T19:44:20Z","description":"Genocide of European Jews by Nazi Germany","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/The_Holocaust","revisions":"https://en.wikipedia.org/wiki/The_Holocaust?action=history","edit":"https://en.wikipedia.org/wiki/The_Holocaust?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:The_Holocaust"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/The_Holocaust","revisions":"https://en.m.wikipedia.org/wiki/Special:History/The_Holocaust","edit":"https://en.m.wikipedia.org/wiki/The_Holocaust?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:The_Holocaust"}},"extract":"The Holocaust was the genocide of European Jews during World War II. Between 1941 and 1945, Nazi Germany and its collaborators systematically murdered some six million Jews across German-occupied Europe, around two-thirds of Europe's Jewish population. The murders were carried out primarily through mass shootings and poison gas in extermination camps, chiefly Auschwitz-Birkenau, Treblinka, Belzec, Sobibor, and Chełmno in occupied Poland.","extract_html":"<p><b>The Holocaust</b> was the genocide of European Jews during World War II. Between 1941 and 1945, Nazi Germany and its collaborators systematically murdered some six million Jews across German-occupied Europe, around two-thirds of Europe's Jewish population. The murders were carried out primarily through mass shootings and poison gas in extermination camps, chiefly Auschwitz-Birkenau, Treblinka, Belzec, Sobibor, and Chełmno in occupied Poland.</p>","normalizedtitle":"The Holocaust"},{"type":"standard","title":"Operation_Harvest_Festival","displaytitle":"<span class=\"mw-page-title-main\">Operation Harvest Festival</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q153325","titles":{"canonical":"Operation_Harvest_Festival","normalized":"Operation Harvest Festival","display":"<span class=\"mw-page-title-main\">Operation Harvest Festival</span>"},"pageid":1012623,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/b/b4/Alinas_PL_Maceba_miejsce_zamordowania_18400_zydow_na_MajdankuP5130085.jpg/320px-Alinas_PL_Maceba_miejsce_zamordowania_18400_zydow_na_MajdankuP5130085.jpg","width":320,"height":240},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/b/b4/Alinas_PL_Maceba_miejsce_zamordowania_18400_zydow_na_MajdankuP5130085.jpg","width":2400,"height":1800},"lang":"en","dir":"ltr","revision":"1181547522","tid":"fe3130e0-781f-11ee-a7ae-a763cb936970","timestamp":"2023-10-23T18:45:59Z","description":"1943 massacre of Jews during the Holocaust","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Operation_Harvest_Festival","revisions":"https://en.wikipedia.org/wiki/Operation_Harvest_Festival?action=history","edit":"https://en.wikipedia.org/wiki/Operation_Harvest_Festival?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Operation_Harvest_Festival"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Operation_Harvest_Festival","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Operation_Harvest_Festival","edit":"https://en.m.wikipedia.org/wiki/Operation_Harvest_Festival?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Operation_Harvest_Festival"}},"extract":"Operation Harvest Festival was the murder of up to 43,000 Jews at the Majdanek, Poniatowa and Trawniki concentration camps by the SS, the Order Police battalions, and the Ukrainian Sonderdienst on 3–4 November 1943.","extract_html":"<p><b>Operation Harvest Festival</b> was the murder of up to 43,000 Jews at the Majdanek, Poniatowa and Trawniki concentration camps by the SS, the Order Police battalions, and the Ukrainian <i>Sonderdienst</i> on 3–4 November 1943.</p>","normalizedtitle":"Operation Harvest Festival"},{"type":"standard","title":"Majdanek_concentration_camp","displaytitle":"<span class=\"mw-page-title-main\">Majdanek concentration camp</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q160135","titles":{"canonical":"Majdanek_concentration_camp","normalized":"Majdanek concentration camp","display":"<span class=\"mw-page-title-main\">Majdanek concentration camp</span>"},"pageid":253575,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/0/02/2013_KL_Majdanek_crematorium_-_01.jpg/320px-2013_KL_Majdanek_crematorium_-_01.jpg","width":320,"height":240},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/0/02/2013_KL_Majdanek_crematorium_-_01.jpg","width":4896,"height":3672},"lang":"en","dir":"ltr","revision":"1181538897","tid":"b1584a20-780f-11ee-bf60-fbb4e76ada2b","timestamp":"2023-10-23T17:42:00Z","description":"Nazi concentration camp","description_source":"local","coordinates":{"lat":51.22055556,"lon":22.59944444},"content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Majdanek_concentration_camp","revisions":"https://en.wikipedia.org/wiki/Majdanek_concentration_camp?action=history","edit":"https://en.wikipedia.org/wiki/Majdanek_concentration_camp?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Majdanek_concentration_camp"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Majdanek_concentration_camp","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Majdanek_concentration_camp","edit":"https://en.m.wikipedia.org/wiki/Majdanek_concentration_camp?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Majdanek_concentration_camp"}},"extract":"\n","extract_html":"<p>\n</p>","normalizedtitle":"Majdanek concentration camp"}],"year":1943},{"text":"World War II: U.S. Marines and U.S. Army forces began an attempt to encircle and destroy a regiment of Imperial Japanese Army troops on Guadalcanal.","pages":[{"type":"standard","title":"World_War_II","displaytitle":"<span class=\"mw-page-title-main\">World War II</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q362","titles":{"canonical":"World_War_II","normalized":"World War II","display":"<span class=\"mw-page-title-main\">World War II</span>"},"pageid":32927,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/1/10/Bundesarchiv_Bild_101I-646-5188-17%2C_Flugzeuge_Junkers_Ju_87.jpg/320px-Bundesarchiv_Bild_101I-646-5188-17%2C_Flugzeuge_Junkers_Ju_87.jpg","width":320,"height":218},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/1/10/Bundesarchiv_Bild_101I-646-5188-17%2C_Flugzeuge_Junkers_Ju_87.jpg","width":798,"height":544},"lang":"en","dir":"ltr","revision":"1182572419","tid":"e9a8c200-7789-11ee-8ad5-3b5acf1dbf95","timestamp":"2023-10-30T03:07:13Z","description":"1939–1945 global conflict","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/World_War_II","revisions":"https://en.wikipedia.org/wiki/World_War_II?action=history","edit":"https://en.wikipedia.org/wiki/World_War_II?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:World_War_II"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/World_War_II","revisions":"https://en.m.wikipedia.org/wiki/Special:History/World_War_II","edit":"https://en.m.wikipedia.org/wiki/World_War_II?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:World_War_II"}},"extract":"World War II or the Second World War was a global conflict that lasted from 1939 to 1945.\nThe vast majority of the world's countries, including all the great powers, fought as part of two opposing military alliances: the Allies and the Axis. Many participants threw their economic, industrial, and scientific capabilities behind this total war, blurring the distinction between civilian and military resources. Aircraft played a major role, enabling the strategic bombing of population centres and delivery of the only two nuclear weapons ever used in war. It was by far the deadliest conflict in history, resulting in 70 to 85 million fatalities, mostly civilians. Millions died due to genocides, including the Holocaust, as well as starvation, massacres, and disease. In the wake of Axis defeat, Germany, Austria and Japan were occupied, and war crimes tribunals were conducted against German and Japanese leaders.","extract_html":"<p><b>World War II</b> or the <b>Second World War</b> was a global conflict that lasted from 1939 to 1945.\nThe vast majority of the world's countries, including all the great powers, fought as part of two opposing military alliances: the Allies and the Axis. Many participants threw their economic, industrial, and scientific capabilities behind this total war, blurring the distinction between civilian and military resources. Aircraft played a major role, enabling the strategic bombing of population centres and delivery of the only two nuclear weapons ever used in war. It was by far the deadliest conflict in history, resulting in 70 to 85 million fatalities, mostly civilians. Millions died due to genocides, including the Holocaust, as well as starvation, massacres, and disease. In the wake of Axis defeat, Germany, Austria and Japan were occupied, and war crimes tribunals were conducted against German and Japanese leaders.</p>","normalizedtitle":"World War II"},{"type":"standard","title":"United_States_Marine_Corps","displaytitle":"<span class=\"mw-page-title-main\">United States Marine Corps</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q11218","titles":{"canonical":"United_States_Marine_Corps","normalized":"United States Marine Corps","display":"<span class=\"mw-page-title-main\">United States Marine Corps</span>"},"pageid":17349325,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/9/9f/Emblem_of_the_United_States_Marine_Corps.svg/320px-Emblem_of_the_United_States_Marine_Corps.svg.png","width":320,"height":320},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/9/9f/Emblem_of_the_United_States_Marine_Corps.svg/720px-Emblem_of_the_United_States_Marine_Corps.svg.png","width":720,"height":720},"lang":"en","dir":"ltr","revision":"1182916135","tid":"a7eca960-797a-11ee-a834-81202bd61f9f","timestamp":"2023-11-01T04:34:51Z","description":"Maritime land force service branch of the U.S. military","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/United_States_Marine_Corps","revisions":"https://en.wikipedia.org/wiki/United_States_Marine_Corps?action=history","edit":"https://en.wikipedia.org/wiki/United_States_Marine_Corps?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:United_States_Marine_Corps"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/United_States_Marine_Corps","revisions":"https://en.m.wikipedia.org/wiki/Special:History/United_States_Marine_Corps","edit":"https://en.m.wikipedia.org/wiki/United_States_Marine_Corps?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:United_States_Marine_Corps"}},"extract":"The United States Marine Corps (USMC), also referred to as the United States Marines, is the maritime land force service branch of the United States Armed Forces responsible for conducting expeditionary and amphibious operations through combined arms, implementing its own infantry, artillery, aerial, and special operations forces. The U.S. Marine Corps is one of the eight uniformed services of the United States.","extract_html":"<p>The <b>United States Marine Corps</b> (<b>USMC</b>), also referred to as the <b>United States Marines</b>, is the maritime land force service branch of the United States Armed Forces responsible for conducting expeditionary and amphibious operations through combined arms, implementing its own infantry, artillery, aerial, and special operations forces. The U.S. Marine Corps is one of the eight uniformed services of the United States.</p>","normalizedtitle":"United States Marine Corps"},{"type":"standard","title":"United_States_Army","displaytitle":"<span class=\"mw-page-title-main\">United States Army</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q9212","titles":{"canonical":"United_States_Army","normalized":"United States Army","display":"<span class=\"mw-page-title-main\">United States Army</span>"},"pageid":32087,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/2/24/Mark_of_the_United_States_Army.svg/320px-Mark_of_the_United_States_Army.svg.png","width":320,"height":320},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/2/24/Mark_of_the_United_States_Army.svg/921px-Mark_of_the_United_States_Army.svg.png","width":921,"height":921},"lang":"en","dir":"ltr","revision":"1182987186","tid":"a74a9d00-797a-11ee-b7fe-2f1c42385a90","timestamp":"2023-11-01T15:44:20Z","description":"Land service branch of the U.S. military","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/United_States_Army","revisions":"https://en.wikipedia.org/wiki/United_States_Army?action=history","edit":"https://en.wikipedia.org/wiki/United_States_Army?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:United_States_Army"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/United_States_Army","revisions":"https://en.m.wikipedia.org/wiki/Special:History/United_States_Army","edit":"https://en.m.wikipedia.org/wiki/United_States_Army?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:United_States_Army"}},"extract":"The United States Army (USA) is the land service branch of the United States Armed Forces. It is one of the eight U.S. uniformed services, and is designated as the Army of the United States in the U.S. Constitution. The oldest and most senior branch of the U.S. military in order of precedence, the modern U.S. Army has its roots in the Continental Army, which was formed on 14 June 1775 to fight the American Revolutionary War (1775–1783)—against the British for independence before the United States was established as a country. After the Revolutionary War, the Congress of the Confederation created the United States Army on 3 June 1784 to replace the disbanded Continental Army. The United States Army considers itself a continuation of the Continental Army, and thus considers its institutional inception to be the origin of that armed force in 1775.","extract_html":"<p>The <b>United States Army</b> (<b>USA</b>) is the land service branch of the United States Armed Forces. It is one of the eight U.S. uniformed services, and is designated as the Army of the United States in the U.S. Constitution. The oldest and most senior branch of the U.S. military in order of precedence, the modern U.S. Army has its roots in the Continental Army, which was formed on 14 June 1775 to fight the American Revolutionary War (1775–1783)—against the British for independence before the United States was established as a country. After the Revolutionary War, the Congress of the Confederation created the United States Army on 3 June 1784 to replace the disbanded Continental Army. The United States Army considers itself a continuation of the Continental Army, and thus considers its institutional inception to be the origin of that armed force in 1775.</p>","normalizedtitle":"United States Army"},{"type":"standard","title":"Koli_Point_action","displaytitle":"<span class=\"mw-page-title-main\">Koli Point action</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q2394303","titles":{"canonical":"Koli_Point_action","normalized":"Koli Point action","display":"<span class=\"mw-page-title-main\">Koli Point action</span>"},"pageid":13931112,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/8/85/GuadKoliPoint75mm.jpg/320px-GuadKoliPoint75mm.jpg","width":320,"height":134},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/8/85/GuadKoliPoint75mm.jpg","width":2277,"height":951},"lang":"en","dir":"ltr","revision":"1183271868","tid":"eb155940-7a19-11ee-a213-93bb4cf86340","timestamp":"2023-11-03T07:23:40Z","description":"1942 Allied victory over Japan on Guadalcanal","description_source":"local","coordinates":{"lat":-9.45,"lon":160.17},"content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Koli_Point_action","revisions":"https://en.wikipedia.org/wiki/Koli_Point_action?action=history","edit":"https://en.wikipedia.org/wiki/Koli_Point_action?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Koli_Point_action"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Koli_Point_action","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Koli_Point_action","edit":"https://en.m.wikipedia.org/wiki/Koli_Point_action?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Koli_Point_action"}},"extract":"The Koli Point action, during 3–12 November 1942, was an engagement between U.S. Marine Corps and U.S. Army forces and Imperial Japanese Army forces around Koli Point on Guadalcanal during the Guadalcanal campaign. The U.S. forces were under the overall command of Major General Alexander Vandegrift, while the Japanese forces were under the overall command of Lieutenant General Harukichi Hyakutake.","extract_html":"<p>The <b>Koli Point action</b>, during 3–12 November 1942, was an engagement between U.S. Marine Corps and U.S. Army forces and Imperial Japanese Army forces around Koli Point on Guadalcanal during the Guadalcanal campaign. The U.S. forces were under the overall command of Major General Alexander Vandegrift, while the Japanese forces were under the overall command of Lieutenant General Harukichi Hyakutake.</p>","normalizedtitle":"Koli Point action"},{"type":"standard","title":"Imperial_Japanese_Army","displaytitle":"<span class=\"mw-page-title-main\">Imperial Japanese Army</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q276535","titles":{"canonical":"Imperial_Japanese_Army","normalized":"Imperial Japanese Army","display":"<span class=\"mw-page-title-main\">Imperial Japanese Army</span>"},"pageid":481708,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/6/6f/War_flag_of_the_Imperial_Japanese_Army_%281868%E2%80%931945%29.svg/320px-War_flag_of_the_Imperial_Japanese_Army_%281868%E2%80%931945%29.svg.png","width":320,"height":213},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/6/6f/War_flag_of_the_Imperial_Japanese_Army_%281868%E2%80%931945%29.svg/900px-War_flag_of_the_Imperial_Japanese_Army_%281868%E2%80%931945%29.svg.png","width":900,"height":600},"lang":"en","dir":"ltr","revision":"1183292163","tid":"650c25c0-7a3e-11ee-a59f-4348e89b22ce","timestamp":"2023-11-03T11:44:45Z","description":"Ground force of the Empire of Japan","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Imperial_Japanese_Army","revisions":"https://en.wikipedia.org/wiki/Imperial_Japanese_Army?action=history","edit":"https://en.wikipedia.org/wiki/Imperial_Japanese_Army?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Imperial_Japanese_Army"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Imperial_Japanese_Army","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Imperial_Japanese_Army","edit":"https://en.m.wikipedia.org/wiki/Imperial_Japanese_Army?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Imperial_Japanese_Army"}},"extract":"The Imperial Japanese Army  (IJA) was the principal ground force of the Empire of Japan. Forming one of the military branches of the Imperial Japanese Armed Forces (IJAF), it was controlled by the Imperial Japanese Army General Staff Office and the Army Ministry, both of which were nominally subordinate to the Emperor of Japan, the supreme commander of IJAF. During the 20th century, an Inspectorate General of Aviation became the third agency with oversight of the IJA. At its height, the IJA was one of the most influential factions in the politics of Japan and was one of the most powerful armies in the world. The IJA was also notorious for committing numerous war crimes during the Second Sino-Japanese War and the Pacific War, such as the Nanjing Massacre and the Bataan Death March.","extract_html":"<p>The <b>Imperial Japanese Army</b><span style=\"font-weight:normal\"> </span> (IJA) was the principal ground force of the Empire of Japan. Forming one of the military branches of the Imperial Japanese Armed Forces (IJAF), it was controlled by the Imperial Japanese Army General Staff Office and the Army Ministry, both of which were nominally subordinate to the Emperor of Japan, the supreme commander of IJAF. During the 20th century, an Inspectorate General of Aviation became the third agency with oversight of the IJA. At its height, the IJA was one of the most influential factions in the politics of Japan and was one of the most powerful armies in the world. The IJA was also notorious for committing numerous war crimes during the Second Sino-Japanese War and the Pacific War, such as the Nanjing Massacre and the Bataan Death March.</p>","normalizedtitle":"Imperial Japanese Army"},{"type":"standard","title":"Guadalcanal","displaytitle":"<span class=\"mw-page-title-main\">Guadalcanal</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q192767","titles":{"canonical":"Guadalcanal","normalized":"Guadalcanal","display":"<span class=\"mw-page-title-main\">Guadalcanal</span>"},"pageid":113645,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/f/fb/GuadalcanalCloseup.png/320px-GuadalcanalCloseup.png","width":320,"height":229},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/f/fb/GuadalcanalCloseup.png","width":550,"height":394},"lang":"en","dir":"ltr","revision":"1183279610","tid":"f7e710a0-7a28-11ee-bae9-81c8c20ff677","timestamp":"2023-11-03T09:11:24Z","description":"Principal island of Solomon Islands","description_source":"local","coordinates":{"lat":-9.59,"lon":160.235},"content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Guadalcanal","revisions":"https://en.wikipedia.org/wiki/Guadalcanal?action=history","edit":"https://en.wikipedia.org/wiki/Guadalcanal?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Guadalcanal"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Guadalcanal","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Guadalcanal","edit":"https://en.m.wikipedia.org/wiki/Guadalcanal?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Guadalcanal"}},"extract":"Guadalcanal is the principal island in Guadalcanal Province of the Solomon Islands, located in the southwestern Pacific Ocean, northeast of Australia. It is the largest island in the Solomons by area and the second-largest by population. The island is mainly covered in dense tropical rainforest and has a mountainous hinterland.","extract_html":"<p><b>Guadalcanal</b> is the principal island in Guadalcanal Province of the Solomon Islands, located in the southwestern Pacific Ocean, northeast of Australia. It is the largest island in the Solomons by area and the second-largest by population. The island is mainly covered in dense tropical rainforest and has a mountainous hinterland.</p>","normalizedtitle":"Guadalcanal"}],"year":1942},{"text":"Almost 98 percent of reported votes in a Greek referendum supported the restoration of George II as King of the Hellenes.","pages":[{"type":"standard","title":"1935_Greek_monarchy_referendum","displaytitle":"<span class=\"mw-page-title-main\">1935 Greek monarchy referendum</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q3454881","titles":{"canonical":"1935_Greek_monarchy_referendum","normalized":"1935 Greek monarchy referendum","display":"<span class=\"mw-page-title-main\">1935 Greek monarchy referendum</span>"},"pageid":4150356,"lang":"en","dir":"ltr","revision":"1136866727","tid":"bf05f9d0-67dc-11ee-9264-77505a975220","timestamp":"2023-02-01T15:31:46Z","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/1935_Greek_monarchy_referendum","revisions":"https://en.wikipedia.org/wiki/1935_Greek_monarchy_referendum?action=history","edit":"https://en.wikipedia.org/wiki/1935_Greek_monarchy_referendum?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:1935_Greek_monarchy_referendum"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/1935_Greek_monarchy_referendum","revisions":"https://en.m.wikipedia.org/wiki/Special:History/1935_Greek_monarchy_referendum","edit":"https://en.m.wikipedia.org/wiki/1935_Greek_monarchy_referendum?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:1935_Greek_monarchy_referendum"}},"extract":"A referendum on restoring the monarchy was held in Greece on 3 November 1935. The proposal was approved by nearly 97.9% of voters, although the conduct during the referendum is not considered to have been free or fair. George II returned from exile and was restored to the throne on 25 November 1935.","extract_html":"<p>A referendum on restoring the monarchy was held in Greece on 3 November 1935. The proposal was approved by nearly 97.9% of voters, although the conduct during the referendum is not considered to have been free or fair. George II returned from exile and was restored to the throne on 25 November 1935.</p>","normalizedtitle":"1935 Greek monarchy referendum"},{"type":"standard","title":"George_II_of_Greece","displaytitle":"<span class=\"mw-page-title-main\">George II of Greece</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q152935","titles":{"canonical":"George_II_of_Greece","normalized":"George II of Greece","display":"<span class=\"mw-page-title-main\">George II of Greece</span>"},"pageid":160203,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/5/58/Georgeiiofgreece.jpg/320px-Georgeiiofgreece.jpg","width":320,"height":441},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/5/58/Georgeiiofgreece.jpg","width":1593,"height":2197},"lang":"en","dir":"ltr","revision":"1178633227","tid":"930b5650-778a-11ee-865c-e5af8cde6d32","timestamp":"2023-10-04T22:18:55Z","description":"King of Greece from 1922 to 1924 and 1935 to 1947)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/George_II_of_Greece","revisions":"https://en.wikipedia.org/wiki/George_II_of_Greece?action=history","edit":"https://en.wikipedia.org/wiki/George_II_of_Greece?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:George_II_of_Greece"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/George_II_of_Greece","revisions":"https://en.m.wikipedia.org/wiki/Special:History/George_II_of_Greece","edit":"https://en.m.wikipedia.org/wiki/George_II_of_Greece?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:George_II_of_Greece"}},"extract":"George II was King of Greece from 27 September 1922 until 25 March 1924 and from 25 November 1935 until his death in 1947.","extract_html":"<p><b>George II</b> was King of Greece from 27 September 1922 until 25 March 1924 and from 25 November 1935 until his death in 1947.</p>","normalizedtitle":"George II of Greece"},{"type":"standard","title":"List_of_kings_of_Greece","displaytitle":"<span class=\"mw-page-title-main\">List of kings of Greece</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q2198995","titles":{"canonical":"List_of_kings_of_Greece","normalized":"List of kings of Greece","display":"<span class=\"mw-page-title-main\">List of kings of Greece</span>"},"pageid":40941755,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/a/af/Royal_Coat_of_Arms_of_Greece.svg/320px-Royal_Coat_of_Arms_of_Greece.svg.png","width":320,"height":376},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/a/af/Royal_Coat_of_Arms_of_Greece.svg/512px-Royal_Coat_of_Arms_of_Greece.svg.png","width":512,"height":602},"lang":"en","dir":"ltr","revision":"1159370750","tid":"a08339a0-67ff-11ee-bf52-f9c3765f1fe0","timestamp":"2023-06-09T22:07:28Z","description":"List of rulers of the Kingdom of Greece","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/List_of_kings_of_Greece","revisions":"https://en.wikipedia.org/wiki/List_of_kings_of_Greece?action=history","edit":"https://en.wikipedia.org/wiki/List_of_kings_of_Greece?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:List_of_kings_of_Greece"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/List_of_kings_of_Greece","revisions":"https://en.m.wikipedia.org/wiki/Special:History/List_of_kings_of_Greece","edit":"https://en.m.wikipedia.org/wiki/List_of_kings_of_Greece?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:List_of_kings_of_Greece"}},"extract":"The Kingdom of Greece was ruled by the House of Wittelsbach from 1832 to 1862 and by the House of Glücksburg from 1863 to 1924 and, after being temporarily abolished in favor of the Second Hellenic Republic, again from 1935 to 1973, when it was once more abolished and replaced by the Third Hellenic Republic.","extract_html":"<p>The Kingdom of Greece was ruled by the House of Wittelsbach from 1832 to 1862 and by the House of Glücksburg from 1863 to 1924 and, after being temporarily abolished in favor of the Second Hellenic Republic, again from 1935 to 1973, when it was once more abolished and replaced by the Third Hellenic Republic.</p>","normalizedtitle":"List of kings of Greece"}],"year":1935},{"text":"The Fashoda Incident ended with French forces withdrawing after several months of military stalemate with the British in Fashoda (now in South Sudan).","pages":[{"type":"standard","title":"Fashoda_Incident","displaytitle":"<span class=\"mw-page-title-main\">Fashoda Incident</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q722699","titles":{"canonical":"Fashoda_Incident","normalized":"Fashoda Incident","display":"<span class=\"mw-page-title-main\">Fashoda Incident</span>"},"pageid":283542,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/f/fc/Fashoda_Incident_map_-_en.svg/320px-Fashoda_Incident_map_-_en.svg.png","width":320,"height":259},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/f/fc/Fashoda_Incident_map_-_en.svg/3384px-Fashoda_Incident_map_-_en.svg.png","width":3384,"height":2740},"lang":"en","dir":"ltr","revision":"1183285787","tid":"6088cc10-7a34-11ee-97cf-6f1e1569e40e","timestamp":"2023-11-03T10:33:05Z","description":"1898 Anglo-French dispute in East Africa","description_source":"local","coordinates":{"lat":9.8875,"lon":32.11027778},"content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Fashoda_Incident","revisions":"https://en.wikipedia.org/wiki/Fashoda_Incident?action=history","edit":"https://en.wikipedia.org/wiki/Fashoda_Incident?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Fashoda_Incident"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Fashoda_Incident","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Fashoda_Incident","edit":"https://en.m.wikipedia.org/wiki/Fashoda_Incident?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Fashoda_Incident"}},"extract":"The Fashoda Incident, also known as the Fashoda Crisis, was an international incident and the climax of imperialist territorial disputes between Britain and France in East Africa, occurring in 1898. A French expedition to Fashoda on the White Nile sought to gain control of the Upper Nile river basin and thereby exclude Britain from Sudan. The French party and a British-Egyptian force met on friendly terms, but back in Europe it became a war scare. The British held firm as both empires stood on the verge of war with heated rhetoric on both sides. Under heavy pressure, the French withdrew, ensuring Anglo-Egyptian control over the area.","extract_html":"<p>The <b>Fashoda Incident</b>, also known as the <b>Fashoda Crisis</b>, was an international incident and the climax of imperialist territorial disputes between Britain and France in East Africa, occurring in 1898. A French expedition to Fashoda on the White Nile sought to gain control of the Upper Nile river basin and thereby exclude Britain from Sudan. The French party and a British-Egyptian force met on friendly terms, but back in Europe it became a war scare. The British held firm as both empires stood on the verge of war with heated rhetoric on both sides. Under heavy pressure, the French withdrew, ensuring Anglo-Egyptian control over the area.</p>","normalizedtitle":"Fashoda Incident"},{"type":"standard","title":"Kodok","displaytitle":"<span class=\"mw-page-title-main\">Kodok</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q1888763","titles":{"canonical":"Kodok","normalized":"Kodok","display":"<span class=\"mw-page-title-main\">Kodok</span>"},"pageid":1515533,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/9/95/Fashoda_-_The_Governor%27s_House_%281906%29_-_TIMEA.jpg/320px-Fashoda_-_The_Governor%27s_House_%281906%29_-_TIMEA.jpg","width":320,"height":151},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/9/95/Fashoda_-_The_Governor%27s_House_%281906%29_-_TIMEA.jpg","width":993,"height":468},"lang":"en","dir":"ltr","revision":"1183269215","tid":"d50afb80-7a16-11ee-88a8-216763b7aa0a","timestamp":"2023-11-03T07:01:35Z","description":"Place in Upper Nile State, South Sudan","description_source":"local","coordinates":{"lat":9.8875,"lon":32.11027778},"content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Kodok","revisions":"https://en.wikipedia.org/wiki/Kodok?action=history","edit":"https://en.wikipedia.org/wiki/Kodok?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Kodok"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Kodok","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Kodok","edit":"https://en.m.wikipedia.org/wiki/Kodok?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Kodok"}},"extract":"Kodok or Kothok, formerly known as Fashoda, is a town in the north-eastern South Sudanese state of Upper Nile. Kodok is the capital of Shilluk country, formally known as the Shilluk Kingdom. Shilluk had been an independent kingdom for more than sixteen centuries. Fashoda is best known as the place where the British and French nearly went to war in 1898 in the Fashoda Incident.","extract_html":"<p><b>Kodok</b> or <b>Kothok</b>, formerly known as <b>Fashoda</b>, is a town in the north-eastern South Sudanese state of Upper Nile. Kodok is the capital of Shilluk country, formally known as the Shilluk Kingdom. Shilluk had been an independent kingdom for more than sixteen centuries. Fashoda is best known as the place where the British and French nearly went to war in 1898 in the Fashoda Incident.</p>","normalizedtitle":"Kodok"}],"year":1898},{"text":"Indigenous Mapuche began an uprising against the occupation of Araucanía by Chile.","pages":[{"type":"standard","title":"Mapuche","displaytitle":"<span class=\"mw-page-title-main\">Mapuche</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q178484","titles":{"canonical":"Mapuche","normalized":"Mapuche","display":"<span class=\"mw-page-title-main\">Mapuche</span>"},"pageid":392305,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/4/46/Mujeres_mapuches_en_la_entrega_terreno_a_Comunidad_Mapuche_Lorenzo_Quintrileo_de_Tir%C3%BAa.jpg/320px-Mujeres_mapuches_en_la_entrega_terreno_a_Comunidad_Mapuche_Lorenzo_Quintrileo_de_Tir%C3%BAa.jpg","width":320,"height":213},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/4/46/Mujeres_mapuches_en_la_entrega_terreno_a_Comunidad_Mapuche_Lorenzo_Quintrileo_de_Tir%C3%BAa.jpg","width":5184,"height":3456},"lang":"en","dir":"ltr","revision":"1182407326","tid":"063eb360-7614-11ee-87c0-e3a5ebc06e58","timestamp":"2023-10-29T04:31:23Z","description":"Ethnic group in South America","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Mapuche","revisions":"https://en.wikipedia.org/wiki/Mapuche?action=history","edit":"https://en.wikipedia.org/wiki/Mapuche?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Mapuche"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Mapuche","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Mapuche","edit":"https://en.m.wikipedia.org/wiki/Mapuche?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Mapuche"}},"extract":"The Mapuche is a group of native indigenous inhabitants of south-central Chile and southwestern Argentina, including parts of Patagonia. The collective term refers to a wide-ranging ethnicity composed of various groups who share a common social, religious, and economic structure, as well as a common linguistic heritage as Mapudungun speakers. Their homelands once extended from Aconcagua Valley to the Chiloé Archipelago and later spread eastward to Puelmapu, a land comprising part of the Argentine pampa and Patagonia. Today the collective group makes up over 80% of the indigenous peoples in Chile and about 9% of the total Chilean population. The Mapuche are concentrated in the Araucanía region. Many have migrated from rural areas to the cities of Santiago and Buenos Aires for economic opportunities.","extract_html":"<p>The <b>Mapuche</b> is a group of native indigenous inhabitants of south-central Chile and southwestern Argentina, including parts of Patagonia. The collective term refers to a wide-ranging ethnicity composed of various groups who share a common social, religious, and economic structure, as well as a common linguistic heritage as Mapudungun speakers. Their homelands once extended from Aconcagua Valley to the Chiloé Archipelago and later spread eastward to Puelmapu, a land comprising part of the Argentine pampa and Patagonia. Today the collective group makes up over 80% of the indigenous peoples in Chile and about 9% of the total Chilean population. The Mapuche are concentrated in the Araucanía region. Many have migrated from rural areas to the cities of Santiago and Buenos Aires for economic opportunities.</p>","normalizedtitle":"Mapuche"},{"type":"standard","title":"Mapuche_uprising_of_1881","displaytitle":"<span class=\"mw-page-title-main\">Mapuche uprising of 1881</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q16824925","titles":{"canonical":"Mapuche_uprising_of_1881","normalized":"Mapuche uprising of 1881","display":"<span class=\"mw-page-title-main\">Mapuche uprising of 1881</span>"},"pageid":41575537,"lang":"en","dir":"ltr","revision":"1124834626","tid":"2d8873b0-6800-11ee-986d-91c16720e09e","timestamp":"2022-11-30T19:20:14Z","description":"1881 native uprising against the Chilean occupation of Araucanía","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Mapuche_uprising_of_1881","revisions":"https://en.wikipedia.org/wiki/Mapuche_uprising_of_1881?action=history","edit":"https://en.wikipedia.org/wiki/Mapuche_uprising_of_1881?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Mapuche_uprising_of_1881"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Mapuche_uprising_of_1881","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Mapuche_uprising_of_1881","edit":"https://en.m.wikipedia.org/wiki/Mapuche_uprising_of_1881?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Mapuche_uprising_of_1881"}},"extract":"The last major rebellion of the indigenous Mapuches of Araucanía took place in 1881, during the last phase of the Occupation of Araucanía (1861–1883) by the Chilean state. It was planned by Mapuche chiefs in March 1881 to be launched in November the same year. Mapuche support for the uprising was not unanimous: Some Mapuche factions sided with the Chileans and others declared themselves neutral. The organizers of the uprising did however succeed in involving Mapuche factions that had not previously been at war with Chile. With most of the attacks repelled within a matters of days Chile went on the next years to consolidate its conquests.","extract_html":"<p>The last major rebellion of the indigenous Mapuches of Araucanía took place in 1881, during the last phase of the Occupation of Araucanía (1861–1883) by the Chilean state. It was planned by Mapuche chiefs in March 1881 to be launched in November the same year. Mapuche support for the uprising was not unanimous: Some Mapuche factions sided with the Chileans and others declared themselves neutral. The organizers of the uprising did however succeed in involving Mapuche factions that had not previously been at war with Chile. With most of the attacks repelled within a matters of days Chile went on the next years to consolidate its conquests.</p>","normalizedtitle":"Mapuche uprising of 1881"},{"type":"standard","title":"Occupation_of_Araucanía","displaytitle":"<span class=\"mw-page-title-main\">Occupation of Araucanía</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q2422135","titles":{"canonical":"Occupation_of_Araucanía","normalized":"Occupation of Araucanía","display":"<span class=\"mw-page-title-main\">Occupation of Araucanía</span>"},"pageid":8887430,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/d/dd/Fuerte_de_Pur%C3%A9n_Chile.jpg/320px-Fuerte_de_Pur%C3%A9n_Chile.jpg","width":320,"height":240},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/d/dd/Fuerte_de_Pur%C3%A9n_Chile.jpg","width":1280,"height":960},"lang":"en","dir":"ltr","revision":"1174100828","tid":"f91c90a0-67e3-11ee-adbf-837b5dfb5396","timestamp":"2023-09-06T09:39:43Z","description":"Series of incursions by the Chilean army and settlers into Mapuche territory (1861-83)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Occupation_of_Araucan%C3%ADa","revisions":"https://en.wikipedia.org/wiki/Occupation_of_Araucan%C3%ADa?action=history","edit":"https://en.wikipedia.org/wiki/Occupation_of_Araucan%C3%ADa?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Occupation_of_Araucan%C3%ADa"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Occupation_of_Araucan%C3%ADa","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Occupation_of_Araucan%C3%ADa","edit":"https://en.m.wikipedia.org/wiki/Occupation_of_Araucan%C3%ADa?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Occupation_of_Araucan%C3%ADa"}},"extract":"The Occupation of Araucanía or Pacification of Araucanía (1861–1883) was a series of military campaigns, agreements and penetrations by the Chilean army and settlers into Mapuche territory which led to the incorporation of Araucanía into Chilean national territory. Pacification of Araucanía was the expression used by the Chilean authorities for this process. The conflict was concurrent with Argentine campaigns against the Mapuche (1878–1885) and Chile's wars with Spain (1865–1866) and with Peru and Bolivia (1879–1883).","extract_html":"<p>The <b>Occupation of Araucanía</b> or <b>Pacification of Araucanía</b> (1861–1883) was a series of military campaigns, agreements and penetrations by the Chilean army and settlers into Mapuche territory which led to the incorporation of Araucanía into Chilean national territory. <i>Pacification of Araucanía</i> was the expression used by the Chilean authorities for this process. The conflict was concurrent with Argentine campaigns against the Mapuche (1878–1885) and Chile's wars with Spain (1865–1866) and with Peru and Bolivia (1879–1883).</p>","normalizedtitle":"Occupation of Araucanía"},{"type":"standard","title":"Araucanía_(historic_region)","displaytitle":"<span class=\"mw-page-title-main\">Araucanía (historic region)</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q3492932","titles":{"canonical":"Araucanía_(historic_region)","normalized":"Araucanía (historic region)","display":"<span class=\"mw-page-title-main\">Araucanía (historic region)</span>"},"pageid":1046545,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/7/75/Change_of_Chile_frontier_border_in_the_Occupation_of_the_Araucan%C3%ADa_-_1870.jpg/320px-Change_of_Chile_frontier_border_in_the_Occupation_of_the_Araucan%C3%ADa_-_1870.jpg","width":320,"height":402},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/7/75/Change_of_Chile_frontier_border_in_the_Occupation_of_the_Araucan%C3%ADa_-_1870.jpg","width":577,"height":725},"lang":"en","dir":"ltr","revision":"1181806947","tid":"e22f8e30-731c-11ee-9e29-b9eb15ac887b","timestamp":"2023-10-25T09:57:17Z","description":"Historic indigenously-inhabited region of Chile","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Araucan%C3%ADa_(historic_region)","revisions":"https://en.wikipedia.org/wiki/Araucan%C3%ADa_(historic_region)?action=history","edit":"https://en.wikipedia.org/wiki/Araucan%C3%ADa_(historic_region)?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Araucan%C3%ADa_(historic_region)"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Araucan%C3%ADa_(historic_region)","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Araucan%C3%ADa_(historic_region)","edit":"https://en.m.wikipedia.org/wiki/Araucan%C3%ADa_(historic_region)?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Araucan%C3%ADa_(historic_region)"}},"extract":"Araucanía or Araucana was the Spanish name given to the region of Chile inhabited by the Mapuche peoples known as the Moluche in the 18th century. Prior to the Spanish conquest of Chile, the lands of the Moluche lay between the Itata River and Toltén River.","extract_html":"<p><b>Araucanía</b> or <b>Araucana</b> was the Spanish name given to the region of Chile inhabited by the Mapuche peoples known as the Moluche in the 18th century. Prior to the Spanish conquest of Chile, the lands of the Moluche lay between the Itata River and Toltén River.</p>","normalizedtitle":"Araucanía (historic region)"}],"year":1881},{"text":"The current melody of Kimigayo, the national anthem of Japan, was adopted.","pages":[{"type":"standard","title":"Kimigayo","displaytitle":"<span class=\"mw-page-title-main\">Kimigayo</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q81534","titles":{"canonical":"Kimigayo","normalized":"Kimigayo","display":"<span class=\"mw-page-title-main\">Kimigayo</span>"},"pageid":147709,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/e/ec/Kimigayo.score.svg/320px-Kimigayo.score.svg.png","width":320,"height":225},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/e/ec/Kimigayo.score.svg/525px-Kimigayo.score.svg.png","width":525,"height":369},"lang":"en","dir":"ltr","revision":"1176986711","tid":"fee77260-7199-11ee-b09e-a3d42a4bbd9d","timestamp":"2023-09-25T06:35:10Z","description":"National anthem of Japan","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Kimigayo","revisions":"https://en.wikipedia.org/wiki/Kimigayo?action=history","edit":"https://en.wikipedia.org/wiki/Kimigayo?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Kimigayo"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Kimigayo","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Kimigayo","edit":"https://en.m.wikipedia.org/wiki/Kimigayo?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Kimigayo"}},"extract":"\"Kimigayo\"  is the national anthem of Japan. The lyrics are from a waka poem written by an unnamed author in the Heian period (794–1185), and the current melody was chosen in 1880, replacing an unpopular melody composed by John William Fenton eleven years earlier. While the title \"Kimigayo\" is usually translated as \"His Imperial Majesty's Reign\", no official translation of the title or lyrics has been established in law.","extract_html":"<p>\"<b>Kimigayo</b>\"<span style=\"font-weight:normal\"> </span> is the national anthem of Japan. The lyrics are from a <i><span><i lang=\"ja-Latn\">waka</i></span></i> poem written by an unnamed author in the Heian period (794–1185), and the current melody was chosen in 1880, replacing an unpopular melody composed by John William Fenton eleven years earlier. While the title \"Kimigayo\" is usually translated as \"His Imperial Majesty's Reign\", no official translation of the title or lyrics has been established in law.</p>","normalizedtitle":"Kimigayo"},{"type":"standard","title":"National_anthem","displaytitle":"<span class=\"mw-page-title-main\">National anthem</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q23691","titles":{"canonical":"National_anthem","normalized":"National anthem","display":"<span class=\"mw-page-title-main\">National anthem</span>"},"pageid":234540,"lang":"en","dir":"ltr","revision":"1182659653","tid":"11ac7b00-7741-11ee-9501-5d0bffda7bbd","timestamp":"2023-10-30T16:26:21Z","description":"Song that represents a country or sovereign state","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/National_anthem","revisions":"https://en.wikipedia.org/wiki/National_anthem?action=history","edit":"https://en.wikipedia.org/wiki/National_anthem?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:National_anthem"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/National_anthem","revisions":"https://en.m.wikipedia.org/wiki/Special:History/National_anthem","edit":"https://en.m.wikipedia.org/wiki/National_anthem?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:National_anthem"}},"extract":"A national anthem is a patriotic musical composition symbolizing and evoking eulogies of the history and traditions of a country or nation. The majority of national anthems are marches or hymns in style. American, Central Asian, and European nations tend towards more ornate and operatic pieces, while those in the Middle East, Oceania, Africa, and the Caribbean use a more simplistic fanfare. Some countries that are devolved into multiple constituent states have their own official musical compositions for them ; their constituencies' songs are sometimes referred to as national anthems even though they are not sovereign states.","extract_html":"<p>A <b>national anthem</b> is a patriotic musical composition symbolizing and evoking eulogies of the history and traditions of a country or nation. The majority of national anthems are marches or hymns in style. American, Central Asian, and European nations tend towards more ornate and operatic pieces, while those in the Middle East, Oceania, Africa, and the Caribbean use a more simplistic fanfare. Some countries that are devolved into multiple constituent states have their own official musical compositions for them ; their constituencies' songs are sometimes referred to as national anthems even though they are not sovereign states.</p>","normalizedtitle":"National anthem"}],"year":1880},{"text":"A new constitution drafted by Johan Rudolph Thorbecke was proclaimed, limiting the powers of the Dutch monarchy.","pages":[{"type":"standard","title":"Constitution_of_the_Netherlands","displaytitle":"<span class=\"mw-page-title-main\">Constitution of the Netherlands</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q2299064","titles":{"canonical":"Constitution_of_the_Netherlands","normalized":"Constitution of the Netherlands","display":"<span class=\"mw-page-title-main\">Constitution of the Netherlands</span>"},"pageid":70124,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/8/8f/State_coat_of_arms_of_the_Netherlands.svg/320px-State_coat_of_arms_of_the_Netherlands.svg.png","width":320,"height":252},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/8/8f/State_coat_of_arms_of_the_Netherlands.svg/756px-State_coat_of_arms_of_the_Netherlands.svg.png","width":756,"height":595},"lang":"en","dir":"ltr","revision":"1173394224","tid":"273c8be0-7363-11ee-a46e-6d60780108da","timestamp":"2023-09-02T04:12:44Z","description":"Basic law of the Netherlands","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Constitution_of_the_Netherlands","revisions":"https://en.wikipedia.org/wiki/Constitution_of_the_Netherlands?action=history","edit":"https://en.wikipedia.org/wiki/Constitution_of_the_Netherlands?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Constitution_of_the_Netherlands"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Constitution_of_the_Netherlands","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Constitution_of_the_Netherlands","edit":"https://en.m.wikipedia.org/wiki/Constitution_of_the_Netherlands?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Constitution_of_the_Netherlands"}},"extract":"The Constitution for the Kingdom of the Netherlands is one of two fundamental documents governing the Kingdom of the Netherlands as well as the fundamental law of the European territory of the Kingdom of the Netherlands. It is generally seen as directly derived from the one issued in 1815, constituting a constitutional monarchy; it is the third oldest constitution still in use worldwide.","extract_html":"<p>The <b>Constitution for the Kingdom of the Netherlands</b> is one of two fundamental documents governing the Kingdom of the Netherlands as well as the fundamental law of the European territory of the Kingdom of the Netherlands. It is generally seen as directly derived from the one issued in 1815, constituting a constitutional monarchy; it is the third oldest constitution still in use worldwide.</p>","normalizedtitle":"Constitution of the Netherlands"},{"type":"standard","title":"Johan_Rudolph_Thorbecke","displaytitle":"<span class=\"mw-page-title-main\">Johan Rudolph Thorbecke</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q182509","titles":{"canonical":"Johan_Rudolph_Thorbecke","normalized":"Johan Rudolph Thorbecke","display":"<span class=\"mw-page-title-main\">Johan Rudolph Thorbecke</span>"},"pageid":23690058,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/7/7a/Johan_Heinrich_Neuman_-_Johan_Rudolf_Thorbecke.jpg/320px-Johan_Heinrich_Neuman_-_Johan_Rudolf_Thorbecke.jpg","width":320,"height":386},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/7/7a/Johan_Heinrich_Neuman_-_Johan_Rudolf_Thorbecke.jpg","width":2075,"height":2500},"lang":"en","dir":"ltr","revision":"1179984116","tid":"d9306230-6ea5-11ee-94ae-23a5cb411197","timestamp":"2023-10-13T18:46:33Z","description":"Dutch politician (1798–1872)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Johan_Rudolph_Thorbecke","revisions":"https://en.wikipedia.org/wiki/Johan_Rudolph_Thorbecke?action=history","edit":"https://en.wikipedia.org/wiki/Johan_Rudolph_Thorbecke?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Johan_Rudolph_Thorbecke"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Johan_Rudolph_Thorbecke","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Johan_Rudolph_Thorbecke","edit":"https://en.m.wikipedia.org/wiki/Johan_Rudolph_Thorbecke?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Johan_Rudolph_Thorbecke"}},"extract":"Johan Rudolph Thorbecke was a Dutch liberal statesman, one of the most important Dutch politicians of the 19th century. Thorbecke is best known for heading the commission that drafted the revision of the Constitution of the Netherlands in 1848, amidst the liberal democratic revolutions of 1848. The new constitution transformed the country from an absolute monarchy into a constitutional monarchy, with the States General and the Council of Ministers becoming more powerful than the king. The amended constitution also granted individual rights to residents and citizens of the kingdom. This made the constitution one of the more progressive at the time. Thorbecke is generally considered a founding father of the modern political system of the Netherlands.","extract_html":"<p><b>Johan Rudolph Thorbecke</b> was a Dutch liberal statesman, one of the most important Dutch politicians of the 19th century. Thorbecke is best known for heading the commission that drafted the revision of the Constitution of the Netherlands in 1848, amidst the liberal democratic revolutions of 1848. The new constitution transformed the country from an absolute monarchy into a constitutional monarchy, with the States General and the Council of Ministers becoming more powerful than the king. The amended constitution also granted individual rights to residents and citizens of the kingdom. This made the constitution one of the more progressive at the time. Thorbecke is generally considered a founding father of the modern political system of the Netherlands.</p>","normalizedtitle":"Johan Rudolph Thorbecke"},{"type":"standard","title":"Constitutional_Reform_of_1848","displaytitle":"<span class=\"mw-page-title-main\">Constitutional Reform of 1848</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q2330714","titles":{"canonical":"Constitutional_Reform_of_1848","normalized":"Constitutional Reform of 1848","display":"<span class=\"mw-page-title-main\">Constitutional Reform of 1848</span>"},"pageid":46659715,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/2/26/Grondwet_1848_%281%29.JPG/320px-Grondwet_1848_%281%29.JPG","width":320,"height":240},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/2/26/Grondwet_1848_%281%29.JPG","width":3648,"height":2736},"lang":"en","dir":"ltr","revision":"1028255856","tid":"44abb8c0-62a3-11ee-885f-edf770f86ad7","timestamp":"2021-06-12T20:53:15Z","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Constitutional_Reform_of_1848","revisions":"https://en.wikipedia.org/wiki/Constitutional_Reform_of_1848?action=history","edit":"https://en.wikipedia.org/wiki/Constitutional_Reform_of_1848?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Constitutional_Reform_of_1848"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Constitutional_Reform_of_1848","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Constitutional_Reform_of_1848","edit":"https://en.m.wikipedia.org/wiki/Constitutional_Reform_of_1848?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Constitutional_Reform_of_1848"}},"extract":"The Constitutional Reform of 1848 laid the basis for the present system of parliamentary democracy in the Netherlands. It is often described as the original version of the Dutch Constitution that is still in force today. Under pressure from the Revolutions of 1848 in surrounding countries, King William II agreed to several demands of the liberal parliamentary opposition. The House of Representatives obtained much more influence, and was now directly elected. The reform was in some sense a peaceful revolution, in which liberal politician Johan Rudolph Thorbecke and King William II played important roles.","extract_html":"<p>The <b>Constitutional Reform of 1848</b> laid the basis for the present system of parliamentary democracy in the Netherlands. It is often described as the original version of the Dutch Constitution that is still in force today. Under pressure from the Revolutions of 1848 in surrounding countries, King William II agreed to several demands of the liberal parliamentary opposition. The House of Representatives obtained much more influence, and was now directly elected. The reform was in some sense a peaceful revolution, in which liberal politician Johan Rudolph Thorbecke and King William II played important roles.</p>","normalizedtitle":"Constitutional Reform of 1848"},{"type":"standard","title":"Monarchy_of_the_Netherlands","displaytitle":"<span class=\"mw-page-title-main\">Monarchy of the Netherlands</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q302958","titles":{"canonical":"Monarchy_of_the_Netherlands","normalized":"Monarchy of the Netherlands","display":"<span class=\"mw-page-title-main\">Monarchy of the Netherlands</span>"},"pageid":23416611,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/e/ea/Royal_coat_of_arms_of_the_Netherlands.svg/320px-Royal_coat_of_arms_of_the_Netherlands.svg.png","width":320,"height":351},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/e/ea/Royal_coat_of_arms_of_the_Netherlands.svg/952px-Royal_coat_of_arms_of_the_Netherlands.svg.png","width":952,"height":1045},"lang":"en","dir":"ltr","revision":"1183097677","tid":"13926ef0-7937-11ee-bd67-81623dbbb3b9","timestamp":"2023-11-02T04:19:50Z","description":"Constitutional and hereditary monarchy of the Kingdom of the Netherlands","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Monarchy_of_the_Netherlands","revisions":"https://en.wikipedia.org/wiki/Monarchy_of_the_Netherlands?action=history","edit":"https://en.wikipedia.org/wiki/Monarchy_of_the_Netherlands?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Monarchy_of_the_Netherlands"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Monarchy_of_the_Netherlands","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Monarchy_of_the_Netherlands","edit":"https://en.m.wikipedia.org/wiki/Monarchy_of_the_Netherlands?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Monarchy_of_the_Netherlands"}},"extract":"The monarchy of the Netherlands is a constitutional monarchy whose role and position are governed by the Constitution of the Netherlands. Roughly a third of the Constitution explains the succession, mechanisms of accession and abdication to the throne, the roles and duties of the monarch, the formalities of communication between the States General of the Netherlands, and the monarch's role in creating laws.","extract_html":"<p>The <b>monarchy of the Netherlands</b> is a constitutional monarchy whose role and position are governed by the Constitution of the Netherlands. Roughly a third of the Constitution explains the succession, mechanisms of accession and abdication to the throne, the roles and duties of the monarch, the formalities of communication between the States General of the Netherlands, and the monarch's role in creating laws.</p>","normalizedtitle":"Monarchy of the Netherlands"}],"year":1848},{"text":"French invasion of Russia: As Napoleon's Grande Armée began its retreat, its rear guard was defeated at the Battle of Vyazma.","pages":[{"type":"standard","title":"French_invasion_of_Russia","displaytitle":"<span class=\"mw-page-title-main\">French invasion of Russia</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q179250","titles":{"canonical":"French_invasion_of_Russia","normalized":"French invasion of Russia","display":"<span class=\"mw-page-title-main\">French invasion of Russia</span>"},"pageid":24334819,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/5/55/French_invasion_of_Russia_collage.jpg/320px-French_invasion_of_Russia_collage.jpg","width":320,"height":240},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/5/55/French_invasion_of_Russia_collage.jpg","width":1024,"height":768},"lang":"en","dir":"ltr","revision":"1183189045","tid":"aad7abd0-79b0-11ee-ae01-557650f6f905","timestamp":"2023-11-02T18:50:10Z","description":"1812 conflict during the Napoleonic Wars","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/French_invasion_of_Russia","revisions":"https://en.wikipedia.org/wiki/French_invasion_of_Russia?action=history","edit":"https://en.wikipedia.org/wiki/French_invasion_of_Russia?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:French_invasion_of_Russia"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/French_invasion_of_Russia","revisions":"https://en.m.wikipedia.org/wiki/Special:History/French_invasion_of_Russia","edit":"https://en.m.wikipedia.org/wiki/French_invasion_of_Russia?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:French_invasion_of_Russia"}},"extract":"The French invasion of Russia, also known as Russian campaign and in Russia as the Patriotic War of 1812, was launched by Napoleon to force the Russian Empire back into the continental blockade of the United Kingdom. Napoleon's invasion of Russia is one of the best studied military campaigns in history and is listed among the most lethal military operations in world history. It is characterized by the massive toll on human life: in less than six months nearly a million soldiers and civilians died.","extract_html":"<p>The <b>French invasion of Russia</b>, also known as <b>Russian campaign</b> and in Russia as the <b>Patriotic War of 1812</b>, was launched by Napoleon to force the Russian Empire back into the continental blockade of the United Kingdom. Napoleon's invasion of Russia is one of the best studied military campaigns in history and is listed among the most lethal military operations in world history. It is characterized by the massive toll on human life: in less than six months nearly a million soldiers and civilians died.</p>","normalizedtitle":"French invasion of Russia"},{"type":"standard","title":"Napoleon","displaytitle":"<span class=\"mw-page-title-main\">Napoleon</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q517","titles":{"canonical":"Napoleon","normalized":"Napoleon","display":"<span class=\"mw-page-title-main\">Napoleon</span>"},"pageid":69880,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/5/50/Jacques-Louis_David_-_The_Emperor_Napoleon_in_His_Study_at_the_Tuileries_-_Google_Art_Project.jpg/320px-Jacques-Louis_David_-_The_Emperor_Napoleon_in_His_Study_at_the_Tuileries_-_Google_Art_Project.jpg","width":320,"height":534},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/5/50/Jacques-Louis_David_-_The_Emperor_Napoleon_in_His_Study_at_the_Tuileries_-_Google_Art_Project.jpg","width":3079,"height":5135},"lang":"en","dir":"ltr","revision":"1183111183","tid":"8fcf31a0-794c-11ee-ac70-77591cfe23a3","timestamp":"2023-11-02T06:53:29Z","description":"Military leader and emperor of the French (1769–1821)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Napoleon","revisions":"https://en.wikipedia.org/wiki/Napoleon?action=history","edit":"https://en.wikipedia.org/wiki/Napoleon?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Napoleon"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Napoleon","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Napoleon","edit":"https://en.m.wikipedia.org/wiki/Napoleon?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Napoleon"}},"extract":"Napoleon Bonaparte, later known by his regnal name Napoleon I, was a French military commander and political leader who rose to prominence during the French Revolution and led successful campaigns during the Revolutionary Wars. He was the leader of the French Republic as First Consul from 1799 to 1804, then of the French Empire as Emperor of the French from 1804 until 1814, and briefly again in 1815. Napoleon's political and cultural legacy endures as a celebrated and controversial leader. He initiated many liberal reforms that have persisted through the years, and is considered one of the greatest military commanders in history. His campaigns are still studied at military academies worldwide. Between three and six million soldiers and civilians died in the Napoleonic Wars.","extract_html":"<p><b>Napoleon Bonaparte</b>, later known by his regnal name <b>Napoleon I</b>, was a French military commander and political leader who rose to prominence during the French Revolution and led successful campaigns during the Revolutionary Wars. He was the leader of the French Republic as First Consul from 1799 to 1804, then of the French Empire as Emperor of the French from 1804 until 1814, and briefly again in 1815. Napoleon's political and cultural legacy endures as a celebrated and controversial leader. He initiated many liberal reforms that have persisted through the years, and is considered one of the greatest military commanders in history. His campaigns are still studied at military academies worldwide. Between three and six million soldiers and civilians died in the Napoleonic Wars.</p>","normalizedtitle":"Napoleon"},{"type":"standard","title":"Grande_Armée","displaytitle":"<i>Grande Armée</i>","namespace":{"id":0,"text":""},"wikibase_item":"Q504721","titles":{"canonical":"Grande_Armée","normalized":"Grande Armée","display":"<i>Grande Armée</i>"},"pageid":308084,"lang":"en","dir":"ltr","revision":"1182431314","tid":"e3b23410-76e1-11ee-b276-a5d298673d29","timestamp":"2023-10-29T09:12:46Z","description":"Field Army of the French Imperial Army","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Grande_Arm%C3%A9e","revisions":"https://en.wikipedia.org/wiki/Grande_Arm%C3%A9e?action=history","edit":"https://en.wikipedia.org/wiki/Grande_Arm%C3%A9e?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Grande_Arm%C3%A9e"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Grande_Arm%C3%A9e","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Grande_Arm%C3%A9e","edit":"https://en.m.wikipedia.org/wiki/Grande_Arm%C3%A9e?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Grande_Arm%C3%A9e"}},"extract":"La Grande Armée was the main military component of the French Imperial Army commanded by Emperor Napoleon Bonaparte during the Napoleonic Wars. From 1804 to 1808, it won a series of military victories that allowed the French Empire to exercise unprecedented control over most of Europe. Widely acknowledged to be one of the greatest fighting forces ever assembled, it suffered enormous losses during the disastrous invasion of Russia in 1812, after which it never recovered its strategic superiority.","extract_html":"<p><span><i lang=\"fr\"><b>La Grande Armée</b></i></span> was the main military component of the French Imperial Army commanded by Emperor Napoleon Bonaparte during the Napoleonic Wars. From 1804 to 1808, it won a series of military victories that allowed the French Empire to exercise unprecedented control over most of Europe. Widely acknowledged to be one of the greatest fighting forces ever assembled, it suffered enormous losses during the disastrous invasion of Russia in 1812, after which it never recovered its strategic superiority.</p>","normalizedtitle":"Grande Armée"},{"type":"standard","title":"Rearguard","displaytitle":"<span class=\"mw-page-title-main\">Rearguard</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q980173","titles":{"canonical":"Rearguard","normalized":"Rearguard","display":"<span class=\"mw-page-title-main\">Rearguard</span>"},"pageid":17293333,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/1/1b/USMC-090713-M-7693K-001.jpg/320px-USMC-090713-M-7693K-001.jpg","width":320,"height":214},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/1/1b/USMC-090713-M-7693K-001.jpg","width":3872,"height":2592},"lang":"en","dir":"ltr","revision":"1174807766","tid":"04b53d20-62a0-11ee-acee-adb10b460300","timestamp":"2023-09-10T20:15:48Z","description":"Military unit or personnel that protects the rear of the main force","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Rearguard","revisions":"https://en.wikipedia.org/wiki/Rearguard?action=history","edit":"https://en.wikipedia.org/wiki/Rearguard?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Rearguard"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Rearguard","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Rearguard","edit":"https://en.m.wikipedia.org/wiki/Rearguard?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Rearguard"}},"extract":"A rearguard or rear security is a part of a military force that protects it from attack from the rear, either during an advance or withdrawal. The term can also be used to describe forces protecting lines, such as communication lines, behind an army. Even more generally, a rearguard action may refer idiomatically to an attempt at preventing something though it is likely too late to be prevented; this idiomatic meaning may apply in either a military or non-military context.","extract_html":"<p>A <b>rearguard</b> or <b>rear security</b> is a part of a military force that protects it from attack from the rear, either during an advance or withdrawal. The term can also be used to describe forces protecting lines, such as communication lines, behind an army. Even more generally, a rearguard action may refer idiomatically to an attempt at preventing something though it is likely too late to be prevented; this idiomatic meaning may apply in either a military or non-military context.</p>","normalizedtitle":"Rearguard"},{"type":"standard","title":"Battle_of_Vyazma","displaytitle":"<span class=\"mw-page-title-main\">Battle of Vyazma</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q903472","titles":{"canonical":"Battle_of_Vyazma","normalized":"Battle of Vyazma","display":"<span class=\"mw-page-title-main\">Battle of Vyazma</span>"},"pageid":7574743,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/9/92/Battle_vyazma.jpg/320px-Battle_vyazma.jpg","width":320,"height":202},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/9/92/Battle_vyazma.jpg","width":1920,"height":1210},"lang":"en","dir":"ltr","revision":"1177261416","tid":"b8f2be10-67e2-11ee-bb36-9340ae522832","timestamp":"2023-09-26T23:32:42Z","description":"1812 battle during the French invasion of Russia","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Battle_of_Vyazma","revisions":"https://en.wikipedia.org/wiki/Battle_of_Vyazma?action=history","edit":"https://en.wikipedia.org/wiki/Battle_of_Vyazma?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Battle_of_Vyazma"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Battle_of_Vyazma","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Battle_of_Vyazma","edit":"https://en.m.wikipedia.org/wiki/Battle_of_Vyazma?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Battle_of_Vyazma"}},"extract":"The Battle of Vyazma, occurred at the beginning of Napoleon's retreat from Moscow. In this encounter a Russian force commanded by General Miloradovich inflicted heavy losses on the rear guard of the Grande Armée. Although the French thwarted Miloradovich's goal of encircling and destroying the corps of Marshal Davout, they withdrew in a partial state of disorder due to ongoing Russian harassment and heavy artillery bombardments. The French reversal at Vyazma, although indecisive, was significant due to its damaging impact on several corps of Napoleon's retreating army.","extract_html":"<p>The <b>Battle of Vyazma</b>, occurred at the beginning of Napoleon's retreat from Moscow. In this encounter a Russian force commanded by General Miloradovich inflicted heavy losses on the rear guard of the <i>Grande Armée</i>. Although the French thwarted Miloradovich's goal of encircling and destroying the corps of Marshal Davout, they withdrew in a partial state of disorder due to ongoing Russian harassment and heavy artillery bombardments. The French reversal at Vyazma, although indecisive, was significant due to its damaging impact on several corps of Napoleon's retreating army.</p>","normalizedtitle":"Battle of Vyazma"}],"year":1812},{"text":"War of the Third Coalition: The Treaty of Potsdam was signed compelling Prussia to join the coalition if it failed to negotiate peace between Russia and France.","pages":[{"type":"standard","title":"War_of_the_Third_Coalition","displaytitle":"<span class=\"mw-page-title-main\">War of the Third Coalition</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q249232","titles":{"canonical":"War_of_the_Third_Coalition","normalized":"War of the Third Coalition","display":"<span class=\"mw-page-title-main\">War of the Third Coalition</span>"},"pageid":178661,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/1/10/War_of_the_3rd_coalition.jpg/320px-War_of_the_3rd_coalition.jpg","width":320,"height":360},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/1/10/War_of_the_3rd_coalition.jpg","width":880,"height":990},"lang":"en","dir":"ltr","revision":"1177593069","tid":"9e189f30-778a-11ee-8f68-6d6e703a55b7","timestamp":"2023-09-28T10:05:44Z","description":"1805–1806 conflict during the Napoleonic Wars","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/War_of_the_Third_Coalition","revisions":"https://en.wikipedia.org/wiki/War_of_the_Third_Coalition?action=history","edit":"https://en.wikipedia.org/wiki/War_of_the_Third_Coalition?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:War_of_the_Third_Coalition"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/War_of_the_Third_Coalition","revisions":"https://en.m.wikipedia.org/wiki/Special:History/War_of_the_Third_Coalition","edit":"https://en.m.wikipedia.org/wiki/War_of_the_Third_Coalition?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:War_of_the_Third_Coalition"}},"extract":"The War of the Third Coalition was a European conflict spanning from 1805 to 1806. During the war, France and its client states under Napoleon I opposed an alliance, the Third Coalition, which was made up of the United Kingdom, the Austrian Empire, the Russian Empire, Naples, Sicily, and Sweden. Prussia remained neutral during the war.","extract_html":"<p>The <b>War of the Third Coalition</b> was a European conflict spanning from 1805 to 1806. During the war, France and its client states under Napoleon I opposed an alliance, the Third Coalition, which was made up of the United Kingdom, the Austrian Empire, the Russian Empire, Naples, Sicily, and Sweden. Prussia remained neutral during the war.</p>","normalizedtitle":"War of the Third Coalition"},{"type":"standard","title":"Treaty_of_Potsdam_(1805)","displaytitle":"<span class=\"mw-page-title-main\">Treaty of Potsdam (1805)</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q85810595","titles":{"canonical":"Treaty_of_Potsdam_(1805)","normalized":"Treaty of Potsdam (1805)","display":"<span class=\"mw-page-title-main\">Treaty of Potsdam (1805)</span>"},"pageid":59431762,"lang":"en","dir":"ltr","revision":"1180354890","tid":"79514450-6bd1-11ee-bd03-55895771f98f","timestamp":"2023-10-16T03:09:50Z","description":"1805 treaty between Prussia and Russia","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Treaty_of_Potsdam_(1805)","revisions":"https://en.wikipedia.org/wiki/Treaty_of_Potsdam_(1805)?action=history","edit":"https://en.wikipedia.org/wiki/Treaty_of_Potsdam_(1805)?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Treaty_of_Potsdam_(1805)"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Treaty_of_Potsdam_(1805)","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Treaty_of_Potsdam_(1805)","edit":"https://en.m.wikipedia.org/wiki/Treaty_of_Potsdam_(1805)?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Treaty_of_Potsdam_(1805)"}},"extract":"The Treaty of Potsdam was a treaty signed during the War of the Third Coalition on 3 November 1805 between Alexander I of the Russian Empire and Frederick William III of Prussia. It required Prussia to mediate negotiations between Napoleon's French Empire and Russia, and if the negotiations failed, join the Third Coalition.","extract_html":"<p>The <b>Treaty of Potsdam</b> was a treaty signed during the War of the Third Coalition on 3 November 1805 between Alexander I of the Russian Empire and Frederick William III of Prussia. It required Prussia to mediate negotiations between Napoleon's French Empire and Russia, and if the negotiations failed, join the Third Coalition.</p>","normalizedtitle":"Treaty of Potsdam (1805)"}],"year":1805},{"text":"French Revolution: Playwright, journalist and outspoken feminist Olympe de Gouges  was guillotined.","pages":[{"type":"standard","title":"French_Revolution","displaytitle":"<span class=\"mw-page-title-main\">French Revolution</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q6534","titles":{"canonical":"French_Revolution","normalized":"French Revolution","display":"<span class=\"mw-page-title-main\">French Revolution</span>"},"pageid":11188,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/5/57/Anonymous_-_Prise_de_la_Bastille.jpg/320px-Anonymous_-_Prise_de_la_Bastille.jpg","width":320,"height":252},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/5/57/Anonymous_-_Prise_de_la_Bastille.jpg","width":8332,"height":6571},"lang":"en","dir":"ltr","revision":"1183286983","tid":"4e596c50-7a36-11ee-8269-1bf558cac365","timestamp":"2023-11-03T10:46:49Z","description":"Revolution in France from 1789 to 1799","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/French_Revolution","revisions":"https://en.wikipedia.org/wiki/French_Revolution?action=history","edit":"https://en.wikipedia.org/wiki/French_Revolution?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:French_Revolution"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/French_Revolution","revisions":"https://en.m.wikipedia.org/wiki/Special:History/French_Revolution","edit":"https://en.m.wikipedia.org/wiki/French_Revolution?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:French_Revolution"}},"extract":"The French Revolution was a period of political and societal change in France that began with the Estates General of 1789, and ended with the formation of the French Consulate in November 1799. Many of its ideas are considered fundamental principles of liberal democracy, while its values and institutions remain central to modern French political discourse.","extract_html":"<p>The <b>French Revolution</b> was a period of political and societal change in France that began with the Estates General of 1789, and ended with the formation of the French Consulate in November 1799. Many of its ideas are considered fundamental principles of liberal democracy, while its values and institutions remain central to modern French political discourse.</p>","normalizedtitle":"French Revolution"},{"type":"standard","title":"Olympe_de_Gouges","displaytitle":"<span class=\"mw-page-title-main\">Olympe de Gouges</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q206972","titles":{"canonical":"Olympe_de_Gouges","normalized":"Olympe de Gouges","display":"<span class=\"mw-page-title-main\">Olympe de Gouges</span>"},"pageid":407530,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/0/05/Olympe_de_Gouges.png/320px-Olympe_de_Gouges.png","width":320,"height":427},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/0/05/Olympe_de_Gouges.png","width":816,"height":1090},"lang":"en","dir":"ltr","revision":"1183288168","tid":"26999260-7a38-11ee-9f1a-ddbf9174f75f","timestamp":"2023-11-03T11:00:04Z","description":"French playwright and activist (1748–1793)","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Olympe_de_Gouges","revisions":"https://en.wikipedia.org/wiki/Olympe_de_Gouges?action=history","edit":"https://en.wikipedia.org/wiki/Olympe_de_Gouges?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Olympe_de_Gouges"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Olympe_de_Gouges","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Olympe_de_Gouges","edit":"https://en.m.wikipedia.org/wiki/Olympe_de_Gouges?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Olympe_de_Gouges"}},"extract":"Olympe de Gouges was a French playwright and political activist. She is best known for her Declaration of the Rights of Woman and of the Female Citizen and other writings on women's rights and abolitionism.","extract_html":"<p><b>Olympe de Gouges</b> was a French playwright and political activist. She is best known for her Declaration of the Rights of Woman and of the Female Citizen and other writings on women's rights and abolitionism.</p>","normalizedtitle":"Olympe de Gouges"},{"type":"standard","title":"Guillotine","displaytitle":"<span class=\"mw-page-title-main\">Guillotine</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q128015","titles":{"canonical":"Guillotine","normalized":"Guillotine","display":"<span class=\"mw-page-title-main\">Guillotine</span>"},"pageid":51272,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/0/0f/Guillotine_Luxembourg_01.jpg/320px-Guillotine_Luxembourg_01.jpg","width":320,"height":427},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/0/0f/Guillotine_Luxembourg_01.jpg","width":2304,"height":3072},"lang":"en","dir":"ltr","revision":"1183254805","tid":"790a77c0-79fd-11ee-ab71-a7ee32c42389","timestamp":"2023-11-03T04:00:03Z","description":"Apparatus designed for carrying out executions by beheading","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Guillotine","revisions":"https://en.wikipedia.org/wiki/Guillotine?action=history","edit":"https://en.wikipedia.org/wiki/Guillotine?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Guillotine"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Guillotine","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Guillotine","edit":"https://en.m.wikipedia.org/wiki/Guillotine?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Guillotine"}},"extract":"A guillotine is an apparatus designed for efficiently carrying out executions by beheading. The device consists of a tall, upright frame with a weighted and angled blade suspended at the top. The condemned person is secured with a pillory at the bottom of the frame, holding the position of the neck directly below the blade. The blade is then released, swiftly and forcefully decapitating the victim with a single, clean pass; the head falls into a basket or other receptacle below.","extract_html":"<p>A <b>guillotine</b> is an apparatus designed for efficiently carrying out executions by beheading. The device consists of a tall, upright frame with a weighted and angled blade suspended at the top. The condemned person is secured with a pillory at the bottom of the frame, holding the position of the neck directly below the blade. The blade is then released, swiftly and forcefully decapitating the victim with a single, clean pass; the head falls into a basket or other receptacle below.</p>","normalizedtitle":"Guillotine"}],"year":1793},{"text":"The Parliament of England passed the first Act of Supremacy, making King Henry VIII head of the Church of England, supplanting the pope and the Catholic Church.","pages":[{"type":"standard","title":"Parliament_of_England","displaytitle":"<span class=\"mw-page-title-main\">Parliament of England</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q1130737","titles":{"canonical":"Parliament_of_England","normalized":"Parliament of England","display":"<span class=\"mw-page-title-main\">Parliament of England</span>"},"pageid":378033,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/3/3a/Coat_of_Arms_of_England_%281558-1603%29.svg/320px-Coat_of_Arms_of_England_%281558-1603%29.svg.png","width":320,"height":320},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/3/3a/Coat_of_Arms_of_England_%281558-1603%29.svg/1550px-Coat_of_Arms_of_England_%281558-1603%29.svg.png","width":1550,"height":1550},"lang":"en","dir":"ltr","revision":"1180496158","tid":"cd7cae40-6c83-11ee-81e6-a712230da287","timestamp":"2023-10-17T00:26:18Z","description":"Legislature of England, c. 1215 to 1707","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Parliament_of_England","revisions":"https://en.wikipedia.org/wiki/Parliament_of_England?action=history","edit":"https://en.wikipedia.org/wiki/Parliament_of_England?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Parliament_of_England"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Parliament_of_England","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Parliament_of_England","edit":"https://en.m.wikipedia.org/wiki/Parliament_of_England?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Parliament_of_England"}},"extract":"The Parliament of England was the legislature of the Kingdom of England from the 13th century until 1707 when it was replaced by the Parliament of Great Britain. Parliament evolved from the great council of bishops and peers that advised the English monarch. Great councils were first called Parliaments during the reign of Henry III. By this time, the king required Parliament's consent to levy taxation.","extract_html":"<p>The <b>Parliament of England</b> was the legislature of the Kingdom of England from the 13th century until 1707 when it was replaced by the Parliament of Great Britain. Parliament evolved from the great council of bishops and peers that advised the English monarch. Great councils were first called Parliaments during the reign of Henry III. By this time, the king required Parliament's consent to levy taxation.</p>","normalizedtitle":"Parliament of England"},{"type":"standard","title":"Acts_of_Supremacy","displaytitle":"<span class=\"mw-page-title-main\">Acts of Supremacy</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q392226","titles":{"canonical":"Acts_of_Supremacy","normalized":"Acts of Supremacy","display":"<span class=\"mw-page-title-main\">Acts of Supremacy</span>"},"pageid":367969,"lang":"en","dir":"ltr","revision":"1180074294","tid":"bb5cf810-7a3d-11ee-862d-cf2fefaa9de7","timestamp":"2023-10-14T10:17:35Z","description":"16th century English laws establishing Royal Supremacy","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Acts_of_Supremacy","revisions":"https://en.wikipedia.org/wiki/Acts_of_Supremacy?action=history","edit":"https://en.wikipedia.org/wiki/Acts_of_Supremacy?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Acts_of_Supremacy"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Acts_of_Supremacy","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Acts_of_Supremacy","edit":"https://en.m.wikipedia.org/wiki/Acts_of_Supremacy?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Acts_of_Supremacy"}},"extract":"The Acts of Supremacy are two acts passed by the Parliament of England in the 16th century that established the English monarchs as the head of the Church of England; two similar laws were passed by the Parliament of Ireland establishing the English monarchs as the head of the Church of Ireland. The 1534 Act declared King Henry VIII and his successors as the Supreme Head of the Church, replacing the Pope. This first Act was repealed during the reign of the Catholic Queen Mary I. The 1558 Act declared Queen Elizabeth I and her successors the Supreme Governor of the Church, a title that the British monarch still holds.","extract_html":"<p>The <b>Acts of Supremacy</b> are two acts passed by the Parliament of England in the 16th century that established the English monarchs as the head of the Church of England; two similar laws were passed by the Parliament of Ireland establishing the English monarchs as the head of the Church of Ireland. The 1534 Act declared King Henry VIII and his successors as the Supreme Head of the Church, replacing the Pope. This first Act was repealed during the reign of the Catholic Queen Mary I. The 1558 Act declared Queen Elizabeth I and her successors the Supreme Governor of the Church, a title that the British monarch still holds.</p>","normalizedtitle":"Acts of Supremacy"},{"type":"standard","title":"Henry_VIII","displaytitle":"<span class=\"mw-page-title-main\">Henry VIII</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q38370","titles":{"canonical":"Henry_VIII","normalized":"Henry VIII","display":"<span class=\"mw-page-title-main\">Henry VIII</span>"},"pageid":14187,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/f/f9/After_Hans_Holbein_the_Younger_-_Portrait_of_Henry_VIII_-_Google_Art_Project.jpg/320px-After_Hans_Holbein_the_Younger_-_Portrait_of_Henry_VIII_-_Google_Art_Project.jpg","width":320,"height":563},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/f/f9/After_Hans_Holbein_the_Younger_-_Portrait_of_Henry_VIII_-_Google_Art_Project.jpg","width":2041,"height":3589},"lang":"en","dir":"ltr","revision":"1182959066","tid":"6b42d2b0-78b1-11ee-8ce8-e3deddfc651d","timestamp":"2023-11-01T12:23:02Z","description":"King of England from 1509 to 1547","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Henry_VIII","revisions":"https://en.wikipedia.org/wiki/Henry_VIII?action=history","edit":"https://en.wikipedia.org/wiki/Henry_VIII?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Henry_VIII"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Henry_VIII","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Henry_VIII","edit":"https://en.m.wikipedia.org/wiki/Henry_VIII?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Henry_VIII"}},"extract":"Henry VIII was King of England from 22 April 1509 until his death in 1547. Henry is best known for his six marriages, and his efforts to have his first marriage annulled. His disagreement with Pope Clement VII about such an annulment led Henry to initiate the English Reformation, separating the Church of England from papal authority. He appointed himself Supreme Head of the Church of England and dissolved convents and monasteries, for which he was excommunicated by the pope.","extract_html":"<p><b>Henry VIII</b> was King of England from 22 April 1509 until his death in 1547. Henry is best known for his six marriages, and his efforts to have his first marriage annulled. His disagreement with Pope Clement VII about such an annulment led Henry to initiate the English Reformation, separating the Church of England from papal authority. He appointed himself Supreme Head of the Church of England and dissolved convents and monasteries, for which he was excommunicated by the pope.</p>","normalizedtitle":"Henry VIII"},{"type":"standard","title":"Church_of_England","displaytitle":"<span class=\"mw-page-title-main\">Church of England</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q82708","titles":{"canonical":"Church_of_England","normalized":"Church of England","display":"<span class=\"mw-page-title-main\">Church of England</span>"},"pageid":5955,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/b/be/Logo_of_the_Church_of_England.svg/320px-Logo_of_the_Church_of_England.svg.png","width":320,"height":229},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/b/be/Logo_of_the_Church_of_England.svg/700px-Logo_of_the_Church_of_England.svg.png","width":700,"height":500},"lang":"en","dir":"ltr","revision":"1182701145","tid":"2229c480-776c-11ee-aba8-f98b8e42c4eb","timestamp":"2023-10-30T21:34:29Z","description":"Anglican state church in England","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Church_of_England","revisions":"https://en.wikipedia.org/wiki/Church_of_England?action=history","edit":"https://en.wikipedia.org/wiki/Church_of_England?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Church_of_England"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Church_of_England","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Church_of_England","edit":"https://en.m.wikipedia.org/wiki/Church_of_England?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Church_of_England"}},"extract":"The Church of England is the established Christian church in England. It traces its history to the Christian church recorded as existing in the Roman province of Britain by the 3rd century and to the 6th-century Gregorian mission to Kent led by Augustine of Canterbury. Its adherents are called Anglicans.","extract_html":"<p>The <b>Church of England</b> is the established Christian church in England. It traces its history to the Christian church recorded as existing in the Roman province of Britain by the 3rd century and to the 6th-century Gregorian mission to Kent led by Augustine of Canterbury. Its adherents are called <i>Anglicans</i>.</p>","normalizedtitle":"Church of England"},{"type":"standard","title":"Pope","displaytitle":"<span class=\"mw-page-title-main\">Pope</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q19546","titles":{"canonical":"Pope","normalized":"Pope","display":"<span class=\"mw-page-title-main\">Pope</span>"},"pageid":23056,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/9/95/Portrait_of_Pope_Francis_%282021%29_FXD.jpg/320px-Portrait_of_Pope_Francis_%282021%29_FXD.jpg","width":320,"height":425},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/9/95/Portrait_of_Pope_Francis_%282021%29_FXD.jpg","width":991,"height":1316},"lang":"en","dir":"ltr","revision":"1183199454","tid":"9ed6da30-79bb-11ee-babc-33c4fd4b3de1","timestamp":"2023-11-02T20:08:29Z","description":"Head of the Catholic Church","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Pope","revisions":"https://en.wikipedia.org/wiki/Pope?action=history","edit":"https://en.wikipedia.org/wiki/Pope?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Pope"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Pope","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Pope","edit":"https://en.m.wikipedia.org/wiki/Pope?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Pope"}},"extract":"The pope, also known as the supreme pontiff, Roman pontiff or sovereign pontiff, is the bishop of Rome, head of the worldwide Catholic Church, and has also served as the head of state or sovereign of the Papal States and later the Vatican City State since the eighth century. From a Catholic viewpoint, the primacy of the bishop of Rome is largely derived from his role as the apostolic successor to Saint Peter, to whom primacy was conferred by Jesus, who gave Peter the Keys of Heaven and the powers of \"binding and loosing\", naming him as the \"rock\" upon which the Church would be built. The current pope is Francis, who was elected on 13 March 2013.","extract_html":"<p>The <b>pope</b>, also known as the <b>supreme pontiff</b>, <b>Roman pontiff</b> or <b>sovereign pontiff</b>, is the <b>bishop of Rome</b>, head of the worldwide Catholic Church, and has also served as the head of state or sovereign of the Papal States and later the Vatican City State since the eighth century. From a Catholic viewpoint, the primacy of the bishop of Rome is largely derived from his role as the apostolic successor to Saint Peter, to whom primacy was conferred by Jesus, who gave Peter the Keys of Heaven and the powers of \"binding and loosing\", naming him as the \"rock\" upon which the Church would be built. The current pope is Francis, who was elected on 13 March 2013.</p>","normalizedtitle":"Pope"},{"type":"standard","title":"Catholic_Church","displaytitle":"<span class=\"mw-page-title-main\">Catholic Church</span>","namespace":{"id":0,"text":""},"wikibase_item":"Q9592","titles":{"canonical":"Catholic_Church","normalized":"Catholic Church","display":"<span class=\"mw-page-title-main\">Catholic Church</span>"},"pageid":606848,"thumbnail":{"source":"https://upload.wikimedia.org/wikipedia/commons/thumb/0/0e/Saint_Peter%27s_Basilica_facade%2C_Rome%2C_Italy.jpg/320px-Saint_Peter%27s_Basilica_facade%2C_Rome%2C_Italy.jpg","width":320,"height":213},"originalimage":{"source":"https://upload.wikimedia.org/wikipedia/commons/0/0e/Saint_Peter%27s_Basilica_facade%2C_Rome%2C_Italy.jpg","width":4470,"height":2975},"lang":"en","dir":"ltr","revision":"1182544864","tid":"098424f0-7886-11ee-b156-158e5e97700e","timestamp":"2023-10-29T23:50:31Z","description":"Major Christian church based in Rome","description_source":"local","content_urls":{"desktop":{"page":"https://en.wikipedia.org/wiki/Catholic_Church","revisions":"https://en.wikipedia.org/wiki/Catholic_Church?action=history","edit":"https://en.wikipedia.org/wiki/Catholic_Church?action=edit","talk":"https://en.wikipedia.org/wiki/Talk:Catholic_Church"},"mobile":{"page":"https://en.m.wikipedia.org/wiki/Catholic_Church","revisions":"https://en.m.wikipedia.org/wiki/Special:History/Catholic_Church","edit":"https://en.m.wikipedia.org/wiki/Catholic_Church?action=edit","talk":"https://en.m.wikipedia.org/wiki/Talk:Catholic_Church"}},"extract":"The Catholic Church, also known as the Roman Catholic Church, is the largest Christian church, with 1.3 billion baptized Catholics worldwide as of 2019. It is among the world's oldest and largest international institutions, and has played a prominent role in the history and development of Western civilization. The church consists of 24 sui iuris churches, including the Latin Church and 23 Eastern Catholic Churches, which comprise almost 3,500 dioceses and eparchies located around the world. The pope, who is the bishop of Rome, is the chief pastor of the church. The bishopric of Rome, known as the Holy See, is the central governing authority of the church. The administrative body of the Holy See, the Roman Curia, has its principal offices in Vatican City, a small enclave of the Italian city of Rome, of which the pope is head of state.","extract_html":"<p>The <b>Catholic Church</b>, also known as the <b>Roman Catholic Church</b>, is the largest Christian church, with 1.3 billion baptized Catholics worldwide as of 2019. It is among the world's oldest and largest international institutions, and has played a prominent role in the history and development of Western civilization. The church consists of 24 <span><i>sui iuris</i> churches</span>, including the Latin Church and 23 Eastern Catholic Churches, which comprise almost 3,500 dioceses and eparchies located around the world. The pope, who is the bishop of Rome, is the chief pastor of the church. The bishopric of Rome, known as the Holy See, is the central governing authority of the church. The administrative body of the Holy See, the Roman Curia, has its principal offices in Vatican City, a small enclave of the Italian city of Rome, of which the pope is head of state.</p>","normalizedtitle":"Catholic Church"}],"year":1534}]}
''';
